from faker import Faker
from faker.providers import BaseProvider
import random
from psycopg2.extensions import AsIs
import psycopg2
import datetime as dt

DSN = 'postgres://postgres@localhost'

fake = Faker()
print(fake.job())

class Provider(BaseProvider):
    teams = ['backoffice 1', 'backoffice 2', 'call team', 'chat team', 'email team']
    tiers = ['T1', 'T2', 'T3']
    sites = ['Zlin', 'Brno', 'Bangladesh', 'Tunis', 'Amsterdam']
    channels = ['Emails', 'Voice&Emails', 'Chat', 'Operations', 'Complaints']
    positions = ['CS specialist', 'OPS specialist', 'CS Junior', 'OPS Junior', 'OPS Senior']

    queues = ['Call EN', 'Call FR', 'Call JP', 'Complaints', 'Chat EN', 'Refunds']
    queue_groups = ['BackOffice', 'Urgent', 'General', 'FrontOffice']
    off_reasons = ['Vacation', 'Sick day', 'Doctors appt', 'Maternity leave']


    def get_team(self):
        return random.choice(self.teams)

    def get_tier(self):
        return random.choice(self.tiers)

    def get_site(self):
        return random.choice(self.sites)
    
    def get_channel(self):
        return random.choice(self.channels)

    def get_position(self):
        return random.choice(self.positions)

    def get_queue(self):
        return random.choice(self.queues)

    def get_queue_group(self):
        return random.choice(self.queue_groups)
    
    def get_shift_plan(self):
        day_in_future = random.randint(0,30)
        shift_start = random.choice([7,15,23])
        shift_length = random.choice([8,12])
        today = dt.date.today()
        shift_start = (dt.datetime(
            year=today.year, 
            month=today.month,
            day=today.day
        ) + dt.timedelta(days=day_in_future)).replace(hour=shift_start)
        shift_end = shift_start + dt.timedelta(hours=shift_length)
        return shift_start, shift_end

    def get_off_reason(self):
        return random.choice(self.off_reasons)



fake.add_provider(Provider)
print(fake.get_channel())


def create_agents():
    agents = []
    for _ in range(100):
        agents.append({
            "first_name": fake.first_name(),
            "last_name": fake.last_name(),
            "email": fake.email(),
            "staff": '',
            "active": True,
            "team_manager": None,
            "site": fake.get_site(),
            "position": fake.get_position(),
            "channel": fake.get_channel(),
            "tier": fake.get_tier(),
            "team": fake.get_team(),
            "purecloud_id": None,
            "position_abbr": fake.get_position()[:2],
        })
    return agents


def create_queues():
    queue_names = ['Call EN', 'Call FR', 'Call JP', 'Complaints', 'Chat EN', 'Refunds']
    queues = []
    for q_name in queue_names:
        queues.append({
            "name": q_name,
            "purecloud_id": None,
            "balkan_id": None,
            "group_name": fake.get_queue_group()
        })
    return queues


def create_shifts():
    shifts_names = ['BO morning 8h', 'BO afternoon 8h', 'BO night 8h', 'FO morning 12h','FO afternoon 12h','FO night 12h'
    ,'Complaints 8h']
    shifts = []
    for shift_name in shifts_names:
        shifts.append({
            "name": shift_name,
            "description":'',
            "length": 8,
            "minspacing":0,
            "delete_on_utc": None,
            "created_on_utc": dt.utcnow(),
            "created_by": fake.email(),
            "modified_on_utc": None,
            "modified_by":None,
            "maxspacing":None,
        })
    return shifts

def create_on_shift_plan():
    on_shift_plan = []
    for _ in range(500):
        start, end = fake.get_shift_plan()
        on_shift_plan.append({
            "shift_id": random.randint(1,7),
            "start_time_utc": start,
            "end_time_utc": end,
            "agent_id": random.randint(5,104),
        })
    return on_shift_plan

def create_off_shift_plan():
    off_shift_plan = []
    for _ in range(50):
        start, end = fake.get_shift_plan()
        off_shift_plan.append({
            "shift_id": random.randint(1,7),
            "start_time_utc": start,
            "end_time_utc": end,
            "agent_id": random.randint(5,104),
            "off_reason": fake.get_off_reason()
        })
    return off_shift_plan

def create_agent_shift_queue():
    off_shift_plan = []
    for _ in range(50):
        start, end = fake.get_shift_plan()
        off_shift_plan.append({
            "shift_id": random.randint(1,7),
            "start_time_utc": start,
            "end_time_utc": end,
            "agent_id": random.randint(5,104),
            "off_reason": fake.get_off_reason()
        })
    return off_shift_plan


with psycopg2.connect(DSN) as conn:
    with conn.cursor() as curs:
        insert_statement = 'insert into agent_off_shift (%s) values %s'
        for row in create_off_shift_plan():
            print(curs.execute(insert_statement, (AsIs(','.join(row.keys())), tuple(row.values()))))

        
        