import React, {Component} from 'react';
import {Switch, Route, Redirect} from 'react-router-dom';
import PropTypes from "prop-types";

import {createMuiTheme, MuiThemeProvider, withStyles} from '@material-ui/core/styles';
import Grid from '@material-ui/core/Grid';
import CssBaseline from '@material-ui/core/CssBaseline';
import {MuiPickersUtilsProvider} from 'material-ui-pickers';
import MomentUtils from '@date-io/moment';

import {Query} from 'react-apollo';
import gql from 'graphql-tag';

import './App.css';
import NavBar from './components/navbar';
import AgentsDashboard from './components/agentsDashboard';
import QueuesDashboard from './components/queuesDashboard';
import HistoryDashboard from './components/historyDashboard';



const styles = theme => ({
    wrapper: {
        flexGrow: 1,
        margin: theme.spacing.unit * 4,
        marginTop: theme.spacing.unit * 8,
        textAlign: 'left',
    }
});

class App extends Component {

    getTheme(paletteType) {
        return createMuiTheme({
            palette: {
                type: paletteType,
                primary: {
                    strong: '#00695f',
                    main: '#009688',
                    light: '#33ab9f',
                    contrastText: '#fff',
                },
                secondary: {
                    strong: '#ab003c',
                    main: '#f50057',
                    light: '#f73378',
                    contrastText: '#fff',
                },
                background: {
                    default: paletteType === 'light' ? '#eeeeee' : '#303030',
                }
            },
            typography: {
                useNextVariants: true,
            },
            overrides: {
                MUIDataTable: {
                    paper: {
                        boxShadow: 'none',
                    }
                },
            }
        });
    }

    render() {
        const {classes} = this.props;
        return (
            <Query query={gql`query{selectedTheme @client}`}>
                {({data}) => {
                    return (
                        <MuiThemeProvider theme={this.getTheme(data.selectedTheme)}>
                            <MuiPickersUtilsProvider utils={MomentUtils}>
                                <React.Fragment>
                                    <CssBaseline/>
                                    <main className="container">
                                        <NavBar/>
                                        <div className={classes.wrapper}>
                                            <Grid container>
                                                <Grid item xs={12}>
                                                    <Switch>
                                                        <Route path="/agents" component={AgentsDashboard} />
                                                        <Route path="/queues" component={QueuesDashboard} />
                                                        <Route path="/history" component={HistoryDashboard} />
                                                        <Redirect from="/" to="/agents" />
                                                    </Switch>
                                                </Grid>
                                            </Grid>
                                        </div>
                                    </main>
                                </React.Fragment>
                            </MuiPickersUtilsProvider>
                        </MuiThemeProvider>
                    );
                }}
            </Query>

        );
    }
}

App.propTypes = {
    classes: PropTypes.object.isRequired,
};


export default withStyles(styles)(App);
