import React from 'react';
import {withApollo} from 'react-apollo';
import PropTypes from 'prop-types';

import {withStyles} from '@material-ui/core/styles';
import GroupAddIcon from '@material-ui/icons/GroupAdd';
import {IconButton, Tooltip} from '@material-ui/core';

import {selectStyles} from './autocompleteSelect';
import {ShiftToggle, Stats, ApplyChangesConfirmation} from './tableTools';
import SingleAgentDialog from './singleAgentDialog';


const defaultToolbarStyles = (theme) => ({
    iconButton: {
        '&:hover svg': {
            color: theme.palette.primary.main,
        }
    },
    statsWrapper: {
        position: 'absolute',
        top: theme.spacing.unit * 6 - 2,
        left: theme.spacing.unit * 3,
    },
    dialogActions: {
        margin: theme.spacing.unit * 3,
        marginTop: theme.spacing.unit,
        marginBottom: theme.spacing.unit * 2,
    },
    selectWrapper: {
        minHeight: 320,
    },
});

class AgentsTableToolbar extends React.Component {

    constructor(props, context) {
        super(props, context);
        this.state = {
            isSingleAgentDialogOpen: false,
        };
    }

    openSingleAgentDialog = () => {
        this.setState({isSingleAgentDialogOpen: true});
    };


    render() {
        const {client, classes, onApplyChanges} = this.props;
        return (
            <React.Fragment>
                <ShiftToggle classes={classes} client={client}/>
                <SingleAgentDialog
                    title={'Add Agents To Queue'}
                    isOpen={this.state.isSingleAgentDialogOpen}
                    classes={classes}
                    onApplyChanges={() => {
                        this.setState({isSingleAgentDialogOpen: false});
                        if (typeof onApplyChanges === 'function') {
                            onApplyChanges();
                        }
                    }}
                    client={client}
                />

                <Tooltip title="Add Agents to Queues">
                    <IconButton className={classes.iconButton} onClick={this.openSingleAgentDialog}>
                        <GroupAddIcon/>
                    </IconButton>
                </Tooltip>

                <ApplyChangesConfirmation
                    classes={classes}
                    client={client}
                    cacheName={'updatedAgentsTableQueues'}
                    additionalColumns={{
                        shift_id: 'shiftId',
                        start_time_utc: 'shiftStartTimeUTC',
                        end_time_utc: 'shiftEndTimeUTC',
                    }}
                    onApplyChanges={onApplyChanges}
                />

                <Stats classes={classes} client={client}/>
            </React.Fragment>
        )
    }
}

AgentsTableToolbar.propTypes = {
    classes: PropTypes.object.isRequired,
    client: PropTypes.object.isRequired,
    onApplyChanges: PropTypes.func,
};


export default withApollo(withStyles((theme) => ({
    ...selectStyles(theme),
    ...defaultToolbarStyles(theme),
}), {name: 'AgentsTableToolbar'})(AgentsTableToolbar));