import React from 'react';
import {withStyles} from '@material-ui/core';
import PropTypes from 'prop-types';
import {Query} from 'react-apollo';
import gql from 'graphql-tag';

import Progress from './progress';
import Error from './error';
import {HistoryTable} from './table';


const styles = theme => ({
    root: {
        marginBottom: theme.spacing.unit * 2,
    },
    controlsWrapper: {
        paddingTop: theme.spacing.unit * 2,
    },
    tableWrapper: {
        marginTop: theme.spacing.unit * 8,
    },
});

class HistoryDashboard extends React.Component {

    query = gql`query {
      logs:log(order_by: {created_on_utc: desc}) {
        action
        agent: agent_fk {
          email
          id
        }
        queue {
          name
          id
        }
        author
        created_on_utc
      }
    }`;

    render() {
        const {classes} = this.props;
        return (
            <React.Fragment>
                <Query query={this.query} pollInterval={1000}>
                    {({loading, error, data}) => {
                        if (loading) return <Progress/>;
                        if (error) return <Error msg={'Failed to load history entries'} />;

                        const history = data.logs.map(log => {
                            return [
                                log.created_on_utc,
                                log.action,
                                log.agent && log.agent.email ? log.agent.email : '',
                                log.agent && log.agent.id ? log.agent.id : '',
                                log.queue && log.queue.name ? log.queue.name : '',
                                log.queue && log.queue.id ? log.queue.id : '',
                                log.author,
                            ];
                        });

                        return <HistoryTable data={history} classes={classes}/>
                    }}
                </Query>
            </React.Fragment>
        );
    }
}

HistoryDashboard.propTypes = {
    classes: PropTypes.object.isRequired,
};

export default withStyles(styles)(HistoryDashboard);
