import React from 'react';
import PropTypes from 'prop-types';
import {withStyles} from '@material-ui/core/styles';
import AppBar from '@material-ui/core/AppBar';
import Toolbar from '@material-ui/core/Toolbar';
import IconButton from '@material-ui/core/IconButton';
import WbIncandescent from '@material-ui/icons/WbIncandescent';
import Tooltip from '@material-ui/core/Tooltip';

import {Mutation} from 'react-apollo';
import gql from 'graphql-tag';
import {NavLink} from 'react-router-dom';

import {Typography} from '@material-ui/core';


const styles = theme => ({
    subHeader: {
        backgroundColor: theme.palette.background.paper,
    },
    appBar: {
        top: 0,
        bottom: 'auto',
    },
    iconWrapper: {
        position: 'relative',
        bottom: -5,
        paddingRight: theme.spacing.unit,
    },
    toolbar: {
        alignItems: 'center',
        justifyContent: 'space-between',
    },
    toolbarLink: {
        padding: theme.spacing.unit * 1.5,
        paddingBottom: theme.spacing.unit,
        color: theme.palette.primary.contrastText,
        textDecoration: 'none',
        textTransform: 'uppercase',
        fontSize: 14,
        fontWeight: 500,
        '&.active': {
            textDecoration: 'underline',
        }
    },
    leftToolbar: {
        height: '100%',
    },
    rightToolbar: {
        height: '100%',
    },
    userName: {
        display: 'inline',
        paddingRight: theme.spacing.unit * 4,
        color: theme.palette.primary.contrastText
    },
});


class MainNavBar extends React.Component {
    toggleThemeQuery = gql`
        mutation toggleTheme($theme: String!) {
          toggleTheme(theme: $theme) @client
        }`;

    render() {
        const {classes} = this.props;
        return <AppBar position="fixed" color="primary" className={classes.appBar}>
            <Toolbar variant="dense" className={this.props.classes.toolbar}>
                <div className={classes.leftToolbar}>
                    <React.Fragment>
                        <NavLink to="/agents" className={classes.toolbarLink}>
                            Agents
                        </NavLink>
                        <NavLink to="/queues" className={classes.toolbarLink}>
                            Queues
                        </NavLink>
                        <NavLink to="/history" className={classes.toolbarLink}>
                            History
                        </NavLink>
                    </React.Fragment>
                </div>
                <div className={classes.rightToolbar}>
                    <Mutation mutation={this.toggleThemeQuery}>
                        {toggleTheme => {
                            const currentUserEmail = "test-bp@test-bp.com";
                            return (
                                <React.Fragment>
                                    {currentUserEmail &&
                                        <Typography className={classes.userName}>
                                            Hello {currentUserEmail}!
                                        </Typography>
                                    }
                                    <Tooltip title="Toggle light/dark theme">
                                        <IconButton color="inherit" onClick={toggleTheme}>
                                            <WbIncandescent/>
                                        </IconButton>
                                    </Tooltip>
                                </React.Fragment>
                            );
                        }}
                    </Mutation>
                </div>
            </Toolbar>
        </AppBar>
    };
}

MainNavBar.propTypes = {
    classes: PropTypes.object.isRequired,
};

export default withStyles(styles)(MainNavBar);
