import React from 'react';
import PropTypes from 'prop-types';

import {withStyles} from '@material-ui/core/styles';
import Grid from '@material-ui/core/Grid';

import Select from 'react-select';
import {Query, Mutation} from 'react-apollo';
import gql from 'graphql-tag';

import selectComponents, {selectStyles} from './autocompleteSelect';
import Progress from './progress';
import Error from './error';

class QueuesControls extends React.Component {
    setQueuesQuery = gql`
        mutation setQueues($queues: [String]!) {
          setQueues(queues: $queues) @client
        }
    `;

    queuesQuery = gql`
        query {
          queue {
            id
            name
            purecloud_id
            balkan_id
          }
          selectedQueues @client
        }
    `;

    parseQueues(response) {
        return response.queue.map(x => ({
            value: x.id,
            label: x.name,
        }));
    }

    parseSelectedQueues(response) {
        return response.selectedQueues.map(x => ({
            value: x.id,
            label: x.label,
        }));
    }

    render() {
        const {classes} = this.props;

        return (
            <div className={classes.queuesControlWrapper}>
                <form className={classes.root} autoComplete='on'>
                    <Grid container spacing={16}>
                        <Grid item xs={12} style={{position: 'relative'}}>
                            <Query query={this.queuesQuery}>
                                {({loading, error, data}) => {
                                    if (loading) return <Progress/>;
                                    if (error) return <Error msg={'Failed to load queues.'} />;

                                    return (
                                        <Mutation mutation={this.setQueuesQuery} ignoreResults={true}>
                                            {setQueues => (
                                                <Select
                                                    isMulti
                                                    onChange={x => {
                                                        setQueues({variables: {queues: x}});
                                                    }}
                                                    options={this.parseQueues(data)}
                                                    value={this.parseSelectedQueues(data)}
                                                    classes={classes}
                                                    components={selectComponents}
                                                    textFieldProps={{
                                                        label: 'Queues',
                                                        InputLabelProps: {
                                                            shrink: true,
                                                        },
                                                    }}
                                                    styles={selectStyles}
                                                />
                                            )}
                                        </Mutation>
                                    )
                                }}
                            </Query>
                        </Grid>
                    </Grid>
                </form>
            </div>
        );
    }
}

QueuesControls.propTypes = {
    classes: PropTypes.object.isRequired
};

export default withStyles(selectStyles)(QueuesControls);