import React from 'react';
import {Query, withApollo} from 'react-apollo';
import {withStyles} from '@material-ui/core/styles';
import PropTypes from 'prop-types';
import gql from 'graphql-tag';

import {IconButton, Tooltip} from '@material-ui/core';
import GroupAddIcon from '@material-ui/icons/GroupAdd';

import {ApplyChangesConfirmation} from './tableTools';
import SingleAgentDialog from './singleAgentDialog';
import {selectStyles} from './autocompleteSelect';
import Progress from './progress';
import Error from './error';


const defaultToolbarStyles = (theme) => ({
    dialogActions: {
        margin: theme.spacing.unit * 3,
        marginTop: theme.spacing.unit,
        marginBottom: theme.spacing.unit * 2,
    },
    iconButton: {
        '&:hover svg': {
            color: theme.palette.primary.main,
        }
    },
    selectWrapper: {
        minHeight: 320,
    },
});

class QueuesTableToolbar extends React.Component {

    render() {
        const {client, classes, onApplyChanges} = this.props;
        return (
            <React.Fragment>
                <AddAgentToQueue classes={classes} client={client}/>
                <ApplyChangesConfirmation
                    classes={classes}
                    client={client}
                    cacheName={'updatedQueuesTableQueues'}
                    onApplyChanges={onApplyChanges}
                />
            </React.Fragment>
        )
    }
}

QueuesTableToolbar.propTypes = {
    classes: PropTypes.object.isRequired,
    client: PropTypes.object.isRequired,
    onApplyChanges: PropTypes.func,
};

export default withApollo(withStyles((theme) => ({
    ...selectStyles(theme),
    ...defaultToolbarStyles(theme),
}), {name: 'QueuesTableToolbar', withTheme: true})(QueuesTableToolbar));


export class AddAgentToQueue extends React.Component {
    state = {
        isOpen: false,
    };

    selectedQueuesQuery = gql`
        query {
          selectedQueues @client
        }
    `;

    handleClick = () => {
        this.setState({isOpen: true});
    };

    render() {
        const {classes, client} = this.props;

        return (
            <React.Fragment>
                <Query query={this.selectedQueuesQuery}>
                    {({loading, error, data}) => {
                        if (loading) return <Progress/>;
                        if (error) return <Error msg={'Failed to load agent counts'}/>;
                        const selectedQueues = data.selectedQueues.map(x => {
                            return {value: x.id, label: x.label}
                        });
                        return(
                            <SingleAgentDialog
                                title={'Add Agents To Queue'}
                                isOpen={this.state.isOpen}
                                classes={classes}
                                selectedQueues={selectedQueues}
                                onApplyChanges={() => {
                                    this.setState({isOpen: false});
                                }}
                                client={client}
                            />);
                    }}
                </Query>
                <Tooltip title="Add Agents">
                    <IconButton className={classes.iconButton} onClick={this.handleClick}>
                        <GroupAddIcon/>
                    </IconButton>
                </Tooltip>
            </React.Fragment>
        );
    }
}

AddAgentToQueue.propTypes = {
    classes: PropTypes.object.isRequired,
    client: PropTypes.object.isRequired,
};
