import React from 'react';
import ReactDOM from 'react-dom';
import { BrowserRouter } from 'react-router-dom';
import {ApolloProvider} from 'react-apollo';
import {ApolloClient} from 'apollo-boost';
import {ApolloLink} from 'apollo-link';
import {onError} from 'apollo-link-error';
import {createHttpLink} from 'apollo-link-http';
import {InMemoryCache} from 'apollo-cache-inmemory';

import './index.css';
import App from './App';
import * as serviceWorker from './serviceWorker';
import {resolvers, defaults} from './resolvers';


const cache = new InMemoryCache();
const httpLink = createHttpLink({
    // uri: window.ENV.REACT_APP_GRAPHQL_URL || '',
    uri: "http://localhost:8080/v1alpha1/graphql",
});

const errorLink = onError(({ graphQLErrors, networkError }) => {
    console.log('errr', networkError, graphQLErrors);
});

const client = new ApolloClient({
    link: ApolloLink.from([errorLink, httpLink]),
    cache: cache,
    resolvers: resolvers,
});

cache.writeData({data: defaults});

ReactDOM.render(
    <ApolloProvider client={client}>
        <BrowserRouter>
            <App/>
        </BrowserRouter>
    </ApolloProvider>,
    document.getElementById('root'));

// If you want your app to work offline and load faster, you can change
// unregister() to register() below. Note this comes with some pitfalls.
// Learn more about service workers: https://bit.ly/CRA-PWA
serviceWorker.unregister();
