import gql from 'graphql-tag';
import {cloneDeep} from 'lodash';
import moment from 'moment';

export const defaults = {
    selectedTheme: 'dark',
    selectedQueues: [],
    selectedQueueSources: [],
    selectedStartDate: moment(new Date()).local().valueOf(),
    selectedEndDate: moment(new Date()).add(12, 'hours').local().valueOf(),
    selectedChannels: [],
    selectedTiers: [],
    selectedSites: [],
    selectedTeams: [],
    isOnShift: true,
    updatedAgentsTableQueues: {
        __typename: 'updatedAgentsTableQueues',
        agents: [],
    },
    updatedQueuesTableQueues: {
        __typename: 'updatedQueuesTableQueues',
        agents: [],
    },
    agentsTableColumnsOptions: [
        {
            name: 'first_name',
            display: false,
            __typename: 'agentsTableColumnOption',
        },
        {
            name: 'last_name',
            display: false,
            __typename: 'agentsTableColumnOption',
        },
        {
            name: 'email',
            display: true,
            __typename: 'agentsTableColumnOption',
        },
        {
            name: 'channel',
            display: true,
            __typename: 'agentsTableColumnOption',
        },
        {
            name: 'position',
            display: false,
            __typename: 'agentsTableColumnOption',
        },
        {
            name: 'position_abbr',
            display: true,
            __typename: 'agentsTableColumnOption',
        },
        {
            name: 'team',
            display: false,
            __typename: 'agentsTableColumnOption',
        },
        {
            name: 'tier',
            display: false,
            __typename: 'agentsTableColumnOption',
        },
        {
            name: 'site',
            display: true,
            __typename: 'agentsTableColumnOption',
        },
        {
            name: 'team_manager',
            display: false,
            __typename: 'agentsTableColumnOption',
        },
        {
            name: 'active_queues',
            display: true,
            __typename: 'agentsTableColumnOption',
        },
        {
            name: 'assigned_queues',
            display: false,
            __typename: 'agentsTableColumnOption',
        },
        {
            name: 'shift_name',
            display: false,
            __typename: 'agentsTableColumnOption',
        },
        {
            name: 'shift_start_time_utc',
            display: true,
            __typename: 'agentsTableColumnOption',
        },
        {
            name: 'shift_end_time_utc',
            display: true,
            __typename: 'agentsTableColumnOption',
        },
    ],
    queuesTableColumnsOptions: [
        {
            name: 'first_name',
            display: false,
            __typename: 'queuesTableColumnOption',
        },
        {
            name: 'last_name',
            display: false,
            __typename: 'queuesTableColumnOption',
        },
        {
            name: 'email',
            display: true,
            __typename: 'queuesTableColumnOption',
        },
        {
            name: 'channel',
            display: false,
            __typename: 'queuesTableColumnOption',
        },
        {
            name: 'position',
            display: false,
            __typename: 'queuesTableColumnOption',
        },
        {
            name: 'position_abbr',
            display: true,
            __typename: 'queuesTableColumnOption',
        },
        {
            name: 'team',
            display: true,
            __typename: 'queuesTableColumnOption',
        },
        {
            name: 'tier',
            display: false,
            __typename: 'queuesTableColumnOption',
        },
        {
            name: 'site',
            display: true,
            __typename: 'queuesTableColumnOption',
        },
        {
            name: 'team_manager',
            display: false,
            __typename: 'queuesTableColumnOption',
        },
        {
            name: 'active_queues',
            display: true,
            __typename: 'queuesTableColumnOption',
        },
        {
            name: 'shift_name',
            display: false,
            __typename: 'queuesTableColumnOption',
        },
        {
            name: 'shift_start_time_utc',
            display: true,
            __typename: 'queuesTableColumnOption',
        },
        {
            name: 'shift_end_time_utc',
            display: true,
            __typename: 'queuesTableColumnOption',
        },
        {
            name: 'assigned_queues',
            display: false,
            __typename: 'queuesTableColumnOption',
        },
    ],
};

export const resolvers = {
    Mutation: {
        setQueues: (_, {queues}, {cache}) => {
            let updateQueues = cloneDeep(queues);
            updateQueues.map(x => {
                x['id'] = x['value'];
                delete x['value'];
                return x;
            });

            cache.writeQuery({
                query: gql`query { selectedQueues @client }`,
                data: {selectedQueues: updateQueues}
            });
            return updateQueues;
        },
        setSelectedQueueSources: (_, {sources}, {cache}) => {
            cache.writeQuery({
                query: gql`query { selectedQueueSources @client }`,
                data: {selectedQueueSources: sources}
            });
            return sources;
        },
        setAgentControls: (_, data, {cache}) => {
            const query =  gql`
                query {
                  selectedStartDate @client
                  selectedEndDate @client
                  selectedChannels @client
                  selectedTiers @client
                  selectedSites @client
                  selectedTeams @client
                }
            `;

            let newData = {};
            if (data.startDate) {
                newData['selectedStartDate'] = data.startDate;
            }
            if (data.endDate) {
                newData['selectedEndDate'] = data.endDate;
            }
            if (data.channels) {
                newData['selectedChannels'] = data.channels;
            }
            if (data.tiers) {
                newData['selectedTiers'] = data.tiers;
            }
            if (data.teams) {
                newData['selectedTeams'] = data.teams;
            }
            if (data.sites) {
                newData['selectedSites'] = data.sites;
            }
            cache.writeQuery({query: query, data: newData});
        },
        toggleTheme: (_, {theme}, {cache}) => {
            const query =  gql`query { selectedTheme @client }`;
            const data = cache.readQuery({query: query});
            const selectedTheme = data.selectedTheme === 'dark' ? 'light' : 'dark';

            cache.writeQuery({
                query: query,
                data: {selectedTheme: selectedTheme},
            });
        },
    },
};