--
-- PostgreSQL database dump
--

-- Dumped from database version 11.1 (Debian 11.1-3.pgdg90+1)
-- Dumped by pg_dump version 11.2

SET statement_timeout = 0;
SET lock_timeout = 0;
SET idle_in_transaction_session_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SELECT pg_catalog.set_config('search_path', '', false);
SET check_function_bodies = false;
SET client_min_messages = warning;
SET row_security = off;

--
-- Name: hdb_catalog; Type: SCHEMA; Schema: -; Owner: -
--

CREATE SCHEMA hdb_catalog;


--
-- Name: hdb_views; Type: SCHEMA; Schema: -; Owner: -
--

CREATE SCHEMA hdb_views;


--
-- Name: public_old; Type: SCHEMA; Schema: -; Owner: -
--

CREATE SCHEMA public_old;


--
-- Name: SCHEMA public_old; Type: COMMENT; Schema: -; Owner: -
--

COMMENT ON SCHEMA public_old IS 'standard public schema';


--
-- Name: pgcrypto; Type: EXTENSION; Schema: -; Owner: -
--

CREATE EXTENSION IF NOT EXISTS pgcrypto WITH SCHEMA public_old;


--
-- Name: EXTENSION pgcrypto; Type: COMMENT; Schema: -; Owner: -
--

COMMENT ON EXTENSION pgcrypto IS 'cryptographic functions';


--
-- Name: hdb_schema_update_event_notifier(); Type: FUNCTION; Schema: hdb_catalog; Owner: -
--

CREATE FUNCTION hdb_catalog.hdb_schema_update_event_notifier() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
  DECLARE
    instance_id uuid;
    occurred_at timestamptz;
    curr_rec record;
  BEGIN
    instance_id = NEW.instance_id;
    occurred_at = NEW.occurred_at;
    PERFORM pg_notify('hasura_schema_update', json_build_object(
      'instance_id', instance_id,
      'occurred_at', occurred_at
      )::text);
    RETURN curr_rec;
  END;
$$;


--
-- Name: hdb_table_oid_check(); Type: FUNCTION; Schema: hdb_catalog; Owner: -
--

CREATE FUNCTION hdb_catalog.hdb_table_oid_check() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
  BEGIN
    IF (EXISTS (SELECT 1 FROM information_schema.tables st WHERE st.table_schema = NEW.table_schema AND st.table_name = NEW.table_name)) THEN
      return NEW;
    ELSE
      RAISE foreign_key_violation using message = 'table_schema, table_name not in information_schema.tables';
      return NULL;
    END IF;
  END;
$$;


--
-- Name: inject_table_defaults(text, text, text, text); Type: FUNCTION; Schema: hdb_catalog; Owner: -
--

CREATE FUNCTION hdb_catalog.inject_table_defaults(view_schema text, view_name text, tab_schema text, tab_name text) RETURNS void
    LANGUAGE plpgsql
    AS $$
    DECLARE
        r RECORD;
    BEGIN
      FOR r IN SELECT column_name, column_default FROM information_schema.columns WHERE table_schema = tab_schema AND table_name = tab_name AND column_default IS NOT NULL LOOP
          EXECUTE format('ALTER VIEW %I.%I ALTER COLUMN %I SET DEFAULT %s;', view_schema, view_name, r.column_name, r.column_default);
      END LOOP;
    END;
$$;


--
-- Name: update_log_after_agent_shift_queue_action(); Type: FUNCTION; Schema: public; Owner: -
--

CREATE FUNCTION public.update_log_after_agent_shift_queue_action() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
    IF (TG_OP = 'INSERT') THEN
        IF (NEW.source != 'agatha') THEN
            RETURN NEW;
        END IF;
        INSERT INTO log(action, queue_id, agent_id, author, shift_id, created_on_utc, start_time_utc, end_time_utc)
        SELECT TG_OP, NEW.queue_id, NEW.agent_id, NEW.author, NEW.shift_id, NEW.updated_on_utc, NEW.start_time_utc, NEW.end_time_utc;
        RETURN NEW;
    ELSIF (TG_OP = 'UPDATE') THEN
        IF (NEW.source != 'agatha') THEN
            RETURN NEW;
        END IF;

        IF (NEW.is_active IS FALSE) THEN
            INSERT INTO log(action, queue_id, agent_id, author, shift_id, created_on_utc, start_time_utc, end_time_utc,
                        author_old, shift_id_old, created_on_utc_old, start_time_utc_old, end_time_utc_old, source_old)
            SELECT 'DELETE', NEW.queue_id, NEW.agent_id, NEW.author, NEW.shift_id, NEW.updated_on_utc, NEW.start_time_utc, NEW.end_time_utc,
                   OLD.author, OLD.shift_id, OLD.updated_on_utc, OLD.start_time_utc, OLD.end_time_utc, OLD.source;
            DELETE FROM agent_shift_queue WHERE agent_id=NEW.agent_id AND queue_id=NEW.queue_id;
            RETURN NULL;
        ELSIF (OLD.shift_id != NEW.shift_id) THEN
            INSERT INTO log(action, queue_id, agent_id, author, shift_id, created_on_utc, start_time_utc, end_time_utc,
                        author_old, shift_id_old, created_on_utc_old, start_time_utc_old, end_time_utc_old, source_old)
            SELECT TG_OP, NEW.queue_id, NEW.agent_id, NEW.author, NEW.shift_id, NEW.updated_on_utc, NEW.start_time_utc, NEW.end_time_utc,
                   OLD.author, OLD.shift_id, OLD.updated_on_utc, OLD.start_time_utc, OLD.end_time_utc, OLD.source;
            RETURN NEW;
        END IF;
    END IF;
    RETURN NULL;
END;
$$;


--
-- Name: update_log_after_agent_shift_queue_action(); Type: FUNCTION; Schema: public_old; Owner: -
--

CREATE FUNCTION public_old.update_log_after_agent_shift_queue_action() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
    IF (TG_OP = 'DELETE') THEN
      INSERT INTO log SELECT TG_OP, OLD.queue_id, OLD.agent_id, OLD.author, OLD.shift_id, NOW(), OLD.start_time_utc, OLD.end_time_utc;
      RETURN OLD;
    ELSIF (TG_OP = 'UPDATE' OR TG_OP = 'INSERT') THEN
      IF (NEW.source != 'agatha') THEN
        RETURN NEW;
      END IF;
      INSERT INTO log SELECT TG_OP, NEW.queue_id, NEW.agent_id, NEW.author, NEW.shift_id, NOW(), NEW.start_time_utc, NEW.end_time_utc;
      RETURN NEW;
    END IF;
    RETURN NULL;
  END;
$$;


SET default_tablespace = '';

SET default_with_oids = false;

--
-- Name: event_invocation_logs; Type: TABLE; Schema: hdb_catalog; Owner: -
--

CREATE TABLE hdb_catalog.event_invocation_logs (
    id text DEFAULT public_old.gen_random_uuid() NOT NULL,
    event_id text,
    status integer,
    request json,
    response json,
    created_at timestamp without time zone DEFAULT now()
);


--
-- Name: event_log; Type: TABLE; Schema: hdb_catalog; Owner: -
--

CREATE TABLE hdb_catalog.event_log (
    id text DEFAULT public_old.gen_random_uuid() NOT NULL,
    schema_name text NOT NULL,
    table_name text NOT NULL,
    trigger_name text NOT NULL,
    payload jsonb NOT NULL,
    delivered boolean DEFAULT false NOT NULL,
    error boolean DEFAULT false NOT NULL,
    tries integer DEFAULT 0 NOT NULL,
    created_at timestamp without time zone DEFAULT now(),
    locked boolean DEFAULT false NOT NULL,
    next_retry_at timestamp without time zone
);


--
-- Name: event_triggers; Type: TABLE; Schema: hdb_catalog; Owner: -
--

CREATE TABLE hdb_catalog.event_triggers (
    name text NOT NULL,
    type text NOT NULL,
    schema_name text NOT NULL,
    table_name text NOT NULL,
    configuration json,
    comment text
);


--
-- Name: hdb_check_constraint; Type: VIEW; Schema: hdb_catalog; Owner: -
--

CREATE VIEW hdb_catalog.hdb_check_constraint AS
 SELECT (n.nspname)::text AS table_schema,
    (ct.relname)::text AS table_name,
    (r.conname)::text AS constraint_name,
    pg_get_constraintdef(r.oid, true) AS "check"
   FROM ((pg_constraint r
     JOIN pg_class ct ON ((r.conrelid = ct.oid)))
     JOIN pg_namespace n ON ((ct.relnamespace = n.oid)))
  WHERE (r.contype = 'c'::"char");


--
-- Name: hdb_foreign_key_constraint; Type: VIEW; Schema: hdb_catalog; Owner: -
--

CREATE VIEW hdb_catalog.hdb_foreign_key_constraint AS
 SELECT (q.table_schema)::text AS table_schema,
    (q.table_name)::text AS table_name,
    (q.constraint_name)::text AS constraint_name,
    (min(q.constraint_oid))::integer AS constraint_oid,
    min((q.ref_table_table_schema)::text) AS ref_table_table_schema,
    min((q.ref_table)::text) AS ref_table,
    json_object_agg(ac.attname, afc.attname) AS column_mapping,
    min((q.confupdtype)::text) AS on_update,
    min((q.confdeltype)::text) AS on_delete
   FROM ((( SELECT ctn.nspname AS table_schema,
            ct.relname AS table_name,
            r.conrelid AS table_id,
            r.conname AS constraint_name,
            r.oid AS constraint_oid,
            cftn.nspname AS ref_table_table_schema,
            cft.relname AS ref_table,
            r.confrelid AS ref_table_id,
            r.confupdtype,
            r.confdeltype,
            unnest(r.conkey) AS column_id,
            unnest(r.confkey) AS ref_column_id
           FROM ((((pg_constraint r
             JOIN pg_class ct ON ((r.conrelid = ct.oid)))
             JOIN pg_namespace ctn ON ((ct.relnamespace = ctn.oid)))
             JOIN pg_class cft ON ((r.confrelid = cft.oid)))
             JOIN pg_namespace cftn ON ((cft.relnamespace = cftn.oid)))
          WHERE (r.contype = 'f'::"char")) q
     JOIN pg_attribute ac ON (((q.column_id = ac.attnum) AND (q.table_id = ac.attrelid))))
     JOIN pg_attribute afc ON (((q.ref_column_id = afc.attnum) AND (q.ref_table_id = afc.attrelid))))
  GROUP BY q.table_schema, q.table_name, q.constraint_name;


--
-- Name: hdb_function; Type: TABLE; Schema: hdb_catalog; Owner: -
--

CREATE TABLE hdb_catalog.hdb_function (
    function_schema text NOT NULL,
    function_name text NOT NULL,
    is_system_defined boolean DEFAULT false
);


--
-- Name: hdb_function_agg; Type: VIEW; Schema: hdb_catalog; Owner: -
--

CREATE VIEW hdb_catalog.hdb_function_agg AS
 SELECT (p.proname)::text AS function_name,
    (pn.nspname)::text AS function_schema,
        CASE
            WHEN (p.provariadic = (0)::oid) THEN false
            ELSE true
        END AS has_variadic,
        CASE
            WHEN ((p.provolatile)::text = ('i'::character(1))::text) THEN 'IMMUTABLE'::text
            WHEN ((p.provolatile)::text = ('s'::character(1))::text) THEN 'STABLE'::text
            WHEN ((p.provolatile)::text = ('v'::character(1))::text) THEN 'VOLATILE'::text
            ELSE NULL::text
        END AS function_type,
    pg_get_functiondef(p.oid) AS function_definition,
    (rtn.nspname)::text AS return_type_schema,
    (rt.typname)::text AS return_type_name,
        CASE
            WHEN ((rt.typtype)::text = ('b'::character(1))::text) THEN 'BASE'::text
            WHEN ((rt.typtype)::text = ('c'::character(1))::text) THEN 'COMPOSITE'::text
            WHEN ((rt.typtype)::text = ('d'::character(1))::text) THEN 'DOMAIN'::text
            WHEN ((rt.typtype)::text = ('e'::character(1))::text) THEN 'ENUM'::text
            WHEN ((rt.typtype)::text = ('r'::character(1))::text) THEN 'RANGE'::text
            WHEN ((rt.typtype)::text = ('p'::character(1))::text) THEN 'PSUEDO'::text
            ELSE NULL::text
        END AS return_type_type,
    p.proretset AS returns_set,
    ( SELECT COALESCE(json_agg(q.type_name), '[]'::json) AS "coalesce"
           FROM ( SELECT pt.typname AS type_name,
                    pat.ordinality
                   FROM (unnest(COALESCE(p.proallargtypes, (p.proargtypes)::oid[])) WITH ORDINALITY pat(oid, ordinality)
                     LEFT JOIN pg_type pt ON ((pt.oid = pat.oid)))
                  ORDER BY pat.ordinality) q) AS input_arg_types,
    to_json(COALESCE(p.proargnames, ARRAY[]::text[])) AS input_arg_names
   FROM (((pg_proc p
     JOIN pg_namespace pn ON ((pn.oid = p.pronamespace)))
     JOIN pg_type rt ON ((rt.oid = p.prorettype)))
     JOIN pg_namespace rtn ON ((rtn.oid = rt.typnamespace)))
  WHERE (((pn.nspname)::text !~~ 'pg_%'::text) AND ((pn.nspname)::text <> ALL (ARRAY['information_schema'::text, 'hdb_catalog'::text, 'hdb_views'::text])) AND (NOT (EXISTS ( SELECT 1
           FROM pg_aggregate
          WHERE ((pg_aggregate.aggfnoid)::oid = p.oid)))));


--
-- Name: hdb_permission; Type: TABLE; Schema: hdb_catalog; Owner: -
--

CREATE TABLE hdb_catalog.hdb_permission (
    table_schema text NOT NULL,
    table_name text NOT NULL,
    role_name text NOT NULL,
    perm_type text NOT NULL,
    perm_def jsonb NOT NULL,
    comment text,
    is_system_defined boolean DEFAULT false,
    CONSTRAINT hdb_permission_perm_type_check CHECK ((perm_type = ANY (ARRAY['insert'::text, 'select'::text, 'update'::text, 'delete'::text])))
);


--
-- Name: hdb_permission_agg; Type: VIEW; Schema: hdb_catalog; Owner: -
--

CREATE VIEW hdb_catalog.hdb_permission_agg AS
 SELECT hdb_permission.table_schema,
    hdb_permission.table_name,
    hdb_permission.role_name,
    json_object_agg(hdb_permission.perm_type, hdb_permission.perm_def) AS permissions
   FROM hdb_catalog.hdb_permission
  GROUP BY hdb_permission.table_schema, hdb_permission.table_name, hdb_permission.role_name;


--
-- Name: hdb_primary_key; Type: VIEW; Schema: hdb_catalog; Owner: -
--

CREATE VIEW hdb_catalog.hdb_primary_key AS
 SELECT tc.table_schema,
    tc.table_name,
    tc.constraint_name,
    json_agg(constraint_column_usage.column_name) AS columns
   FROM (information_schema.table_constraints tc
     JOIN ( SELECT x.tblschema AS table_schema,
            x.tblname AS table_name,
            x.colname AS column_name,
            x.cstrname AS constraint_name
           FROM ( SELECT DISTINCT nr.nspname,
                    r.relname,
                    a.attname,
                    c.conname
                   FROM pg_namespace nr,
                    pg_class r,
                    pg_attribute a,
                    pg_depend d,
                    pg_namespace nc,
                    pg_constraint c
                  WHERE ((nr.oid = r.relnamespace) AND (r.oid = a.attrelid) AND (d.refclassid = ('pg_class'::regclass)::oid) AND (d.refobjid = r.oid) AND (d.refobjsubid = a.attnum) AND (d.classid = ('pg_constraint'::regclass)::oid) AND (d.objid = c.oid) AND (c.connamespace = nc.oid) AND (c.contype = 'c'::"char") AND (r.relkind = ANY (ARRAY['r'::"char", 'p'::"char"])) AND (NOT a.attisdropped))
                UNION ALL
                 SELECT nr.nspname,
                    r.relname,
                    a.attname,
                    c.conname
                   FROM pg_namespace nr,
                    pg_class r,
                    pg_attribute a,
                    pg_namespace nc,
                    pg_constraint c
                  WHERE ((nr.oid = r.relnamespace) AND (r.oid = a.attrelid) AND (nc.oid = c.connamespace) AND (r.oid =
                        CASE c.contype
                            WHEN 'f'::"char" THEN c.confrelid
                            ELSE c.conrelid
                        END) AND (a.attnum = ANY (
                        CASE c.contype
                            WHEN 'f'::"char" THEN c.confkey
                            ELSE c.conkey
                        END)) AND (NOT a.attisdropped) AND (c.contype = ANY (ARRAY['p'::"char", 'u'::"char", 'f'::"char"])) AND (r.relkind = ANY (ARRAY['r'::"char", 'p'::"char"])))) x(tblschema, tblname, colname, cstrname)) constraint_column_usage ON ((((tc.constraint_name)::text = (constraint_column_usage.constraint_name)::text) AND ((tc.table_schema)::text = (constraint_column_usage.table_schema)::text) AND ((tc.table_name)::text = (constraint_column_usage.table_name)::text))))
  WHERE ((tc.constraint_type)::text = 'PRIMARY KEY'::text)
  GROUP BY tc.table_schema, tc.table_name, tc.constraint_name;


--
-- Name: hdb_query_template; Type: TABLE; Schema: hdb_catalog; Owner: -
--

CREATE TABLE hdb_catalog.hdb_query_template (
    template_name text NOT NULL,
    template_defn jsonb NOT NULL,
    comment text,
    is_system_defined boolean DEFAULT false
);


--
-- Name: hdb_relationship; Type: TABLE; Schema: hdb_catalog; Owner: -
--

CREATE TABLE hdb_catalog.hdb_relationship (
    table_schema text NOT NULL,
    table_name text NOT NULL,
    rel_name text NOT NULL,
    rel_type text,
    rel_def jsonb NOT NULL,
    comment text,
    is_system_defined boolean DEFAULT false,
    CONSTRAINT hdb_relationship_rel_type_check CHECK ((rel_type = ANY (ARRAY['object'::text, 'array'::text])))
);


--
-- Name: hdb_schema_update_event; Type: TABLE; Schema: hdb_catalog; Owner: -
--

CREATE TABLE hdb_catalog.hdb_schema_update_event (
    id bigint NOT NULL,
    instance_id uuid NOT NULL,
    occurred_at timestamp with time zone DEFAULT now() NOT NULL
);


--
-- Name: hdb_schema_update_event_id_seq; Type: SEQUENCE; Schema: hdb_catalog; Owner: -
--

CREATE SEQUENCE hdb_catalog.hdb_schema_update_event_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: hdb_schema_update_event_id_seq; Type: SEQUENCE OWNED BY; Schema: hdb_catalog; Owner: -
--

ALTER SEQUENCE hdb_catalog.hdb_schema_update_event_id_seq OWNED BY hdb_catalog.hdb_schema_update_event.id;


--
-- Name: hdb_table; Type: TABLE; Schema: hdb_catalog; Owner: -
--

CREATE TABLE hdb_catalog.hdb_table (
    table_schema text NOT NULL,
    table_name text NOT NULL,
    is_system_defined boolean DEFAULT false
);


--
-- Name: hdb_unique_constraint; Type: VIEW; Schema: hdb_catalog; Owner: -
--

CREATE VIEW hdb_catalog.hdb_unique_constraint AS
 SELECT tc.table_name,
    tc.constraint_schema AS table_schema,
    tc.constraint_name,
    json_agg(kcu.column_name) AS columns
   FROM (information_schema.table_constraints tc
     JOIN information_schema.key_column_usage kcu USING (constraint_schema, constraint_name))
  WHERE ((tc.constraint_type)::text = 'UNIQUE'::text)
  GROUP BY tc.table_name, tc.constraint_schema, tc.constraint_name;


--
-- Name: hdb_version; Type: TABLE; Schema: hdb_catalog; Owner: -
--

CREATE TABLE hdb_catalog.hdb_version (
    hasura_uuid uuid DEFAULT public_old.gen_random_uuid() NOT NULL,
    version text NOT NULL,
    upgraded_on timestamp with time zone NOT NULL,
    cli_state jsonb DEFAULT '{}'::jsonb NOT NULL,
    console_state jsonb DEFAULT '{}'::jsonb NOT NULL
);


--
-- Name: remote_schemas; Type: TABLE; Schema: hdb_catalog; Owner: -
--

CREATE TABLE hdb_catalog.remote_schemas (
    id bigint NOT NULL,
    name text,
    definition json,
    comment text
);


--
-- Name: remote_schemas_id_seq; Type: SEQUENCE; Schema: hdb_catalog; Owner: -
--

CREATE SEQUENCE hdb_catalog.remote_schemas_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: remote_schemas_id_seq; Type: SEQUENCE OWNED BY; Schema: hdb_catalog; Owner: -
--

ALTER SEQUENCE hdb_catalog.remote_schemas_id_seq OWNED BY hdb_catalog.remote_schemas.id;


--
-- Name: agent; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.agent (
    id bigint NOT NULL,
    first_name text NOT NULL,
    last_name text NOT NULL,
    email text NOT NULL,
    staff text,
    active boolean,
    team_manager bigint,
    site text,
    "position" text,
    channel text,
    tier text,
    team text,
    purecloud_id text,
    position_abbr text
);


--
-- Name: agent_assigned_queues; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.agent_assigned_queues (
    agent_id bigint,
    queue_id bigint,
    id bigint NOT NULL
);


--
-- Name: agent_assigned_queues_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.agent_assigned_queues_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: agent_assigned_queues_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.agent_assigned_queues_id_seq OWNED BY public.agent_assigned_queues.id;


--
-- Name: agent_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.agent_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: agent_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.agent_id_seq OWNED BY public.agent.id;


--
-- Name: agent_off_shift; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.agent_off_shift (
    id bigint NOT NULL,
    shift_id bigint,
    start_time_utc timestamp without time zone,
    end_time_utc timestamp without time zone,
    agent_id bigint,
    off_reason text
);


--
-- Name: agent_off_shift_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.agent_off_shift_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: agent_off_shift_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.agent_off_shift_id_seq OWNED BY public.agent_off_shift.id;


--
-- Name: agent_on_shift; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.agent_on_shift (
    id bigint NOT NULL,
    shift_id bigint,
    start_time_utc timestamp without time zone,
    end_time_utc timestamp without time zone,
    agent_id bigint
);


--
-- Name: agent_on_shift_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.agent_on_shift_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: agent_on_shift_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.agent_on_shift_id_seq OWNED BY public.agent_on_shift.id;


--
-- Name: agent_shift_queue; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.agent_shift_queue (
    shift_id bigint,
    updated_on_utc timestamp without time zone DEFAULT now(),
    agent_id bigint,
    queue_id bigint,
    start_time_utc timestamp without time zone,
    end_time_utc timestamp without time zone,
    source text DEFAULT 'agatha'::character varying,
    author text,
    is_active boolean DEFAULT true NOT NULL,
    id bigint NOT NULL
);


--
-- Name: agent_shift_queue_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.agent_shift_queue_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: agent_shift_queue_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.agent_shift_queue_id_seq OWNED BY public.agent_shift_queue.id;


--
-- Name: log; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.log (
    action text,
    queue_id bigint,
    agent_id bigint,
    author text,
    shift_id bigint,
    created_on_utc timestamp without time zone,
    start_time_utc timestamp without time zone,
    end_time_utc timestamp without time zone,
    author_old text,
    shift_id_old bigint,
    created_on_utc_old timestamp without time zone,
    start_time_utc_old timestamp without time zone,
    end_time_utc_old timestamp without time zone,
    source_old text
);


--
-- Name: queue; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.queue (
    id bigint NOT NULL,
    name text NOT NULL,
    purecloud_id text,
    balkan_id bigint,
    group_name text
);


--
-- Name: queue_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.queue_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: queue_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.queue_id_seq OWNED BY public.queue.id;


--
-- Name: shift; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.shift (
    id bigint NOT NULL,
    name text NOT NULL,
    description text,
    length integer,
    minspacing integer,
    delete_on_utc timestamp without time zone,
    created_on_utc timestamp without time zone,
    created_by text,
    modified_on_utc timestamp without time zone,
    modified_by text,
    maxspacing integer
);


--
-- Name: shift_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.shift_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: shift_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.shift_id_seq OWNED BY public.shift.id;


--
-- Name: agent; Type: TABLE; Schema: public_old; Owner: -
--

CREATE TABLE public_old.agent (
    id bigint NOT NULL,
    first_name text NOT NULL,
    last_name text NOT NULL,
    email text NOT NULL,
    staff text,
    active boolean,
    team_manager bigint,
    site text,
    "position" text,
    channel text,
    tier text,
    team text,
    purecloud_id text,
    position_abbr text
);


--
-- Name: agent_assigned_queues; Type: TABLE; Schema: public_old; Owner: -
--

CREATE TABLE public_old.agent_assigned_queues (
    agent_id bigint,
    queue_id bigint
);


--
-- Name: agent_id_seq; Type: SEQUENCE; Schema: public_old; Owner: -
--

CREATE SEQUENCE public_old.agent_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: agent_id_seq; Type: SEQUENCE OWNED BY; Schema: public_old; Owner: -
--

ALTER SEQUENCE public_old.agent_id_seq OWNED BY public_old.agent.id;


--
-- Name: agent_off_shift; Type: TABLE; Schema: public_old; Owner: -
--

CREATE TABLE public_old.agent_off_shift (
    id bigint NOT NULL,
    shift_id bigint,
    start_time_utc timestamp without time zone,
    end_time_utc timestamp without time zone,
    agent_id bigint,
    off_reason text
);


--
-- Name: agent_off_shift_id_seq; Type: SEQUENCE; Schema: public_old; Owner: -
--

CREATE SEQUENCE public_old.agent_off_shift_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: agent_off_shift_id_seq; Type: SEQUENCE OWNED BY; Schema: public_old; Owner: -
--

ALTER SEQUENCE public_old.agent_off_shift_id_seq OWNED BY public_old.agent_off_shift.id;


--
-- Name: agent_on_shift; Type: TABLE; Schema: public_old; Owner: -
--

CREATE TABLE public_old.agent_on_shift (
    id bigint NOT NULL,
    shift_id bigint,
    start_time_utc timestamp without time zone,
    end_time_utc timestamp without time zone,
    agent_id bigint
);


--
-- Name: agent_on_shift_id_seq; Type: SEQUENCE; Schema: public_old; Owner: -
--

CREATE SEQUENCE public_old.agent_on_shift_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: agent_on_shift_id_seq; Type: SEQUENCE OWNED BY; Schema: public_old; Owner: -
--

ALTER SEQUENCE public_old.agent_on_shift_id_seq OWNED BY public_old.agent_on_shift.id;


--
-- Name: agent_shift_queue; Type: TABLE; Schema: public_old; Owner: -
--

CREATE TABLE public_old.agent_shift_queue (
    shift_id bigint,
    updated_on_utc timestamp without time zone DEFAULT now(),
    agent_id bigint,
    queue_id bigint,
    start_time_utc timestamp without time zone,
    end_time_utc timestamp without time zone,
    source text DEFAULT 'agatha'::character varying,
    author text
);


--
-- Name: log; Type: TABLE; Schema: public_old; Owner: -
--

CREATE TABLE public_old.log (
    action text,
    queue_id bigint,
    agent_id bigint,
    author text,
    shift_id bigint,
    created_on_utc timestamp without time zone,
    start_time_utc timestamp without time zone,
    end_time_utc timestamp without time zone
);


--
-- Name: queue; Type: TABLE; Schema: public_old; Owner: -
--

CREATE TABLE public_old.queue (
    id bigint NOT NULL,
    name text NOT NULL,
    purecloud_id text,
    balkan_id bigint,
    group_name text
);


--
-- Name: queue_id_seq; Type: SEQUENCE; Schema: public_old; Owner: -
--

CREATE SEQUENCE public_old.queue_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: queue_id_seq; Type: SEQUENCE OWNED BY; Schema: public_old; Owner: -
--

ALTER SEQUENCE public_old.queue_id_seq OWNED BY public_old.queue.id;


--
-- Name: shift; Type: TABLE; Schema: public_old; Owner: -
--

CREATE TABLE public_old.shift (
    id bigint NOT NULL,
    name text NOT NULL,
    description text,
    length integer,
    minspacing integer,
    delete_on_utc timestamp without time zone,
    created_on_utc timestamp without time zone,
    created_by text,
    modified_on_utc timestamp without time zone,
    modified_by text,
    maxspacing integer
);


--
-- Name: shift_id_seq; Type: SEQUENCE; Schema: public_old; Owner: -
--

CREATE SEQUENCE public_old.shift_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: shift_id_seq; Type: SEQUENCE OWNED BY; Schema: public_old; Owner: -
--

ALTER SEQUENCE public_old.shift_id_seq OWNED BY public_old.shift.id;


--
-- Name: hdb_schema_update_event id; Type: DEFAULT; Schema: hdb_catalog; Owner: -
--

ALTER TABLE ONLY hdb_catalog.hdb_schema_update_event ALTER COLUMN id SET DEFAULT nextval('hdb_catalog.hdb_schema_update_event_id_seq'::regclass);


--
-- Name: remote_schemas id; Type: DEFAULT; Schema: hdb_catalog; Owner: -
--

ALTER TABLE ONLY hdb_catalog.remote_schemas ALTER COLUMN id SET DEFAULT nextval('hdb_catalog.remote_schemas_id_seq'::regclass);


--
-- Name: agent id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.agent ALTER COLUMN id SET DEFAULT nextval('public.agent_id_seq'::regclass);


--
-- Name: agent_assigned_queues id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.agent_assigned_queues ALTER COLUMN id SET DEFAULT nextval('public.agent_assigned_queues_id_seq'::regclass);


--
-- Name: agent_off_shift id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.agent_off_shift ALTER COLUMN id SET DEFAULT nextval('public.agent_off_shift_id_seq'::regclass);


--
-- Name: agent_on_shift id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.agent_on_shift ALTER COLUMN id SET DEFAULT nextval('public.agent_on_shift_id_seq'::regclass);


--
-- Name: agent_shift_queue id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.agent_shift_queue ALTER COLUMN id SET DEFAULT nextval('public.agent_shift_queue_id_seq'::regclass);


--
-- Name: queue id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.queue ALTER COLUMN id SET DEFAULT nextval('public.queue_id_seq'::regclass);


--
-- Name: shift id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.shift ALTER COLUMN id SET DEFAULT nextval('public.shift_id_seq'::regclass);


--
-- Name: agent id; Type: DEFAULT; Schema: public_old; Owner: -
--

ALTER TABLE ONLY public_old.agent ALTER COLUMN id SET DEFAULT nextval('public_old.agent_id_seq'::regclass);


--
-- Name: agent_off_shift id; Type: DEFAULT; Schema: public_old; Owner: -
--

ALTER TABLE ONLY public_old.agent_off_shift ALTER COLUMN id SET DEFAULT nextval('public_old.agent_off_shift_id_seq'::regclass);


--
-- Name: agent_on_shift id; Type: DEFAULT; Schema: public_old; Owner: -
--

ALTER TABLE ONLY public_old.agent_on_shift ALTER COLUMN id SET DEFAULT nextval('public_old.agent_on_shift_id_seq'::regclass);


--
-- Name: queue id; Type: DEFAULT; Schema: public_old; Owner: -
--

ALTER TABLE ONLY public_old.queue ALTER COLUMN id SET DEFAULT nextval('public_old.queue_id_seq'::regclass);


--
-- Name: shift id; Type: DEFAULT; Schema: public_old; Owner: -
--

ALTER TABLE ONLY public_old.shift ALTER COLUMN id SET DEFAULT nextval('public_old.shift_id_seq'::regclass);


--
-- Data for Name: event_invocation_logs; Type: TABLE DATA; Schema: hdb_catalog; Owner: -
--

COPY hdb_catalog.event_invocation_logs (id, event_id, status, request, response, created_at) FROM stdin;
\.


--
-- Data for Name: event_log; Type: TABLE DATA; Schema: hdb_catalog; Owner: -
--

COPY hdb_catalog.event_log (id, schema_name, table_name, trigger_name, payload, delivered, error, tries, created_at, locked, next_retry_at) FROM stdin;
\.


--
-- Data for Name: event_triggers; Type: TABLE DATA; Schema: hdb_catalog; Owner: -
--

COPY hdb_catalog.event_triggers (name, type, schema_name, table_name, configuration, comment) FROM stdin;
\.


--
-- Data for Name: hdb_function; Type: TABLE DATA; Schema: hdb_catalog; Owner: -
--

COPY hdb_catalog.hdb_function (function_schema, function_name, is_system_defined) FROM stdin;
\.


--
-- Data for Name: hdb_permission; Type: TABLE DATA; Schema: hdb_catalog; Owner: -
--

COPY hdb_catalog.hdb_permission (table_schema, table_name, role_name, perm_type, perm_def, comment, is_system_defined) FROM stdin;
\.


--
-- Data for Name: hdb_query_template; Type: TABLE DATA; Schema: hdb_catalog; Owner: -
--

COPY hdb_catalog.hdb_query_template (template_name, template_defn, comment, is_system_defined) FROM stdin;
\.


--
-- Data for Name: hdb_relationship; Type: TABLE DATA; Schema: hdb_catalog; Owner: -
--

COPY hdb_catalog.hdb_relationship (table_schema, table_name, rel_name, rel_type, rel_def, comment, is_system_defined) FROM stdin;
hdb_catalog	hdb_table	detail	object	{"manual_configuration": {"remote_table": {"name": "tables", "schema": "information_schema"}, "column_mapping": {"table_name": "table_name", "table_schema": "table_schema"}}}	\N	t
hdb_catalog	hdb_table	primary_key	object	{"manual_configuration": {"remote_table": {"name": "hdb_primary_key", "schema": "hdb_catalog"}, "column_mapping": {"table_name": "table_name", "table_schema": "table_schema"}}}	\N	t
hdb_catalog	hdb_table	columns	array	{"manual_configuration": {"remote_table": {"name": "columns", "schema": "information_schema"}, "column_mapping": {"table_name": "table_name", "table_schema": "table_schema"}}}	\N	t
hdb_catalog	hdb_table	foreign_key_constraints	array	{"manual_configuration": {"remote_table": {"name": "hdb_foreign_key_constraint", "schema": "hdb_catalog"}, "column_mapping": {"table_name": "table_name", "table_schema": "table_schema"}}}	\N	t
hdb_catalog	hdb_table	relationships	array	{"manual_configuration": {"remote_table": {"name": "hdb_relationship", "schema": "hdb_catalog"}, "column_mapping": {"table_name": "table_name", "table_schema": "table_schema"}}}	\N	t
hdb_catalog	hdb_table	permissions	array	{"manual_configuration": {"remote_table": {"name": "hdb_permission_agg", "schema": "hdb_catalog"}, "column_mapping": {"table_name": "table_name", "table_schema": "table_schema"}}}	\N	t
hdb_catalog	hdb_table	check_constraints	array	{"manual_configuration": {"remote_table": {"name": "hdb_check_constraint", "schema": "hdb_catalog"}, "column_mapping": {"table_name": "table_name", "table_schema": "table_schema"}}}	\N	t
hdb_catalog	hdb_table	unique_constraints	array	{"manual_configuration": {"remote_table": {"name": "hdb_unique_constraint", "schema": "hdb_catalog"}, "column_mapping": {"table_name": "table_name", "table_schema": "table_schema"}}}	\N	t
hdb_catalog	event_log	trigger	object	{"manual_configuration": {"remote_table": {"name": "event_triggers", "schema": "hdb_catalog"}, "column_mapping": {"trigger_name": "name"}}}	\N	t
hdb_catalog	event_triggers	events	array	{"manual_configuration": {"remote_table": {"name": "event_log", "schema": "hdb_catalog"}, "column_mapping": {"name": "trigger_name"}}}	\N	t
hdb_catalog	event_invocation_logs	event	object	{"foreign_key_constraint_on": "event_id"}	\N	t
hdb_catalog	event_log	logs	array	{"foreign_key_constraint_on": {"table": {"name": "event_invocation_logs", "schema": "hdb_catalog"}, "column": "event_id"}}	\N	t
hdb_catalog	hdb_function_agg	return_table_info	object	{"manual_configuration": {"remote_table": {"name": "hdb_table", "schema": "hdb_catalog"}, "column_mapping": {"return_type_name": "table_name", "return_type_schema": "table_schema"}}}	\N	t
public	log	queue	object	{"foreign_key_constraint_on": "queue_id"}	\N	f
public	log	agent_fk	object	{"foreign_key_constraint_on": "agent_id"}	\N	f
public	queue	agent_assigned_queues	array	{"foreign_key_constraint_on": {"table": "agent_assigned_queues", "column": "queue_id"}}	\N	f
public	queue	agent_shift_queues	array	{"foreign_key_constraint_on": {"table": "agent_shift_queue", "column": "queue_id"}}	\N	f
public	queue	logs	array	{"foreign_key_constraint_on": {"table": "log", "column": "queue_id"}}	\N	f
public	agent	agent_team_manager	object	{"foreign_key_constraint_on": "team_manager"}	\N	f
public	agent	agent_shift_queues	array	{"foreign_key_constraint_on": {"table": "agent_shift_queue", "column": "agent_id"}}	\N	f
public	agent	agent_on_shifts	array	{"foreign_key_constraint_on": {"table": "agent_on_shift", "column": "agent_id"}}	\N	f
public	agent	agent_off_shifts	array	{"foreign_key_constraint_on": {"table": "agent_off_shift", "column": "agent_id"}}	\N	f
public	agent	logs	array	{"foreign_key_constraint_on": {"table": "log", "column": "agent_id"}}	\N	f
public	agent	agent_assigned_queues	array	{"foreign_key_constraint_on": {"table": "agent_assigned_queues", "column": "agent_id"}}	\N	f
public	agent	agents	array	{"foreign_key_constraint_on": {"table": "agent", "column": "team_manager"}}	\N	f
public	agent_shift_queue	queue	object	{"foreign_key_constraint_on": "queue_id"}	\N	f
public	agent_shift_queue	agent	object	{"foreign_key_constraint_on": "agent_id"}	\N	f
public	shift	agent_on_shifts	array	{"foreign_key_constraint_on": {"table": "agent_on_shift", "column": "shift_id"}}	\N	f
public	shift	agent_off_shifts	array	{"foreign_key_constraint_on": {"table": "agent_off_shift", "column": "shift_id"}}	\N	f
public	agent_on_shift	shift	object	{"foreign_key_constraint_on": "shift_id"}	\N	f
public	agent_on_shift	agent	object	{"foreign_key_constraint_on": "agent_id"}	\N	f
public	agent_off_shift	shift	object	{"foreign_key_constraint_on": "shift_id"}	\N	f
public	agent_off_shift	agent	object	{"foreign_key_constraint_on": "agent_id"}	\N	f
public	agent_assigned_queues	queue	object	{"foreign_key_constraint_on": "queue_id"}	\N	f
public	agent_assigned_queues	agent	object	{"foreign_key_constraint_on": "agent_id"}	\N	f
\.


--
-- Data for Name: hdb_schema_update_event; Type: TABLE DATA; Schema: hdb_catalog; Owner: -
--

COPY hdb_catalog.hdb_schema_update_event (id, instance_id, occurred_at) FROM stdin;
1	e0028156-1319-4b23-b896-9ba6aac04ae0	2019-04-19 09:24:37.73873+00
2	2525fae3-7422-4e10-b4f3-fd3b42a994f9	2019-04-19 10:03:21.843033+00
3	2525fae3-7422-4e10-b4f3-fd3b42a994f9	2019-04-19 12:12:55.573335+00
4	a30992cd-b01b-48ae-b148-de76c3c4a9a9	2019-05-04 12:39:25.082488+00
5	7e3f302a-4b50-437b-9b53-6c9e5e800264	2019-05-05 11:44:17.722687+00
6	7e3f302a-4b50-437b-9b53-6c9e5e800264	2019-05-05 11:48:37.384399+00
7	7e3f302a-4b50-437b-9b53-6c9e5e800264	2019-05-05 11:48:58.096052+00
8	7e3f302a-4b50-437b-9b53-6c9e5e800264	2019-05-05 11:49:36.109074+00
9	7e3f302a-4b50-437b-9b53-6c9e5e800264	2019-05-05 11:49:44.464624+00
10	7e3f302a-4b50-437b-9b53-6c9e5e800264	2019-05-05 11:49:44.597874+00
11	7e3f302a-4b50-437b-9b53-6c9e5e800264	2019-05-05 11:53:13.149174+00
12	7e3f302a-4b50-437b-9b53-6c9e5e800264	2019-05-05 12:55:45.016841+00
13	7e3f302a-4b50-437b-9b53-6c9e5e800264	2019-05-05 12:56:30.485623+00
14	7e3f302a-4b50-437b-9b53-6c9e5e800264	2019-05-05 12:57:11.775637+00
15	7e3f302a-4b50-437b-9b53-6c9e5e800264	2019-05-05 12:57:23.619757+00
16	7e3f302a-4b50-437b-9b53-6c9e5e800264	2019-05-05 12:57:35.662594+00
17	7e3f302a-4b50-437b-9b53-6c9e5e800264	2019-05-05 12:57:57.845206+00
18	7e3f302a-4b50-437b-9b53-6c9e5e800264	2019-05-05 12:58:06.092157+00
19	8522031f-fa6d-4b2b-93c2-2738c25032ec	2019-05-06 13:46:00.498897+00
\.


--
-- Data for Name: hdb_table; Type: TABLE DATA; Schema: hdb_catalog; Owner: -
--

COPY hdb_catalog.hdb_table (table_schema, table_name, is_system_defined) FROM stdin;
hdb_catalog	hdb_table	t
information_schema	tables	t
information_schema	schemata	t
information_schema	views	t
hdb_catalog	hdb_primary_key	t
information_schema	columns	t
hdb_catalog	hdb_foreign_key_constraint	t
hdb_catalog	hdb_relationship	t
hdb_catalog	hdb_permission_agg	t
hdb_catalog	hdb_check_constraint	t
hdb_catalog	hdb_unique_constraint	t
hdb_catalog	hdb_query_template	t
hdb_catalog	event_triggers	t
hdb_catalog	event_log	t
hdb_catalog	event_invocation_logs	t
hdb_catalog	hdb_function_agg	t
hdb_catalog	hdb_function	t
hdb_catalog	remote_schemas	t
hdb_catalog	hdb_version	t
public	log	f
public	queue	f
public	agent	f
public	agent_shift_queue	f
public	shift	f
public	agent_on_shift	f
public	agent_off_shift	f
public	agent_assigned_queues	f
\.


--
-- Data for Name: hdb_version; Type: TABLE DATA; Schema: hdb_catalog; Owner: -
--

COPY hdb_catalog.hdb_version (hasura_uuid, version, upgraded_on, cli_state, console_state) FROM stdin;
288f80c6-5e7f-49d5-b915-e10106915a57	13	2019-04-19 09:24:09.826793+00	{}	{"telemetryNotificationShown": true}
\.


--
-- Data for Name: remote_schemas; Type: TABLE DATA; Schema: hdb_catalog; Owner: -
--

COPY hdb_catalog.remote_schemas (id, name, definition, comment) FROM stdin;
\.


--
-- Data for Name: agent; Type: TABLE DATA; Schema: public; Owner: -
--

COPY public.agent (id, first_name, last_name, email, staff, active, team_manager, site, "position", channel, tier, team, purecloud_id, position_abbr) FROM stdin;
5	Brandon	Neal	stewartbrian@yahoo.com		t	\N	Tunis	OPS Senior	Operations	T3	backoffice 1	\N	CS
6	Alexandra	Rodriguez	webbjanice@cain.com		t	\N	Amsterdam	OPS Senior	Emails	T3	backoffice 1	\N	CS
7	Brandon	Wright	christopher10@macias.com		t	\N	Tunis	OPS Junior	Complaints	T2	email team	\N	OP
8	Vincent	Singleton	pereznancy@reed-mcgee.com		t	\N	Zlin	OPS specialist	Operations	T3	call team	\N	CS
9	Laura	Martinez	scross@friedman-bryan.com		t	\N	Bangladesh	OPS Senior	Emails	T2	backoffice 1	\N	OP
10	Abigail	Green	barrymichele@gmail.com		t	\N	Amsterdam	OPS specialist	Emails	T3	email team	\N	OP
11	Amy	Johnson	cooleyandrew@gmail.com		t	\N	Tunis	CS specialist	Chat	T2	backoffice 2	\N	CS
12	Elizabeth	Eaton	joelabbott@garza.com		t	\N	Zlin	CS Junior	Chat	T1	call team	\N	OP
13	Amy	Murillo	patricia91@yahoo.com		t	\N	Amsterdam	OPS specialist	Chat	T1	call team	\N	OP
14	Benjamin	Young	kennethmccormick@yahoo.com		t	\N	Amsterdam	OPS Senior	Emails	T2	chat team	\N	OP
15	Melissa	Mccarthy	mbrady@yahoo.com		t	\N	Tunis	OPS Senior	Complaints	T1	chat team	\N	CS
16	Yolanda	Miller	uthomas@yahoo.com		t	\N	Bangladesh	OPS Senior	Emails	T2	email team	\N	CS
17	Deanna	Berry	martincourtney@gonzalez-sullivan.com		t	\N	Bangladesh	OPS Junior	Operations	T2	backoffice 1	\N	CS
18	Glenn	Hughes	qsmith@gonzales.com		t	\N	Brno	OPS Senior	Complaints	T1	chat team	\N	CS
19	John	Owen	uhiggins@gmail.com		t	\N	Tunis	OPS Junior	Complaints	T1	call team	\N	OP
20	Jennifer	Schmidt	johnathanduncan@yahoo.com		t	\N	Zlin	OPS specialist	Emails	T1	backoffice 2	\N	OP
21	James	Franco	enguyen@keller.com		t	\N	Brno	OPS specialist	Emails	T3	backoffice 1	\N	OP
22	Jacob	Patel	arthurcabrera@yahoo.com		t	\N	Tunis	CS Junior	Operations	T2	chat team	\N	OP
23	Monique	Marquez	michaelswanson@gmail.com		t	\N	Zlin	CS specialist	Emails	T2	call team	\N	OP
24	Gloria	Miller	dharrell@yahoo.com		t	\N	Tunis	OPS specialist	Emails	T2	email team	\N	OP
25	Paul	Cox	lynnyates@colon.com		t	\N	Zlin	OPS Senior	Emails	T1	chat team	\N	CS
26	Veronica	Jones	shane42@gmail.com		t	\N	Amsterdam	OPS Senior	Emails	T1	backoffice 2	\N	CS
27	Karen	Nguyen	stephanieharris@george-phelps.com		t	\N	Amsterdam	CS specialist	Chat	T3	call team	\N	OP
28	Jennifer	Davis	michael37@wade.com		t	\N	Bangladesh	OPS specialist	Chat	T2	email team	\N	CS
29	Charles	Davis	allen52@marquez-martin.com		t	\N	Amsterdam	CS specialist	Complaints	T1	chat team	\N	CS
30	Laura	Fletcher	hillkelly@friedman-smith.com		t	\N	Brno	CS Junior	Emails	T2	email team	\N	OP
31	Jonathan	Cannon	garyyoung@gmail.com		t	\N	Amsterdam	OPS specialist	Complaints	T2	backoffice 2	\N	OP
32	Christine	Price	teresa51@russell.com		t	\N	Brno	OPS Junior	Emails	T2	call team	\N	OP
33	Sandra	Larson	ralphdominguez@rogers-casey.com		t	\N	Zlin	OPS Junior	Chat	T3	email team	\N	OP
34	Robert	Blevins	thomas17@stewart.org		t	\N	Zlin	CS Junior	Voice&Emails	T2	chat team	\N	OP
35	Sarah	Vega	oreyes@robinson.org		t	\N	Brno	OPS Junior	Voice&Emails	T1	backoffice 1	\N	OP
36	Michael	Carson	jclark@malone.com		t	\N	Brno	CS specialist	Complaints	T2	chat team	\N	CS
37	Kristina	Burns	brownjoseph@kaiser.com		t	\N	Bangladesh	OPS Senior	Complaints	T1	chat team	\N	OP
38	Alison	Stein	hartmanmicheal@wilson.com		t	\N	Tunis	OPS Junior	Complaints	T3	chat team	\N	OP
39	Timothy	Peterson	gstevens@yahoo.com		t	\N	Zlin	CS specialist	Voice&Emails	T3	chat team	\N	OP
40	Charlotte	Johnson	amyhughes@wang-richards.info		t	\N	Bangladesh	CS specialist	Operations	T1	email team	\N	OP
41	Mia	Wilson	qrobinson@yahoo.com		t	\N	Bangladesh	OPS specialist	Operations	T2	call team	\N	OP
42	Diana	Potts	andrewwebb@best.com		t	\N	Bangladesh	OPS Junior	Emails	T2	chat team	\N	OP
43	Ryan	Hernandez	jlee@hotmail.com		t	\N	Bangladesh	CS Junior	Complaints	T3	backoffice 1	\N	OP
44	Jonathan	Morgan	sextonlisa@leblanc-love.com		t	\N	Zlin	CS Junior	Voice&Emails	T3	chat team	\N	CS
45	Kayla	Freeman	davisadam@yahoo.com		t	\N	Brno	CS specialist	Voice&Emails	T1	backoffice 2	\N	OP
46	Francisco	Miranda	yfields@norris-wilson.net		t	\N	Amsterdam	OPS Senior	Voice&Emails	T3	email team	\N	CS
47	Denise	Smith	walkeranthony@lopez.net		t	\N	Bangladesh	OPS specialist	Chat	T1	call team	\N	OP
48	Emily	Larson	zavalarichard@jones.com		t	\N	Brno	OPS Senior	Emails	T3	chat team	\N	OP
49	Tracy	Salazar	owensmary@bird.com		t	\N	Brno	CS Junior	Operations	T2	email team	\N	OP
50	Ernest	Medina	travisyoung@norman.com		t	\N	Zlin	OPS Junior	Operations	T3	backoffice 1	\N	CS
51	Sharon	Turner	kelsey29@mitchell-chandler.com		t	\N	Tunis	CS specialist	Complaints	T2	call team	\N	OP
52	Michael	King	hunter59@moore-brown.net		t	\N	Brno	OPS specialist	Complaints	T2	call team	\N	OP
53	Gerald	Robinson	kgarcia@gmail.com		t	\N	Bangladesh	CS specialist	Emails	T3	email team	\N	CS
54	Amanda	Rogers	nicolenguyen@hotmail.com		t	\N	Zlin	OPS Senior	Operations	T1	call team	\N	CS
55	Carl	Blevins	rfernandez@yahoo.com		t	\N	Zlin	OPS specialist	Voice&Emails	T3	backoffice 2	\N	CS
56	Courtney	Cooper	richardmiller@peters.net		t	\N	Tunis	OPS Junior	Complaints	T2	backoffice 1	\N	CS
57	Gregory	Wolfe	dwilliams@hotmail.com		t	\N	Brno	CS specialist	Chat	T3	chat team	\N	CS
58	Alejandro	White	craiglynch@mcdonald-tran.biz		t	\N	Bangladesh	CS Junior	Chat	T1	backoffice 2	\N	OP
59	Paul	Clay	bartonjacob@yahoo.com		t	\N	Zlin	OPS Junior	Voice&Emails	T3	backoffice 2	\N	OP
60	Melissa	Taylor	pamela53@harmon.org		t	\N	Bangladesh	CS Junior	Emails	T3	email team	\N	CS
61	Michael	Friedman	travisleonard@gmail.com		t	\N	Brno	CS specialist	Emails	T1	email team	\N	OP
62	Shane	Chase	torresjohn@yahoo.com		t	\N	Tunis	CS specialist	Chat	T2	backoffice 1	\N	CS
63	Jessica	Payne	samueloneill@yahoo.com		t	\N	Zlin	CS specialist	Operations	T3	call team	\N	CS
64	Antonio	Alexander	fgutierrez@hotmail.com		t	\N	Brno	OPS specialist	Chat	T3	call team	\N	OP
65	Sarah	Conner	apatrick@martinez-hatfield.org		t	\N	Amsterdam	OPS Junior	Chat	T2	call team	\N	CS
66	Melinda	Dennis	simmonsantonio@gmail.com		t	\N	Zlin	OPS specialist	Operations	T2	backoffice 1	\N	CS
67	Mary	Bennett	adriandavis@weaver.com		t	\N	Bangladesh	OPS Senior	Chat	T1	email team	\N	OP
68	Jo	Hahn	williamsmarco@gmail.com		t	\N	Zlin	CS Junior	Emails	T1	backoffice 1	\N	OP
69	Theresa	Stanton	lori83@gmail.com		t	\N	Tunis	CS specialist	Emails	T1	backoffice 2	\N	OP
70	Stephen	Stokes	ryan03@gmail.com		t	\N	Brno	OPS Junior	Voice&Emails	T1	backoffice 2	\N	OP
71	Madeline	Riley	brenda62@gmail.com		t	\N	Tunis	CS specialist	Operations	T1	email team	\N	CS
72	Sylvia	Jordan	richardlewis@yahoo.com		t	\N	Bangladesh	OPS Junior	Operations	T1	call team	\N	OP
73	Julie	Johnson	tanderson@martin.biz		t	\N	Bangladesh	OPS Junior	Emails	T2	call team	\N	CS
74	Ryan	Taylor	wstuart@gmail.com		t	\N	Tunis	OPS specialist	Complaints	T1	call team	\N	OP
75	Clifford	Mitchell	andrewbarber@gmail.com		t	\N	Tunis	CS specialist	Voice&Emails	T1	backoffice 1	\N	CS
76	Joseph	Mitchell	mooreshirley@hotmail.com		t	\N	Amsterdam	CS specialist	Voice&Emails	T1	backoffice 1	\N	CS
77	Thomas	Wise	spencerbutler@johnson.org		t	\N	Amsterdam	OPS Senior	Emails	T3	call team	\N	CS
78	Courtney	Bates	wrowland@gmail.com		t	\N	Brno	CS specialist	Complaints	T2	backoffice 2	\N	CS
79	Benjamin	Gilmore	gjordan@yahoo.com		t	\N	Bangladesh	OPS Senior	Chat	T2	call team	\N	CS
80	Michael	Morrow	rachel68@whitaker.com		t	\N	Bangladesh	CS Junior	Emails	T2	email team	\N	CS
81	Stephanie	Baxter	hilllaura@adams.info		t	\N	Brno	OPS Senior	Complaints	T1	email team	\N	CS
82	Jasmine	Hendricks	halljamie@shannon.com		t	\N	Tunis	CS specialist	Complaints	T3	call team	\N	OP
83	Samantha	Mcdonald	teresarobinson@yahoo.com		t	\N	Tunis	OPS Junior	Operations	T3	backoffice 1	\N	CS
84	Ray	Cardenas	medinagabriela@garrett.net		t	\N	Tunis	OPS Junior	Chat	T1	email team	\N	OP
85	Benjamin	Garcia	dustin95@yahoo.com		t	\N	Zlin	OPS specialist	Operations	T2	call team	\N	CS
86	David	Williams	jesusdavis@yahoo.com		t	\N	Zlin	CS Junior	Voice&Emails	T3	chat team	\N	OP
87	Michelle	Perez	farmerthomas@yahoo.com		t	\N	Bangladesh	OPS Senior	Complaints	T1	backoffice 2	\N	CS
88	Amy	Hampton	sanderstony@hotmail.com		t	\N	Amsterdam	OPS Senior	Operations	T2	backoffice 2	\N	CS
89	Anthony	Howard	woodlaura@mayer-turner.com		t	\N	Tunis	CS specialist	Emails	T1	email team	\N	OP
90	James	Jones	jacob17@gmail.com		t	\N	Brno	CS Junior	Emails	T1	call team	\N	OP
91	Vicki	Johnson	xolson@hutchinson.net		t	\N	Brno	OPS specialist	Emails	T3	backoffice 1	\N	CS
92	Wanda	Miller	bwagner@hotmail.com		t	\N	Amsterdam	OPS Junior	Chat	T2	chat team	\N	OP
93	Anthony	Pierce	howellgary@yahoo.com		t	\N	Brno	OPS Senior	Voice&Emails	T1	backoffice 2	\N	OP
94	Carrie	Short	jennifercaldwell@estrada.com		t	\N	Amsterdam	OPS Junior	Operations	T2	backoffice 2	\N	CS
95	Wanda	Jordan	riveracindy@rogers.net		t	\N	Amsterdam	CS specialist	Voice&Emails	T2	email team	\N	OP
96	Joan	Friedman	tracy91@horton.com		t	\N	Amsterdam	OPS Junior	Complaints	T2	call team	\N	OP
97	Dominic	Barber	petersonzachary@yahoo.com		t	\N	Amsterdam	CS Junior	Operations	T1	backoffice 1	\N	OP
98	Daniel	Melendez	powelltravis@robinson.com		t	\N	Tunis	CS specialist	Emails	T3	chat team	\N	CS
99	Anthony	Lopez	jennyrice@gibson-brown.biz		t	\N	Tunis	CS specialist	Complaints	T1	chat team	\N	OP
100	Anne	Delgado	davisjustin@oconnor.biz		t	\N	Brno	CS Junior	Chat	T2	call team	\N	OP
101	Noah	Evans	philip87@hotmail.com		t	\N	Bangladesh	OPS specialist	Emails	T1	chat team	\N	OP
102	Holly	Sandoval	michaelross@hotmail.com		t	\N	Bangladesh	OPS Senior	Voice&Emails	T2	chat team	\N	OP
103	Michael	Shepherd	edwardsjeffrey@hotmail.com		t	\N	Zlin	CS specialist	Emails	T2	backoffice 2	\N	OP
104	Eric	Goodwin	angela13@yahoo.com		t	\N	Zlin	CS Junior	Voice&Emails	T1	chat team	\N	OP
\.


--
-- Data for Name: agent_assigned_queues; Type: TABLE DATA; Schema: public; Owner: -
--

COPY public.agent_assigned_queues (agent_id, queue_id, id) FROM stdin;
\.


--
-- Data for Name: agent_off_shift; Type: TABLE DATA; Schema: public; Owner: -
--

COPY public.agent_off_shift (id, shift_id, start_time_utc, end_time_utc, agent_id, off_reason) FROM stdin;
1	5	2019-04-30 15:00:00	2019-04-30 23:00:00	9	Doctors appt
2	6	2019-05-14 15:00:00	2019-05-14 23:00:00	38	Sick day
3	6	2019-05-12 23:00:00	2019-05-13 11:00:00	83	Maternity leave
4	7	2019-04-26 15:00:00	2019-04-26 23:00:00	48	Vacation
5	3	2019-05-15 07:00:00	2019-05-15 19:00:00	10	Vacation
6	4	2019-05-07 07:00:00	2019-05-07 15:00:00	66	Maternity leave
7	7	2019-04-26 15:00:00	2019-04-26 23:00:00	104	Doctors appt
8	1	2019-04-22 07:00:00	2019-04-22 19:00:00	96	Doctors appt
9	4	2019-05-08 15:00:00	2019-05-08 23:00:00	101	Sick day
10	5	2019-05-20 15:00:00	2019-05-20 23:00:00	39	Doctors appt
11	7	2019-05-17 07:00:00	2019-05-17 15:00:00	68	Vacation
12	4	2019-04-29 07:00:00	2019-04-29 15:00:00	42	Maternity leave
13	5	2019-04-23 23:00:00	2019-04-24 07:00:00	72	Maternity leave
14	6	2019-04-26 15:00:00	2019-04-27 03:00:00	15	Doctors appt
15	4	2019-05-09 15:00:00	2019-05-10 03:00:00	21	Doctors appt
16	3	2019-05-15 15:00:00	2019-05-15 23:00:00	44	Maternity leave
17	4	2019-05-18 23:00:00	2019-05-19 11:00:00	83	Maternity leave
18	7	2019-05-15 15:00:00	2019-05-15 23:00:00	47	Doctors appt
19	1	2019-05-04 15:00:00	2019-05-05 03:00:00	63	Doctors appt
20	5	2019-05-07 07:00:00	2019-05-07 15:00:00	80	Vacation
21	7	2019-05-14 23:00:00	2019-05-15 07:00:00	40	Maternity leave
22	3	2019-05-07 07:00:00	2019-05-07 19:00:00	8	Maternity leave
23	6	2019-05-10 15:00:00	2019-05-10 23:00:00	25	Maternity leave
24	4	2019-05-03 15:00:00	2019-05-04 03:00:00	46	Sick day
25	3	2019-05-04 23:00:00	2019-05-05 11:00:00	70	Vacation
26	3	2019-05-11 07:00:00	2019-05-11 15:00:00	7	Sick day
27	7	2019-04-20 15:00:00	2019-04-21 03:00:00	42	Vacation
28	4	2019-05-14 07:00:00	2019-05-14 19:00:00	55	Vacation
29	4	2019-04-27 15:00:00	2019-04-27 23:00:00	88	Sick day
30	5	2019-05-08 07:00:00	2019-05-08 15:00:00	77	Maternity leave
31	7	2019-05-07 15:00:00	2019-05-07 23:00:00	24	Vacation
32	2	2019-05-15 07:00:00	2019-05-15 19:00:00	47	Doctors appt
33	4	2019-05-06 23:00:00	2019-05-07 11:00:00	45	Sick day
34	4	2019-05-15 07:00:00	2019-05-15 19:00:00	67	Maternity leave
35	3	2019-04-20 23:00:00	2019-04-21 07:00:00	25	Vacation
36	4	2019-04-20 07:00:00	2019-04-20 15:00:00	56	Sick day
37	1	2019-05-03 07:00:00	2019-05-03 19:00:00	83	Maternity leave
38	3	2019-04-22 07:00:00	2019-04-22 15:00:00	15	Vacation
39	5	2019-05-16 07:00:00	2019-05-16 19:00:00	70	Doctors appt
40	3	2019-05-19 07:00:00	2019-05-19 15:00:00	47	Maternity leave
41	7	2019-05-01 15:00:00	2019-05-02 03:00:00	68	Doctors appt
42	2	2019-04-25 23:00:00	2019-04-26 07:00:00	8	Maternity leave
43	4	2019-04-23 23:00:00	2019-04-24 11:00:00	8	Maternity leave
44	5	2019-05-05 07:00:00	2019-05-05 15:00:00	87	Maternity leave
45	6	2019-05-05 07:00:00	2019-05-05 15:00:00	102	Maternity leave
46	2	2019-04-26 15:00:00	2019-04-26 23:00:00	84	Maternity leave
47	3	2019-04-25 15:00:00	2019-04-26 03:00:00	8	Doctors appt
48	2	2019-05-02 07:00:00	2019-05-02 19:00:00	24	Sick day
49	5	2019-04-22 07:00:00	2019-04-22 15:00:00	58	Vacation
50	5	2019-05-18 23:00:00	2019-05-19 07:00:00	63	Maternity leave
\.


--
-- Data for Name: agent_on_shift; Type: TABLE DATA; Schema: public; Owner: -
--

COPY public.agent_on_shift (id, shift_id, start_time_utc, end_time_utc, agent_id) FROM stdin;
1	5	2019-04-24 07:00:00	2019-04-24 15:00:00	44
2	7	2019-04-21 07:00:00	2019-04-21 19:00:00	85
3	6	2019-05-20 15:00:00	2019-05-21 03:00:00	53
4	5	2019-05-18 23:00:00	2019-05-19 11:00:00	81
5	4	2019-05-10 15:00:00	2019-05-11 03:00:00	48
6	7	2019-05-17 23:00:00	2019-05-18 11:00:00	58
7	1	2019-05-05 23:00:00	2019-05-06 11:00:00	80
8	1	2019-05-08 07:00:00	2019-05-08 15:00:00	78
9	1	2019-04-29 15:00:00	2019-04-29 23:00:00	37
10	3	2019-05-19 23:00:00	2019-05-20 11:00:00	101
11	3	2019-05-05 23:00:00	2019-05-06 11:00:00	18
12	3	2019-05-14 15:00:00	2019-05-14 23:00:00	50
13	4	2019-04-23 07:00:00	2019-04-23 19:00:00	98
14	2	2019-05-17 23:00:00	2019-05-18 11:00:00	16
15	5	2019-05-18 23:00:00	2019-05-19 11:00:00	81
16	1	2019-05-13 15:00:00	2019-05-14 03:00:00	95
17	1	2019-04-24 23:00:00	2019-04-25 11:00:00	59
18	5	2019-05-19 15:00:00	2019-05-19 23:00:00	52
19	7	2019-04-28 15:00:00	2019-04-28 23:00:00	86
20	1	2019-05-14 07:00:00	2019-05-14 15:00:00	58
21	2	2019-04-21 15:00:00	2019-04-21 23:00:00	18
22	3	2019-04-21 07:00:00	2019-04-21 15:00:00	71
23	4	2019-04-20 07:00:00	2019-04-20 15:00:00	45
24	1	2019-05-13 23:00:00	2019-05-14 07:00:00	31
25	4	2019-05-14 23:00:00	2019-05-15 07:00:00	74
26	6	2019-04-20 23:00:00	2019-04-21 07:00:00	88
27	3	2019-04-30 23:00:00	2019-05-01 11:00:00	55
28	7	2019-05-07 15:00:00	2019-05-07 23:00:00	32
29	2	2019-04-20 07:00:00	2019-04-20 15:00:00	97
30	5	2019-05-18 23:00:00	2019-05-19 11:00:00	98
31	1	2019-05-16 07:00:00	2019-05-16 15:00:00	94
32	3	2019-04-27 07:00:00	2019-04-27 15:00:00	62
33	5	2019-04-23 07:00:00	2019-04-23 19:00:00	30
34	7	2019-04-29 23:00:00	2019-04-30 11:00:00	69
35	1	2019-05-08 07:00:00	2019-05-08 15:00:00	29
36	1	2019-05-05 15:00:00	2019-05-06 03:00:00	28
37	4	2019-04-27 07:00:00	2019-04-27 19:00:00	91
38	3	2019-05-08 07:00:00	2019-05-08 19:00:00	14
39	4	2019-04-24 23:00:00	2019-04-25 11:00:00	71
40	4	2019-05-06 07:00:00	2019-05-06 15:00:00	12
41	4	2019-04-28 15:00:00	2019-04-28 23:00:00	59
42	2	2019-05-16 23:00:00	2019-05-17 11:00:00	70
43	6	2019-05-07 23:00:00	2019-05-08 07:00:00	61
44	4	2019-04-21 15:00:00	2019-04-22 03:00:00	89
45	7	2019-05-16 15:00:00	2019-05-17 03:00:00	7
46	6	2019-05-01 15:00:00	2019-05-01 23:00:00	68
47	1	2019-05-08 23:00:00	2019-05-09 07:00:00	79
48	3	2019-05-14 15:00:00	2019-05-15 03:00:00	85
49	4	2019-04-28 15:00:00	2019-04-28 23:00:00	101
50	3	2019-04-24 07:00:00	2019-04-24 15:00:00	22
51	3	2019-04-21 15:00:00	2019-04-22 03:00:00	71
52	5	2019-05-16 07:00:00	2019-05-16 15:00:00	65
53	2	2019-05-13 15:00:00	2019-05-13 23:00:00	101
54	7	2019-05-02 07:00:00	2019-05-02 19:00:00	12
55	4	2019-05-06 23:00:00	2019-05-07 11:00:00	96
56	5	2019-05-17 07:00:00	2019-05-17 19:00:00	48
57	3	2019-04-26 23:00:00	2019-04-27 11:00:00	13
58	3	2019-04-28 15:00:00	2019-04-28 23:00:00	39
59	7	2019-05-04 07:00:00	2019-05-04 15:00:00	54
60	1	2019-05-14 15:00:00	2019-05-15 03:00:00	93
61	4	2019-05-18 23:00:00	2019-05-19 11:00:00	87
62	4	2019-04-29 15:00:00	2019-04-30 03:00:00	70
63	5	2019-04-25 07:00:00	2019-04-25 19:00:00	22
64	3	2019-04-28 23:00:00	2019-04-29 11:00:00	65
65	7	2019-05-04 07:00:00	2019-05-04 15:00:00	68
66	5	2019-05-12 07:00:00	2019-05-12 19:00:00	37
67	6	2019-05-09 23:00:00	2019-05-10 11:00:00	67
68	3	2019-05-10 23:00:00	2019-05-11 11:00:00	86
69	5	2019-04-28 15:00:00	2019-04-28 23:00:00	40
70	1	2019-05-16 15:00:00	2019-05-16 23:00:00	80
71	4	2019-05-14 15:00:00	2019-05-15 03:00:00	43
72	7	2019-05-03 23:00:00	2019-05-04 11:00:00	18
73	4	2019-05-15 07:00:00	2019-05-15 15:00:00	72
74	2	2019-04-28 07:00:00	2019-04-28 19:00:00	85
75	4	2019-05-07 23:00:00	2019-05-08 07:00:00	20
76	2	2019-04-29 23:00:00	2019-04-30 07:00:00	7
77	2	2019-04-26 07:00:00	2019-04-26 19:00:00	100
78	3	2019-05-10 23:00:00	2019-05-11 11:00:00	27
79	7	2019-05-10 23:00:00	2019-05-11 07:00:00	5
80	3	2019-05-07 15:00:00	2019-05-08 03:00:00	92
81	3	2019-05-05 07:00:00	2019-05-05 19:00:00	19
82	5	2019-04-22 23:00:00	2019-04-23 11:00:00	30
83	5	2019-05-03 23:00:00	2019-05-04 11:00:00	92
84	6	2019-05-18 07:00:00	2019-05-18 19:00:00	57
85	2	2019-05-12 07:00:00	2019-05-12 15:00:00	43
86	6	2019-04-20 23:00:00	2019-04-21 07:00:00	54
87	2	2019-05-02 07:00:00	2019-05-02 19:00:00	16
88	3	2019-05-13 15:00:00	2019-05-14 03:00:00	45
89	1	2019-05-06 15:00:00	2019-05-06 23:00:00	83
90	5	2019-05-05 23:00:00	2019-05-06 07:00:00	103
91	1	2019-05-18 23:00:00	2019-05-19 07:00:00	66
92	3	2019-05-01 23:00:00	2019-05-02 07:00:00	58
93	7	2019-04-23 07:00:00	2019-04-23 15:00:00	53
94	6	2019-05-09 23:00:00	2019-05-10 11:00:00	29
95	3	2019-05-05 15:00:00	2019-05-06 03:00:00	36
96	5	2019-05-15 15:00:00	2019-05-15 23:00:00	56
97	5	2019-05-14 15:00:00	2019-05-15 03:00:00	40
98	7	2019-05-13 23:00:00	2019-05-14 07:00:00	52
99	7	2019-04-21 15:00:00	2019-04-22 03:00:00	37
100	7	2019-04-21 23:00:00	2019-04-22 11:00:00	30
101	3	2019-04-29 23:00:00	2019-04-30 11:00:00	70
102	6	2019-04-30 23:00:00	2019-05-01 11:00:00	89
103	4	2019-05-08 23:00:00	2019-05-09 07:00:00	26
104	4	2019-05-04 15:00:00	2019-05-04 23:00:00	86
105	7	2019-05-02 23:00:00	2019-05-03 07:00:00	40
106	4	2019-04-30 07:00:00	2019-04-30 15:00:00	66
107	5	2019-05-06 07:00:00	2019-05-06 15:00:00	92
108	5	2019-05-04 07:00:00	2019-05-04 15:00:00	30
109	1	2019-05-17 07:00:00	2019-05-17 19:00:00	27
110	1	2019-05-07 15:00:00	2019-05-08 03:00:00	72
111	2	2019-04-26 15:00:00	2019-04-26 23:00:00	30
112	2	2019-05-16 23:00:00	2019-05-17 11:00:00	26
113	1	2019-05-16 07:00:00	2019-05-16 19:00:00	41
114	1	2019-05-04 07:00:00	2019-05-04 15:00:00	93
115	6	2019-04-21 23:00:00	2019-04-22 07:00:00	40
116	7	2019-04-27 23:00:00	2019-04-28 07:00:00	46
117	1	2019-05-20 23:00:00	2019-05-21 11:00:00	103
118	6	2019-05-03 15:00:00	2019-05-03 23:00:00	103
119	7	2019-04-30 15:00:00	2019-05-01 03:00:00	26
120	6	2019-05-16 07:00:00	2019-05-16 19:00:00	38
121	6	2019-05-12 07:00:00	2019-05-12 19:00:00	37
122	4	2019-05-17 07:00:00	2019-05-17 19:00:00	89
123	1	2019-05-07 07:00:00	2019-05-07 19:00:00	64
124	6	2019-05-19 23:00:00	2019-05-20 07:00:00	55
125	5	2019-04-28 23:00:00	2019-04-29 07:00:00	63
126	4	2019-05-11 23:00:00	2019-05-12 11:00:00	36
127	4	2019-04-22 23:00:00	2019-04-23 11:00:00	67
128	2	2019-05-14 07:00:00	2019-05-14 19:00:00	75
129	3	2019-04-21 23:00:00	2019-04-22 07:00:00	39
130	3	2019-05-09 23:00:00	2019-05-10 11:00:00	31
131	3	2019-04-23 07:00:00	2019-04-23 15:00:00	30
132	1	2019-05-04 23:00:00	2019-05-05 11:00:00	71
133	3	2019-05-04 07:00:00	2019-05-04 15:00:00	12
134	5	2019-04-30 23:00:00	2019-05-01 11:00:00	34
135	6	2019-05-18 15:00:00	2019-05-19 03:00:00	8
136	2	2019-05-02 15:00:00	2019-05-03 03:00:00	65
137	5	2019-05-14 07:00:00	2019-05-14 15:00:00	65
138	2	2019-04-21 23:00:00	2019-04-22 11:00:00	38
139	7	2019-05-02 15:00:00	2019-05-02 23:00:00	65
140	7	2019-05-06 07:00:00	2019-05-06 15:00:00	75
141	5	2019-04-29 23:00:00	2019-04-30 11:00:00	75
142	4	2019-05-11 23:00:00	2019-05-12 07:00:00	75
143	6	2019-04-28 23:00:00	2019-04-29 11:00:00	30
144	3	2019-04-20 15:00:00	2019-04-20 23:00:00	14
145	1	2019-04-25 23:00:00	2019-04-26 11:00:00	97
146	4	2019-05-07 07:00:00	2019-05-07 19:00:00	66
147	3	2019-05-06 07:00:00	2019-05-06 15:00:00	90
148	6	2019-05-07 15:00:00	2019-05-08 03:00:00	16
149	4	2019-05-07 15:00:00	2019-05-07 23:00:00	48
150	4	2019-04-23 07:00:00	2019-04-23 19:00:00	47
151	6	2019-04-28 07:00:00	2019-04-28 19:00:00	61
152	6	2019-05-14 23:00:00	2019-05-15 07:00:00	90
153	7	2019-05-18 07:00:00	2019-05-18 19:00:00	17
154	3	2019-05-12 15:00:00	2019-05-12 23:00:00	12
155	7	2019-04-25 23:00:00	2019-04-26 07:00:00	61
156	1	2019-05-11 23:00:00	2019-05-12 11:00:00	99
157	5	2019-05-15 07:00:00	2019-05-15 15:00:00	62
158	2	2019-05-03 07:00:00	2019-05-03 19:00:00	9
159	7	2019-04-27 15:00:00	2019-04-27 23:00:00	43
160	5	2019-05-20 07:00:00	2019-05-20 15:00:00	37
161	2	2019-05-14 07:00:00	2019-05-14 15:00:00	68
162	3	2019-05-14 07:00:00	2019-05-14 15:00:00	60
163	2	2019-04-24 07:00:00	2019-04-24 15:00:00	87
164	6	2019-05-09 23:00:00	2019-05-10 07:00:00	67
165	2	2019-04-23 15:00:00	2019-04-23 23:00:00	79
166	3	2019-04-23 07:00:00	2019-04-23 19:00:00	59
167	4	2019-05-03 15:00:00	2019-05-03 23:00:00	43
168	3	2019-05-07 15:00:00	2019-05-07 23:00:00	21
169	2	2019-05-10 23:00:00	2019-05-11 11:00:00	67
170	5	2019-05-16 07:00:00	2019-05-16 19:00:00	59
171	4	2019-05-17 15:00:00	2019-05-17 23:00:00	66
172	1	2019-05-14 23:00:00	2019-05-15 07:00:00	47
173	2	2019-04-29 23:00:00	2019-04-30 11:00:00	71
174	2	2019-05-20 15:00:00	2019-05-20 23:00:00	42
175	6	2019-05-07 15:00:00	2019-05-07 23:00:00	50
176	6	2019-04-21 23:00:00	2019-04-22 07:00:00	86
177	3	2019-05-09 07:00:00	2019-05-09 15:00:00	40
178	3	2019-05-06 23:00:00	2019-05-07 07:00:00	101
179	4	2019-04-21 07:00:00	2019-04-21 15:00:00	74
180	2	2019-04-23 15:00:00	2019-04-23 23:00:00	103
181	2	2019-05-05 07:00:00	2019-05-05 19:00:00	43
182	2	2019-05-08 23:00:00	2019-05-09 11:00:00	81
183	3	2019-05-19 23:00:00	2019-05-20 07:00:00	66
184	7	2019-05-19 23:00:00	2019-05-20 07:00:00	57
185	5	2019-05-14 07:00:00	2019-05-14 19:00:00	56
186	3	2019-04-24 07:00:00	2019-04-24 19:00:00	40
187	7	2019-05-07 15:00:00	2019-05-07 23:00:00	10
188	4	2019-05-07 07:00:00	2019-05-07 15:00:00	36
189	3	2019-05-08 23:00:00	2019-05-09 11:00:00	28
190	2	2019-05-14 07:00:00	2019-05-14 15:00:00	24
191	7	2019-05-17 23:00:00	2019-05-18 11:00:00	76
192	3	2019-04-29 07:00:00	2019-04-29 19:00:00	47
193	5	2019-05-20 07:00:00	2019-05-20 15:00:00	86
194	3	2019-05-02 23:00:00	2019-05-03 07:00:00	84
195	2	2019-05-12 23:00:00	2019-05-13 07:00:00	104
196	3	2019-05-15 07:00:00	2019-05-15 15:00:00	48
197	7	2019-05-17 23:00:00	2019-05-18 07:00:00	67
198	1	2019-05-02 07:00:00	2019-05-02 15:00:00	30
199	3	2019-05-05 23:00:00	2019-05-06 11:00:00	56
200	5	2019-04-23 07:00:00	2019-04-23 19:00:00	30
201	6	2019-05-04 07:00:00	2019-05-04 19:00:00	27
202	2	2019-05-10 23:00:00	2019-05-11 07:00:00	41
203	2	2019-05-20 07:00:00	2019-05-20 15:00:00	37
204	5	2019-04-29 15:00:00	2019-04-30 03:00:00	35
205	7	2019-05-18 23:00:00	2019-05-19 07:00:00	32
206	6	2019-05-13 07:00:00	2019-05-13 19:00:00	5
207	3	2019-04-30 15:00:00	2019-04-30 23:00:00	41
208	6	2019-04-26 15:00:00	2019-04-27 03:00:00	7
209	6	2019-05-18 07:00:00	2019-05-18 15:00:00	14
210	6	2019-04-30 23:00:00	2019-05-01 07:00:00	18
211	4	2019-05-07 15:00:00	2019-05-08 03:00:00	80
212	7	2019-05-18 07:00:00	2019-05-18 15:00:00	62
213	1	2019-05-04 07:00:00	2019-05-04 15:00:00	66
214	5	2019-04-30 15:00:00	2019-04-30 23:00:00	59
215	6	2019-05-10 23:00:00	2019-05-11 11:00:00	45
216	5	2019-04-21 07:00:00	2019-04-21 15:00:00	16
217	6	2019-05-02 15:00:00	2019-05-02 23:00:00	86
218	7	2019-04-21 23:00:00	2019-04-22 07:00:00	76
219	7	2019-05-14 23:00:00	2019-05-15 07:00:00	7
220	3	2019-04-27 15:00:00	2019-04-28 03:00:00	26
221	1	2019-05-07 07:00:00	2019-05-07 19:00:00	31
222	3	2019-04-29 23:00:00	2019-04-30 07:00:00	16
223	2	2019-05-07 23:00:00	2019-05-08 11:00:00	89
224	4	2019-05-15 23:00:00	2019-05-16 07:00:00	82
225	3	2019-05-11 15:00:00	2019-05-12 03:00:00	79
226	5	2019-04-26 15:00:00	2019-04-26 23:00:00	67
227	3	2019-04-25 07:00:00	2019-04-25 19:00:00	70
228	1	2019-05-18 23:00:00	2019-05-19 11:00:00	74
229	1	2019-05-17 23:00:00	2019-05-18 11:00:00	47
230	4	2019-04-23 15:00:00	2019-04-24 03:00:00	93
231	4	2019-04-20 07:00:00	2019-04-20 19:00:00	54
232	6	2019-04-20 07:00:00	2019-04-20 15:00:00	96
233	6	2019-04-21 23:00:00	2019-04-22 11:00:00	63
234	2	2019-05-20 07:00:00	2019-05-20 15:00:00	41
235	4	2019-04-29 15:00:00	2019-04-29 23:00:00	28
236	6	2019-04-28 23:00:00	2019-04-29 11:00:00	52
237	5	2019-04-29 15:00:00	2019-04-30 03:00:00	14
238	4	2019-04-22 15:00:00	2019-04-22 23:00:00	28
239	6	2019-04-23 23:00:00	2019-04-24 11:00:00	57
240	6	2019-04-28 23:00:00	2019-04-29 11:00:00	88
241	7	2019-04-29 23:00:00	2019-04-30 11:00:00	33
242	3	2019-04-27 23:00:00	2019-04-28 11:00:00	36
243	4	2019-05-09 15:00:00	2019-05-09 23:00:00	5
244	3	2019-05-16 15:00:00	2019-05-17 03:00:00	67
245	6	2019-05-04 23:00:00	2019-05-05 11:00:00	57
246	4	2019-05-17 23:00:00	2019-05-18 11:00:00	35
247	4	2019-04-22 07:00:00	2019-04-22 19:00:00	68
248	6	2019-05-18 07:00:00	2019-05-18 15:00:00	69
249	2	2019-04-26 15:00:00	2019-04-26 23:00:00	75
250	7	2019-05-20 23:00:00	2019-05-21 11:00:00	90
251	6	2019-04-26 23:00:00	2019-04-27 07:00:00	32
252	2	2019-04-22 07:00:00	2019-04-22 19:00:00	80
253	1	2019-04-25 07:00:00	2019-04-25 15:00:00	7
254	6	2019-04-29 23:00:00	2019-04-30 07:00:00	83
255	3	2019-05-18 07:00:00	2019-05-18 19:00:00	32
256	4	2019-05-07 15:00:00	2019-05-08 03:00:00	85
257	7	2019-04-25 07:00:00	2019-04-25 19:00:00	31
258	1	2019-04-25 23:00:00	2019-04-26 11:00:00	48
259	2	2019-04-24 07:00:00	2019-04-24 15:00:00	11
260	4	2019-05-14 15:00:00	2019-05-15 03:00:00	27
261	3	2019-05-03 07:00:00	2019-05-03 15:00:00	69
262	1	2019-05-04 07:00:00	2019-05-04 15:00:00	93
263	5	2019-05-10 07:00:00	2019-05-10 19:00:00	66
264	1	2019-05-10 23:00:00	2019-05-11 07:00:00	35
265	3	2019-05-04 07:00:00	2019-05-04 19:00:00	104
266	4	2019-05-16 15:00:00	2019-05-17 03:00:00	77
267	7	2019-05-13 15:00:00	2019-05-13 23:00:00	7
268	1	2019-05-03 23:00:00	2019-05-04 11:00:00	76
269	1	2019-04-27 07:00:00	2019-04-27 19:00:00	85
270	3	2019-05-03 07:00:00	2019-05-03 15:00:00	101
271	1	2019-05-12 07:00:00	2019-05-12 19:00:00	59
272	5	2019-04-23 15:00:00	2019-04-24 03:00:00	88
273	5	2019-05-04 07:00:00	2019-05-04 19:00:00	65
274	5	2019-05-07 23:00:00	2019-05-08 11:00:00	96
275	7	2019-05-05 15:00:00	2019-05-05 23:00:00	103
276	4	2019-05-03 23:00:00	2019-05-04 07:00:00	47
277	6	2019-05-19 07:00:00	2019-05-19 15:00:00	71
278	7	2019-04-25 23:00:00	2019-04-26 07:00:00	23
279	5	2019-05-09 23:00:00	2019-05-10 11:00:00	88
280	1	2019-05-17 15:00:00	2019-05-17 23:00:00	79
281	6	2019-04-25 15:00:00	2019-04-25 23:00:00	85
282	1	2019-05-02 15:00:00	2019-05-02 23:00:00	104
283	4	2019-05-14 15:00:00	2019-05-15 03:00:00	44
284	5	2019-04-29 07:00:00	2019-04-29 15:00:00	54
285	3	2019-05-13 07:00:00	2019-05-13 19:00:00	97
286	1	2019-05-15 23:00:00	2019-05-16 07:00:00	55
287	6	2019-05-20 07:00:00	2019-05-20 19:00:00	24
288	3	2019-04-21 23:00:00	2019-04-22 07:00:00	29
289	1	2019-04-27 07:00:00	2019-04-27 15:00:00	63
290	3	2019-05-03 23:00:00	2019-05-04 11:00:00	99
291	1	2019-05-13 23:00:00	2019-05-14 07:00:00	24
292	1	2019-04-26 07:00:00	2019-04-26 15:00:00	30
293	3	2019-04-22 15:00:00	2019-04-22 23:00:00	72
294	1	2019-05-18 15:00:00	2019-05-18 23:00:00	9
295	1	2019-05-08 15:00:00	2019-05-09 03:00:00	52
296	4	2019-05-17 07:00:00	2019-05-17 19:00:00	20
297	5	2019-05-11 07:00:00	2019-05-11 19:00:00	89
298	1	2019-05-07 07:00:00	2019-05-07 19:00:00	101
299	3	2019-04-22 07:00:00	2019-04-22 15:00:00	31
300	5	2019-04-24 23:00:00	2019-04-25 07:00:00	62
301	1	2019-05-14 23:00:00	2019-05-15 07:00:00	40
302	5	2019-05-13 15:00:00	2019-05-14 03:00:00	98
303	7	2019-04-22 07:00:00	2019-04-22 19:00:00	74
304	3	2019-04-27 23:00:00	2019-04-28 07:00:00	64
305	5	2019-04-23 07:00:00	2019-04-23 19:00:00	86
306	1	2019-05-03 07:00:00	2019-05-03 19:00:00	65
307	3	2019-05-18 15:00:00	2019-05-19 03:00:00	31
308	6	2019-04-21 15:00:00	2019-04-21 23:00:00	73
309	1	2019-05-15 23:00:00	2019-05-16 07:00:00	32
310	3	2019-04-25 15:00:00	2019-04-25 23:00:00	62
311	5	2019-04-21 15:00:00	2019-04-22 03:00:00	72
312	1	2019-05-02 07:00:00	2019-05-02 15:00:00	97
313	3	2019-05-17 15:00:00	2019-05-18 03:00:00	81
314	1	2019-04-25 07:00:00	2019-04-25 19:00:00	30
315	1	2019-05-03 07:00:00	2019-05-03 19:00:00	91
316	5	2019-05-13 23:00:00	2019-05-14 07:00:00	98
317	5	2019-04-23 15:00:00	2019-04-23 23:00:00	66
318	5	2019-05-12 23:00:00	2019-05-13 07:00:00	19
319	4	2019-05-04 15:00:00	2019-05-05 03:00:00	36
320	4	2019-04-24 15:00:00	2019-04-24 23:00:00	16
321	4	2019-04-28 07:00:00	2019-04-28 15:00:00	68
322	3	2019-05-02 23:00:00	2019-05-03 11:00:00	37
323	1	2019-05-12 15:00:00	2019-05-12 23:00:00	87
324	6	2019-05-17 23:00:00	2019-05-18 11:00:00	39
325	4	2019-04-23 15:00:00	2019-04-24 03:00:00	34
326	5	2019-05-10 23:00:00	2019-05-11 07:00:00	12
327	6	2019-05-09 07:00:00	2019-05-09 19:00:00	35
328	6	2019-04-22 15:00:00	2019-04-23 03:00:00	96
329	2	2019-05-08 15:00:00	2019-05-09 03:00:00	54
330	2	2019-05-11 07:00:00	2019-05-11 19:00:00	31
331	3	2019-05-07 23:00:00	2019-05-08 07:00:00	53
332	3	2019-05-12 15:00:00	2019-05-12 23:00:00	41
333	1	2019-05-03 23:00:00	2019-05-04 11:00:00	8
334	3	2019-05-15 15:00:00	2019-05-16 03:00:00	64
335	1	2019-04-21 07:00:00	2019-04-21 19:00:00	9
336	3	2019-04-29 15:00:00	2019-04-29 23:00:00	13
337	7	2019-04-30 23:00:00	2019-05-01 11:00:00	5
338	1	2019-04-26 15:00:00	2019-04-26 23:00:00	64
339	6	2019-05-16 23:00:00	2019-05-17 07:00:00	10
340	6	2019-04-21 15:00:00	2019-04-22 03:00:00	96
341	5	2019-05-16 23:00:00	2019-05-17 07:00:00	75
342	6	2019-05-08 07:00:00	2019-05-08 19:00:00	74
343	3	2019-05-11 23:00:00	2019-05-12 11:00:00	87
344	3	2019-05-02 23:00:00	2019-05-03 11:00:00	32
345	4	2019-04-24 15:00:00	2019-04-25 03:00:00	63
346	1	2019-04-25 07:00:00	2019-04-25 15:00:00	19
347	3	2019-05-18 07:00:00	2019-05-18 19:00:00	33
348	6	2019-04-29 15:00:00	2019-04-29 23:00:00	62
349	7	2019-05-19 23:00:00	2019-05-20 07:00:00	101
350	3	2019-05-20 07:00:00	2019-05-20 19:00:00	87
351	6	2019-04-22 15:00:00	2019-04-23 03:00:00	55
352	5	2019-05-02 23:00:00	2019-05-03 07:00:00	98
353	4	2019-05-12 15:00:00	2019-05-13 03:00:00	5
354	5	2019-05-05 07:00:00	2019-05-05 15:00:00	30
355	2	2019-05-15 23:00:00	2019-05-16 11:00:00	57
356	7	2019-05-14 07:00:00	2019-05-14 15:00:00	16
357	7	2019-05-07 23:00:00	2019-05-08 07:00:00	50
358	1	2019-05-06 15:00:00	2019-05-07 03:00:00	73
359	2	2019-04-26 15:00:00	2019-04-27 03:00:00	48
360	5	2019-05-20 07:00:00	2019-05-20 15:00:00	101
361	2	2019-04-28 23:00:00	2019-04-29 07:00:00	52
362	2	2019-05-19 23:00:00	2019-05-20 07:00:00	77
363	1	2019-05-07 23:00:00	2019-05-08 11:00:00	15
364	5	2019-05-07 23:00:00	2019-05-08 07:00:00	6
365	7	2019-04-21 15:00:00	2019-04-21 23:00:00	46
366	1	2019-04-28 23:00:00	2019-04-29 11:00:00	96
367	2	2019-04-23 23:00:00	2019-04-24 11:00:00	102
368	2	2019-05-20 23:00:00	2019-05-21 11:00:00	75
369	5	2019-04-22 15:00:00	2019-04-22 23:00:00	52
370	1	2019-05-12 23:00:00	2019-05-13 11:00:00	17
371	1	2019-04-28 23:00:00	2019-04-29 11:00:00	74
372	3	2019-05-15 07:00:00	2019-05-15 19:00:00	55
373	2	2019-05-20 23:00:00	2019-05-21 11:00:00	30
374	7	2019-05-05 23:00:00	2019-05-06 11:00:00	28
375	2	2019-05-07 15:00:00	2019-05-08 03:00:00	65
376	4	2019-04-21 15:00:00	2019-04-22 03:00:00	77
377	2	2019-05-14 07:00:00	2019-05-14 15:00:00	69
378	2	2019-05-05 23:00:00	2019-05-06 11:00:00	6
379	7	2019-05-18 07:00:00	2019-05-18 19:00:00	8
380	1	2019-05-12 23:00:00	2019-05-13 11:00:00	98
381	6	2019-05-11 15:00:00	2019-05-11 23:00:00	23
382	3	2019-05-07 15:00:00	2019-05-07 23:00:00	31
383	6	2019-05-17 07:00:00	2019-05-17 15:00:00	59
384	5	2019-05-16 07:00:00	2019-05-16 15:00:00	15
385	2	2019-04-22 15:00:00	2019-04-23 03:00:00	31
386	2	2019-04-24 15:00:00	2019-04-25 03:00:00	78
387	2	2019-05-05 15:00:00	2019-05-06 03:00:00	87
388	7	2019-05-05 15:00:00	2019-05-05 23:00:00	54
389	5	2019-05-14 07:00:00	2019-05-14 19:00:00	74
390	6	2019-04-21 15:00:00	2019-04-21 23:00:00	63
391	2	2019-05-03 23:00:00	2019-05-04 11:00:00	100
392	3	2019-05-04 07:00:00	2019-05-04 19:00:00	11
393	7	2019-05-08 07:00:00	2019-05-08 19:00:00	6
394	3	2019-04-22 23:00:00	2019-04-23 11:00:00	20
395	1	2019-04-23 15:00:00	2019-04-24 03:00:00	63
396	1	2019-04-22 15:00:00	2019-04-23 03:00:00	76
397	2	2019-05-20 07:00:00	2019-05-20 15:00:00	18
398	2	2019-05-08 07:00:00	2019-05-08 19:00:00	82
399	6	2019-04-20 15:00:00	2019-04-20 23:00:00	77
400	4	2019-04-23 15:00:00	2019-04-24 03:00:00	67
401	4	2019-05-04 15:00:00	2019-05-04 23:00:00	7
402	7	2019-05-09 07:00:00	2019-05-09 19:00:00	78
403	5	2019-05-18 23:00:00	2019-05-19 07:00:00	48
404	5	2019-05-13 23:00:00	2019-05-14 07:00:00	88
405	7	2019-05-02 15:00:00	2019-05-03 03:00:00	66
406	2	2019-04-25 23:00:00	2019-04-26 07:00:00	84
407	4	2019-05-13 23:00:00	2019-05-14 11:00:00	16
408	2	2019-04-24 15:00:00	2019-04-25 03:00:00	83
409	6	2019-04-23 15:00:00	2019-04-24 03:00:00	82
410	2	2019-05-18 07:00:00	2019-05-18 19:00:00	62
411	3	2019-04-28 07:00:00	2019-04-28 15:00:00	56
412	2	2019-05-02 07:00:00	2019-05-02 15:00:00	32
413	7	2019-04-24 07:00:00	2019-04-24 15:00:00	87
414	6	2019-04-23 23:00:00	2019-04-24 07:00:00	35
415	4	2019-05-01 07:00:00	2019-05-01 19:00:00	93
416	6	2019-05-18 07:00:00	2019-05-18 19:00:00	104
417	5	2019-04-24 23:00:00	2019-04-25 07:00:00	62
418	3	2019-05-11 07:00:00	2019-05-11 15:00:00	83
419	2	2019-04-21 07:00:00	2019-04-21 15:00:00	67
420	7	2019-05-14 15:00:00	2019-05-14 23:00:00	72
421	5	2019-04-30 07:00:00	2019-04-30 15:00:00	93
422	3	2019-05-05 23:00:00	2019-05-06 07:00:00	59
423	6	2019-05-17 23:00:00	2019-05-18 11:00:00	20
424	5	2019-05-07 07:00:00	2019-05-07 15:00:00	60
425	6	2019-04-23 07:00:00	2019-04-23 19:00:00	43
426	3	2019-04-26 07:00:00	2019-04-26 19:00:00	38
427	3	2019-05-01 23:00:00	2019-05-02 07:00:00	35
428	6	2019-04-30 15:00:00	2019-05-01 03:00:00	35
429	3	2019-05-17 23:00:00	2019-05-18 07:00:00	50
430	1	2019-05-10 23:00:00	2019-05-11 07:00:00	74
431	2	2019-05-12 07:00:00	2019-05-12 19:00:00	44
432	1	2019-04-29 23:00:00	2019-04-30 07:00:00	103
433	3	2019-05-11 15:00:00	2019-05-11 23:00:00	25
434	1	2019-04-22 23:00:00	2019-04-23 07:00:00	17
435	4	2019-04-26 07:00:00	2019-04-26 15:00:00	53
436	6	2019-04-26 23:00:00	2019-04-27 11:00:00	76
437	1	2019-05-19 15:00:00	2019-05-20 03:00:00	35
438	7	2019-05-11 23:00:00	2019-05-12 07:00:00	46
439	3	2019-05-11 07:00:00	2019-05-11 15:00:00	51
440	6	2019-04-28 23:00:00	2019-04-29 07:00:00	33
441	7	2019-05-14 15:00:00	2019-05-15 03:00:00	104
442	7	2019-05-18 07:00:00	2019-05-18 19:00:00	89
443	7	2019-04-23 07:00:00	2019-04-23 19:00:00	50
444	7	2019-05-02 15:00:00	2019-05-03 03:00:00	17
445	2	2019-05-18 23:00:00	2019-05-19 11:00:00	74
446	6	2019-05-02 07:00:00	2019-05-02 15:00:00	54
447	1	2019-05-19 15:00:00	2019-05-20 03:00:00	58
448	6	2019-04-27 23:00:00	2019-04-28 07:00:00	69
449	7	2019-04-25 07:00:00	2019-04-25 19:00:00	29
450	1	2019-04-23 23:00:00	2019-04-24 07:00:00	64
451	7	2019-04-20 23:00:00	2019-04-21 07:00:00	96
452	1	2019-05-08 07:00:00	2019-05-08 15:00:00	29
453	7	2019-05-15 23:00:00	2019-05-16 07:00:00	9
454	5	2019-04-22 15:00:00	2019-04-22 23:00:00	17
455	3	2019-04-27 07:00:00	2019-04-27 15:00:00	19
456	6	2019-04-28 15:00:00	2019-04-29 03:00:00	83
457	6	2019-05-16 07:00:00	2019-05-16 19:00:00	55
458	7	2019-05-16 23:00:00	2019-05-17 07:00:00	92
459	4	2019-05-12 15:00:00	2019-05-13 03:00:00	100
460	3	2019-05-03 23:00:00	2019-05-04 11:00:00	88
461	4	2019-04-29 15:00:00	2019-04-30 03:00:00	60
462	7	2019-04-28 23:00:00	2019-04-29 07:00:00	73
463	5	2019-04-20 23:00:00	2019-04-21 07:00:00	36
464	5	2019-05-06 23:00:00	2019-05-07 07:00:00	83
465	7	2019-04-30 15:00:00	2019-05-01 03:00:00	56
466	5	2019-05-04 23:00:00	2019-05-05 07:00:00	64
467	4	2019-05-03 23:00:00	2019-05-04 07:00:00	57
468	1	2019-05-15 15:00:00	2019-05-16 03:00:00	42
469	2	2019-04-26 07:00:00	2019-04-26 15:00:00	98
470	7	2019-05-04 07:00:00	2019-05-04 15:00:00	70
471	6	2019-05-15 07:00:00	2019-05-15 15:00:00	25
472	7	2019-04-30 15:00:00	2019-04-30 23:00:00	75
473	1	2019-04-29 07:00:00	2019-04-29 19:00:00	15
474	2	2019-04-28 07:00:00	2019-04-28 19:00:00	72
475	2	2019-05-09 07:00:00	2019-05-09 15:00:00	69
476	5	2019-05-10 07:00:00	2019-05-10 15:00:00	64
477	6	2019-05-01 07:00:00	2019-05-01 15:00:00	11
478	5	2019-04-27 07:00:00	2019-04-27 15:00:00	29
479	4	2019-05-09 07:00:00	2019-05-09 15:00:00	6
480	7	2019-04-23 07:00:00	2019-04-23 15:00:00	9
481	7	2019-04-20 07:00:00	2019-04-20 19:00:00	94
482	6	2019-04-21 23:00:00	2019-04-22 07:00:00	104
483	3	2019-04-27 23:00:00	2019-04-28 07:00:00	12
484	1	2019-05-06 23:00:00	2019-05-07 11:00:00	23
485	4	2019-05-02 23:00:00	2019-05-03 07:00:00	32
486	4	2019-05-05 23:00:00	2019-05-06 07:00:00	96
487	4	2019-04-25 23:00:00	2019-04-26 07:00:00	94
488	7	2019-04-30 15:00:00	2019-04-30 23:00:00	70
489	3	2019-05-07 23:00:00	2019-05-08 11:00:00	44
490	7	2019-05-04 07:00:00	2019-05-04 19:00:00	15
491	6	2019-05-11 23:00:00	2019-05-12 11:00:00	60
492	4	2019-05-12 07:00:00	2019-05-12 15:00:00	30
493	7	2019-04-29 07:00:00	2019-04-29 19:00:00	51
494	2	2019-05-11 23:00:00	2019-05-12 07:00:00	20
495	3	2019-05-11 07:00:00	2019-05-11 15:00:00	7
496	3	2019-04-28 23:00:00	2019-04-29 11:00:00	63
497	7	2019-05-05 23:00:00	2019-05-06 07:00:00	24
498	2	2019-04-21 23:00:00	2019-04-22 11:00:00	85
499	3	2019-04-25 15:00:00	2019-04-26 03:00:00	5
500	5	2019-05-11 15:00:00	2019-05-12 03:00:00	58
\.


--
-- Data for Name: agent_shift_queue; Type: TABLE DATA; Schema: public; Owner: -
--

COPY public.agent_shift_queue (shift_id, updated_on_utc, agent_id, queue_id, start_time_utc, end_time_utc, source, author, is_active, id) FROM stdin;
1	2019-05-06 21:54:37	73	4	2019-05-06 15:00:00	2019-05-07 03:00:00	agatha	test-bp@test-bp.com	t	1072
1	2019-05-06 21:54:37	83	5	2019-05-06 15:00:00	2019-05-06 23:00:00	agatha	test-bp@test-bp.com	t	1073
4	2019-05-06 21:54:37	96	10	2019-05-06 23:00:00	2019-05-07 11:00:00	agatha	test-bp@test-bp.com	t	1074
5	2019-05-06 22:01:23	92	1	2019-05-06 07:00:00	2019-05-06 15:00:00	agatha	test-bp@test-bp.com	t	1077
5	2019-05-06 22:01:23	92	8	2019-05-06 07:00:00	2019-05-06 15:00:00	agatha	test-bp@test-bp.com	t	1078
6	2019-05-10 09:12:16	67	6	2019-05-09 23:00:00	2019-05-10 11:00:00	agatha	test-bp@test-bp.com	t	1083
5	2019-05-10 12:41:08	64	10	2019-05-10 09:00:00	2019-05-10 17:00:00	agatha	test-bp@test-bp.com	t	1084
5	2019-05-06 22:01:23	92	3	2019-05-06 07:00:00	2019-05-06 15:00:00	agatha	test-bp@test-bp.com	t	1058
5	2019-05-06 22:01:23	92	5	2019-05-06 07:00:00	2019-05-06 15:00:00	agatha	test-bp@test-bp.com	t	1063
7	2019-05-06 13:50:11	75	3	2019-05-06 07:00:00	2019-05-06 15:00:00	agatha	test-bp@test-bp.com	t	1064
7	2019-05-06 13:50:11	75	5	2019-05-06 07:00:00	2019-05-06 15:00:00	agatha	test-bp@test-bp.com	t	1065
3	2019-05-06 13:50:11	90	3	2019-05-06 07:00:00	2019-05-06 15:00:00	agatha	test-bp@test-bp.com	t	1066
3	2019-05-06 13:50:11	90	5	2019-05-06 07:00:00	2019-05-06 15:00:00	agatha	test-bp@test-bp.com	t	1067
4	2019-05-06 13:50:11	12	3	2019-05-06 07:00:00	2019-05-06 15:00:00	agatha	test-bp@test-bp.com	t	1060
4	2019-05-06 13:50:11	12	5	2019-05-06 07:00:00	2019-05-06 15:00:00	agatha	test-bp@test-bp.com	t	1061
1	2019-05-06 13:50:58	23	3	2019-05-06 23:00:00	2019-05-07 11:00:00	agatha	test-bp@test-bp.com	t	1068
1	2019-05-06 13:50:58	23	7	2019-05-06 23:00:00	2019-05-07 11:00:00	agatha	test-bp@test-bp.com	t	1069
3	2019-05-06 13:50:58	101	3	2019-05-06 23:00:00	2019-05-07 07:00:00	agatha	test-bp@test-bp.com	t	1070
3	2019-05-06 13:50:58	101	4	2019-05-06 23:00:00	2019-05-07 07:00:00	agatha	test-bp@test-bp.com	t	1071
\.


--
-- Data for Name: log; Type: TABLE DATA; Schema: public; Owner: -
--

COPY public.log (action, queue_id, agent_id, author, shift_id, created_on_utc, start_time_utc, end_time_utc, author_old, shift_id_old, created_on_utc_old, start_time_utc_old, end_time_utc_old, source_old) FROM stdin;
INSERT	3	28	test-bp@test-bp.com	7	2019-05-05 14:43:56	2019-05-05 23:00:00	2019-05-06 11:00:00	\N	\N	\N	\N	\N	\N
DELETE	1	75	test-bp@test-bp.com	2	2019-05-06 13:39:21	\N	\N	test-bp@test-bp.com	2	2019-05-05 13:19:46.6626	\N	\N	agatha
INSERT	3	75	test-bp@test-bp.com	7	2019-05-06 13:39:34	2019-05-06 07:00:00	2019-05-06 15:00:00	\N	\N	\N	\N	\N	\N
INSERT	8	12	test-bp@test-bp.com	4	2019-05-06 13:41:50	2019-05-06 07:00:00	2019-05-06 15:00:00	\N	\N	\N	\N	\N	\N
UPDATE	1	92	test-bp@test-bp.com	5	2019-05-06 13:41:50	2019-05-06 07:00:00	2019-05-06 15:00:00	test-bp@test-bp.com	3	2019-05-05 13:19:46.6626	\N	\N	agatha
INSERT	8	92	test-bp@test-bp.com	5	2019-05-06 13:41:50	2019-05-06 07:00:00	2019-05-06 15:00:00	\N	\N	\N	\N	\N	\N
INSERT	8	90	test-bp@test-bp.com	3	2019-05-06 13:41:50	2019-05-06 07:00:00	2019-05-06 15:00:00	\N	\N	\N	\N	\N	\N
DELETE	1	12	test-bp@test-bp.com	4	2019-05-06 13:42:49	2019-05-06 07:00:00	2019-05-06 15:00:00	test-bp@test-bp.com	4	2019-05-06 13:41:50	2019-05-06 07:00:00	2019-05-06 15:00:00	agatha
DELETE	8	12	test-bp@test-bp.com	4	2019-05-06 13:42:49	2019-05-06 07:00:00	2019-05-06 15:00:00	test-bp@test-bp.com	4	2019-05-06 13:41:50	2019-05-06 07:00:00	2019-05-06 15:00:00	agatha
INSERT	6	67	test-bp@test-bp.com	6	2019-05-10 09:12:16	2019-05-09 23:00:00	2019-05-10 11:00:00	\N	\N	\N	\N	\N	\N
INSERT	10	64	test-bp@test-bp.com	5	2019-05-10 12:41:08	2019-05-10 09:00:00	2019-05-10 17:00:00	\N	\N	\N	\N	\N	\N
INSERT	9	12	test-bp@test-bp.com	4	2019-05-06 13:43:16	2019-05-06 07:00:00	2019-05-06 15:00:00	\N	\N	\N	\N	\N	\N
INSERT	3	12	test-bp@test-bp.com	4	2019-05-06 13:44:22	2019-05-06 07:00:00	2019-05-06 15:00:00	\N	\N	\N	\N	\N	\N
INSERT	3	80	test-bp@test-bp.com	2	2019-05-06 13:46:39	2019-04-22 07:00:00	2019-04-22 19:00:00	\N	\N	\N	\N	\N	\N
INSERT	1	12	test-bp@test-bp.com	4	2019-05-06 13:49:38	2019-05-06 07:00:00	2019-05-06 15:00:00	\N	\N	\N	\N	\N	\N
INSERT	3	92	test-bp@test-bp.com	5	2019-05-06 13:50:01	2019-05-06 07:00:00	2019-05-06 15:00:00	\N	\N	\N	\N	\N	\N
INSERT	8	92	test-bp@test-bp.com	5	2019-05-06 13:50:01	2019-05-06 07:00:00	2019-05-06 15:00:00	\N	\N	\N	\N	\N	\N
DELETE	1	12	test-bp@test-bp.com	4	2019-05-06 13:50:11	2019-05-06 07:00:00	2019-05-06 15:00:00	test-bp@test-bp.com	4	2019-05-06 13:49:38	2019-05-06 07:00:00	2019-05-06 15:00:00	agatha
DELETE	8	92	test-bp@test-bp.com	5	2019-05-06 13:50:11	2019-05-06 07:00:00	2019-05-06 15:00:00	test-bp@test-bp.com	5	2019-05-06 13:50:01	2019-05-06 07:00:00	2019-05-06 15:00:00	agatha
INSERT	3	12	test-bp@test-bp.com	4	2019-05-06 13:50:11	2019-05-06 07:00:00	2019-05-06 15:00:00	\N	\N	\N	\N	\N	\N
INSERT	5	12	test-bp@test-bp.com	4	2019-05-06 13:50:11	2019-05-06 07:00:00	2019-05-06 15:00:00	\N	\N	\N	\N	\N	\N
INSERT	5	92	test-bp@test-bp.com	5	2019-05-06 13:50:11	2019-05-06 07:00:00	2019-05-06 15:00:00	\N	\N	\N	\N	\N	\N
INSERT	3	75	test-bp@test-bp.com	7	2019-05-06 13:50:11	2019-05-06 07:00:00	2019-05-06 15:00:00	\N	\N	\N	\N	\N	\N
INSERT	5	75	test-bp@test-bp.com	7	2019-05-06 13:50:11	2019-05-06 07:00:00	2019-05-06 15:00:00	\N	\N	\N	\N	\N	\N
INSERT	3	90	test-bp@test-bp.com	3	2019-05-06 13:50:11	2019-05-06 07:00:00	2019-05-06 15:00:00	\N	\N	\N	\N	\N	\N
INSERT	5	90	test-bp@test-bp.com	3	2019-05-06 13:50:11	2019-05-06 07:00:00	2019-05-06 15:00:00	\N	\N	\N	\N	\N	\N
INSERT	3	23	test-bp@test-bp.com	1	2019-05-06 13:50:58	2019-05-06 23:00:00	2019-05-07 11:00:00	\N	\N	\N	\N	\N	\N
INSERT	7	23	test-bp@test-bp.com	1	2019-05-06 13:50:58	2019-05-06 23:00:00	2019-05-07 11:00:00	\N	\N	\N	\N	\N	\N
INSERT	3	101	test-bp@test-bp.com	3	2019-05-06 13:50:58	2019-05-06 23:00:00	2019-05-07 07:00:00	\N	\N	\N	\N	\N	\N
INSERT	4	101	test-bp@test-bp.com	3	2019-05-06 13:50:58	2019-05-06 23:00:00	2019-05-07 07:00:00	\N	\N	\N	\N	\N	\N
INSERT	4	73	test-bp@test-bp.com	1	2019-05-06 21:54:37	2019-05-06 15:00:00	2019-05-07 03:00:00	\N	\N	\N	\N	\N	\N
INSERT	5	83	test-bp@test-bp.com	1	2019-05-06 21:54:37	2019-05-06 15:00:00	2019-05-06 23:00:00	\N	\N	\N	\N	\N	\N
INSERT	10	96	test-bp@test-bp.com	4	2019-05-06 21:54:37	2019-05-06 23:00:00	2019-05-07 11:00:00	\N	\N	\N	\N	\N	\N
INSERT	1	92	test-bp@test-bp.com	5	2019-05-06 22:01:23	2019-05-06 07:00:00	2019-05-06 15:00:00	\N	\N	\N	\N	\N	\N
INSERT	8	92	test-bp@test-bp.com	5	2019-05-06 22:01:23	2019-05-06 07:00:00	2019-05-06 15:00:00	\N	\N	\N	\N	\N	\N
INSERT	\N	44	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	85	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	53	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	81	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	48	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	58	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	80	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	78	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	37	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	101	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	18	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	50	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	98	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	16	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	81	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	95	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	59	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	52	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	86	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	58	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	18	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	71	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	45	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	31	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	74	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	88	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	55	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	32	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	97	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	98	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	94	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	62	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	30	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	69	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	29	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	28	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	91	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	14	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	71	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	12	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	59	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	70	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	61	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	89	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	7	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	68	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	79	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	85	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	101	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	22	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	71	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	65	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	101	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	12	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	96	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	48	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	13	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	39	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	54	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	93	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	87	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	70	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	22	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	65	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	68	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	37	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	67	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	86	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	40	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	80	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	43	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	18	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	72	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	85	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	20	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	7	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	100	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	27	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	5	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	92	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	19	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	30	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	92	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	57	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	43	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	54	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	16	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	45	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	83	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	103	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	66	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	58	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	53	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	29	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	36	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	56	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	40	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	52	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	37	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	30	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	70	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	89	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	26	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	86	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	40	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	66	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	92	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	30	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	27	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	72	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	30	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	26	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	41	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	93	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	40	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	46	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	103	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	103	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	26	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	38	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	37	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	89	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	64	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	55	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	63	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	36	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	67	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	75	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	39	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	31	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	30	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	71	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	12	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	34	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	8	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	65	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	65	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	38	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	65	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	75	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	75	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	75	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	30	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	14	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	97	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	66	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	90	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	16	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	48	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	47	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	61	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	90	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	17	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	12	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	61	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	99	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	62	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	9	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	43	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	37	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	68	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	60	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	87	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	67	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	79	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	59	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	43	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	21	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	67	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	59	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	66	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	47	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	71	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	42	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	50	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	86	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	40	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	101	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	74	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	103	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	43	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	81	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	66	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	57	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	56	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	40	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	10	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	36	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	28	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	24	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	76	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	47	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	86	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	84	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	104	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	48	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	67	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	30	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	56	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	30	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	27	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	41	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	37	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	35	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	32	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	5	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	41	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	7	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	14	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	18	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	80	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	62	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	66	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	59	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	45	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	16	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	86	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	76	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	7	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	26	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	31	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	16	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	89	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	82	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	79	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	67	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	70	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	74	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	47	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	93	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	54	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	96	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	63	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	41	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	28	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	52	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	14	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	28	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	57	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	88	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	33	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	36	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	5	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	67	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	57	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	35	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	68	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	69	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	75	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	90	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	32	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	80	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	7	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	83	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	32	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	85	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	31	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	48	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	11	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	27	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	69	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	93	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	66	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	35	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	104	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	77	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	7	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	76	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	85	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	101	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	59	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	88	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	65	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	96	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	103	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	47	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	71	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	23	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	88	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	79	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	85	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	104	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	44	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	54	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	97	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	55	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	24	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	29	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	63	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	99	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	24	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	30	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	72	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	9	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	52	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	20	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	89	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	101	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	31	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	62	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	40	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	98	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	74	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	64	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	86	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	65	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	31	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	73	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	32	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	62	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	72	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	97	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	81	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	30	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	91	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	98	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	66	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	19	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	36	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	16	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	68	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	37	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	87	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	39	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	34	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	12	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	35	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	96	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	54	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	31	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	53	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	41	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	8	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	64	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	9	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	13	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	5	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	64	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	10	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	96	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	75	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	74	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	87	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	32	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	63	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	19	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	33	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	62	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	101	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	87	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	55	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	98	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	5	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	30	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	57	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	16	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	50	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	73	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	48	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	101	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	52	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	77	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	15	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	6	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	46	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	96	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	102	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	75	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	52	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	17	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	74	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	55	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	30	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	28	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	65	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	77	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	69	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	6	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	8	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	98	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	23	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	31	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	59	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	15	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	31	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	78	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	87	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	54	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	74	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	63	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	100	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	11	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	6	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	20	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	63	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	76	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	18	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	82	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	77	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	67	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	7	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	78	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	48	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	88	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	66	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	84	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	16	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	83	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	82	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	62	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	56	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	32	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	87	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	35	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	93	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	104	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	62	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	83	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	67	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	72	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	93	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	59	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	20	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	60	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	43	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	38	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	35	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	35	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	50	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	74	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	44	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	103	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	25	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	17	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	53	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	76	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	35	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	46	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	51	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	33	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	104	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	89	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	50	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	17	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	74	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	54	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	58	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	69	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	29	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	64	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	96	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	29	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	9	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	17	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	19	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	83	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	55	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	92	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	100	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	88	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	60	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	73	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	36	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	83	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	56	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	64	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	57	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	42	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	98	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	70	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	25	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	75	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	15	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	72	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	69	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	64	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	11	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	29	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	6	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	9	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	94	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	104	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	12	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	23	test-bp@test-bp.com	1	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	32	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	96	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	94	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	70	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	44	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	15	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	60	test-bp@test-bp.com	6	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	30	test-bp@test-bp.com	4	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	51	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	20	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	7	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	63	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	24	test-bp@test-bp.com	7	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	85	test-bp@test-bp.com	2	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	5	test-bp@test-bp.com	3	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	\N	58	test-bp@test-bp.com	5	2019-05-05 13:10:19.429907	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	44	test-bp@test-bp.com	5	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	85	test-bp@test-bp.com	7	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	53	test-bp@test-bp.com	6	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	81	test-bp@test-bp.com	5	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	48	test-bp@test-bp.com	4	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	58	test-bp@test-bp.com	7	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	80	test-bp@test-bp.com	1	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	78	test-bp@test-bp.com	1	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	37	test-bp@test-bp.com	1	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	101	test-bp@test-bp.com	3	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	18	test-bp@test-bp.com	3	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	50	test-bp@test-bp.com	3	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	98	test-bp@test-bp.com	4	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	16	test-bp@test-bp.com	2	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	95	test-bp@test-bp.com	1	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	59	test-bp@test-bp.com	1	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	52	test-bp@test-bp.com	5	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	86	test-bp@test-bp.com	7	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	71	test-bp@test-bp.com	3	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	45	test-bp@test-bp.com	4	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	31	test-bp@test-bp.com	1	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	74	test-bp@test-bp.com	4	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	88	test-bp@test-bp.com	6	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	55	test-bp@test-bp.com	3	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	32	test-bp@test-bp.com	7	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	97	test-bp@test-bp.com	2	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	94	test-bp@test-bp.com	1	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	62	test-bp@test-bp.com	3	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	30	test-bp@test-bp.com	5	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	69	test-bp@test-bp.com	7	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	29	test-bp@test-bp.com	1	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	28	test-bp@test-bp.com	1	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	91	test-bp@test-bp.com	4	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	14	test-bp@test-bp.com	3	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	12	test-bp@test-bp.com	4	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	70	test-bp@test-bp.com	2	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	61	test-bp@test-bp.com	6	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	89	test-bp@test-bp.com	4	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	7	test-bp@test-bp.com	7	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	68	test-bp@test-bp.com	6	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	79	test-bp@test-bp.com	1	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	22	test-bp@test-bp.com	3	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	65	test-bp@test-bp.com	5	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	96	test-bp@test-bp.com	4	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	13	test-bp@test-bp.com	3	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	39	test-bp@test-bp.com	3	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	54	test-bp@test-bp.com	7	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	93	test-bp@test-bp.com	1	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	87	test-bp@test-bp.com	4	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	67	test-bp@test-bp.com	6	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	40	test-bp@test-bp.com	5	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	43	test-bp@test-bp.com	4	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	72	test-bp@test-bp.com	4	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	20	test-bp@test-bp.com	4	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	100	test-bp@test-bp.com	2	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	27	test-bp@test-bp.com	3	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	5	test-bp@test-bp.com	7	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	92	test-bp@test-bp.com	3	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	19	test-bp@test-bp.com	3	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	57	test-bp@test-bp.com	6	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	83	test-bp@test-bp.com	1	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	103	test-bp@test-bp.com	5	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	66	test-bp@test-bp.com	1	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	36	test-bp@test-bp.com	3	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	56	test-bp@test-bp.com	5	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	26	test-bp@test-bp.com	4	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	41	test-bp@test-bp.com	1	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	46	test-bp@test-bp.com	7	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	38	test-bp@test-bp.com	6	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	64	test-bp@test-bp.com	1	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	63	test-bp@test-bp.com	5	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	75	test-bp@test-bp.com	2	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	34	test-bp@test-bp.com	5	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	8	test-bp@test-bp.com	6	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	90	test-bp@test-bp.com	3	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	47	test-bp@test-bp.com	4	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	17	test-bp@test-bp.com	7	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	99	test-bp@test-bp.com	1	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	9	test-bp@test-bp.com	2	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	60	test-bp@test-bp.com	3	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	21	test-bp@test-bp.com	3	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	42	test-bp@test-bp.com	2	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	10	test-bp@test-bp.com	7	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	24	test-bp@test-bp.com	2	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	76	test-bp@test-bp.com	7	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	84	test-bp@test-bp.com	3	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	104	test-bp@test-bp.com	2	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	35	test-bp@test-bp.com	5	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	82	test-bp@test-bp.com	4	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	33	test-bp@test-bp.com	7	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	11	test-bp@test-bp.com	2	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	77	test-bp@test-bp.com	4	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	23	test-bp@test-bp.com	7	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	73	test-bp@test-bp.com	6	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	15	test-bp@test-bp.com	1	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	6	test-bp@test-bp.com	5	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	102	test-bp@test-bp.com	2	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	25	test-bp@test-bp.com	3	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
INSERT	1	51	test-bp@test-bp.com	3	2019-05-05 13:19:46.6626	\N	\N	\N	\N	\N	\N	\N	\N
DELETE	1	28	test-bp@test-bp.com	1	2019-05-05 14:43:28	\N	\N	test-bp@test-bp.com	1	2019-05-05 13:19:46.6626	\N	\N	agatha
\.


--
-- Data for Name: queue; Type: TABLE DATA; Schema: public; Owner: -
--

COPY public.queue (id, name, purecloud_id, balkan_id, group_name) FROM stdin;
1	Call EN	\N	\N	FrontOffice
2	Chat EN	\N	\N	Urgent
3	Call FR	\N	\N	FrontOffice
4	Complaints	\N	\N	BackOffice
5	Refunds	\N	\N	BackOffice
6	Chat EN	\N	\N	General
7	Call JP	\N	\N	FrontOffice
8	Call JP	\N	\N	Urgent
9	Refunds	\N	\N	Urgent
10	Refunds	\N	\N	BackOffice
\.


--
-- Data for Name: shift; Type: TABLE DATA; Schema: public; Owner: -
--

COPY public.shift (id, name, description, length, minspacing, delete_on_utc, created_on_utc, created_by, modified_on_utc, modified_by, maxspacing) FROM stdin;
1	BO morning 8h		8	0	\N	2019-04-20 09:03:03.655815	sthomas@dickson.com	\N	\N	\N
2	BO afternoon 8h		8	0	\N	2019-04-20 09:03:03.656391	fieldsmegan@mcbride-davis.com	\N	\N	\N
3	BO night 8h		8	0	\N	2019-04-20 09:03:03.656813	sarnold@alvarez-mendez.info	\N	\N	\N
4	FO morning 12h		8	0	\N	2019-04-20 09:03:03.657163	mstephens@gmail.com	\N	\N	\N
5	FO afternoon 12h		8	0	\N	2019-04-20 09:03:03.657305	kevinnichols@yahoo.com	\N	\N	\N
6	FO night 12h		8	0	\N	2019-04-20 09:03:03.657499	smithshannon@gmail.com	\N	\N	\N
7	Complaints 8h		8	0	\N	2019-04-20 09:03:03.657699	johnsonkelli@gmail.com	\N	\N	\N
\.


--
-- Data for Name: agent; Type: TABLE DATA; Schema: public_old; Owner: -
--

COPY public_old.agent (id, first_name, last_name, email, staff, active, team_manager, site, "position", channel, tier, team, purecloud_id, position_abbr) FROM stdin;
5	Brandon	Neal	stewartbrian@yahoo.com		t	\N	Tunis	OPS Senior	Operations	T3	backoffice 1	\N	CS
6	Alexandra	Rodriguez	webbjanice@cain.com		t	\N	Amsterdam	OPS Senior	Emails	T3	backoffice 1	\N	CS
7	Brandon	Wright	christopher10@macias.com		t	\N	Tunis	OPS Junior	Complaints	T2	email team	\N	OP
8	Vincent	Singleton	pereznancy@reed-mcgee.com		t	\N	Zlin	OPS specialist	Operations	T3	call team	\N	CS
9	Laura	Martinez	scross@friedman-bryan.com		t	\N	Bangladesh	OPS Senior	Emails	T2	backoffice 1	\N	OP
10	Abigail	Green	barrymichele@gmail.com		t	\N	Amsterdam	OPS specialist	Emails	T3	email team	\N	OP
11	Amy	Johnson	cooleyandrew@gmail.com		t	\N	Tunis	CS specialist	Chat	T2	backoffice 2	\N	CS
12	Elizabeth	Eaton	joelabbott@garza.com		t	\N	Zlin	CS Junior	Chat	T1	call team	\N	OP
13	Amy	Murillo	patricia91@yahoo.com		t	\N	Amsterdam	OPS specialist	Chat	T1	call team	\N	OP
14	Benjamin	Young	kennethmccormick@yahoo.com		t	\N	Amsterdam	OPS Senior	Emails	T2	chat team	\N	OP
15	Melissa	Mccarthy	mbrady@yahoo.com		t	\N	Tunis	OPS Senior	Complaints	T1	chat team	\N	CS
16	Yolanda	Miller	uthomas@yahoo.com		t	\N	Bangladesh	OPS Senior	Emails	T2	email team	\N	CS
17	Deanna	Berry	martincourtney@gonzalez-sullivan.com		t	\N	Bangladesh	OPS Junior	Operations	T2	backoffice 1	\N	CS
18	Glenn	Hughes	qsmith@gonzales.com		t	\N	Brno	OPS Senior	Complaints	T1	chat team	\N	CS
19	John	Owen	uhiggins@gmail.com		t	\N	Tunis	OPS Junior	Complaints	T1	call team	\N	OP
20	Jennifer	Schmidt	johnathanduncan@yahoo.com		t	\N	Zlin	OPS specialist	Emails	T1	backoffice 2	\N	OP
21	James	Franco	enguyen@keller.com		t	\N	Brno	OPS specialist	Emails	T3	backoffice 1	\N	OP
22	Jacob	Patel	arthurcabrera@yahoo.com		t	\N	Tunis	CS Junior	Operations	T2	chat team	\N	OP
23	Monique	Marquez	michaelswanson@gmail.com		t	\N	Zlin	CS specialist	Emails	T2	call team	\N	OP
24	Gloria	Miller	dharrell@yahoo.com		t	\N	Tunis	OPS specialist	Emails	T2	email team	\N	OP
25	Paul	Cox	lynnyates@colon.com		t	\N	Zlin	OPS Senior	Emails	T1	chat team	\N	CS
26	Veronica	Jones	shane42@gmail.com		t	\N	Amsterdam	OPS Senior	Emails	T1	backoffice 2	\N	CS
27	Karen	Nguyen	stephanieharris@george-phelps.com		t	\N	Amsterdam	CS specialist	Chat	T3	call team	\N	OP
28	Jennifer	Davis	michael37@wade.com		t	\N	Bangladesh	OPS specialist	Chat	T2	email team	\N	CS
29	Charles	Davis	allen52@marquez-martin.com		t	\N	Amsterdam	CS specialist	Complaints	T1	chat team	\N	CS
30	Laura	Fletcher	hillkelly@friedman-smith.com		t	\N	Brno	CS Junior	Emails	T2	email team	\N	OP
31	Jonathan	Cannon	garyyoung@gmail.com		t	\N	Amsterdam	OPS specialist	Complaints	T2	backoffice 2	\N	OP
32	Christine	Price	teresa51@russell.com		t	\N	Brno	OPS Junior	Emails	T2	call team	\N	OP
33	Sandra	Larson	ralphdominguez@rogers-casey.com		t	\N	Zlin	OPS Junior	Chat	T3	email team	\N	OP
34	Robert	Blevins	thomas17@stewart.org		t	\N	Zlin	CS Junior	Voice&Emails	T2	chat team	\N	OP
35	Sarah	Vega	oreyes@robinson.org		t	\N	Brno	OPS Junior	Voice&Emails	T1	backoffice 1	\N	OP
36	Michael	Carson	jclark@malone.com		t	\N	Brno	CS specialist	Complaints	T2	chat team	\N	CS
37	Kristina	Burns	brownjoseph@kaiser.com		t	\N	Bangladesh	OPS Senior	Complaints	T1	chat team	\N	OP
38	Alison	Stein	hartmanmicheal@wilson.com		t	\N	Tunis	OPS Junior	Complaints	T3	chat team	\N	OP
39	Timothy	Peterson	gstevens@yahoo.com		t	\N	Zlin	CS specialist	Voice&Emails	T3	chat team	\N	OP
40	Charlotte	Johnson	amyhughes@wang-richards.info		t	\N	Bangladesh	CS specialist	Operations	T1	email team	\N	OP
41	Mia	Wilson	qrobinson@yahoo.com		t	\N	Bangladesh	OPS specialist	Operations	T2	call team	\N	OP
42	Diana	Potts	andrewwebb@best.com		t	\N	Bangladesh	OPS Junior	Emails	T2	chat team	\N	OP
43	Ryan	Hernandez	jlee@hotmail.com		t	\N	Bangladesh	CS Junior	Complaints	T3	backoffice 1	\N	OP
44	Jonathan	Morgan	sextonlisa@leblanc-love.com		t	\N	Zlin	CS Junior	Voice&Emails	T3	chat team	\N	CS
45	Kayla	Freeman	davisadam@yahoo.com		t	\N	Brno	CS specialist	Voice&Emails	T1	backoffice 2	\N	OP
46	Francisco	Miranda	yfields@norris-wilson.net		t	\N	Amsterdam	OPS Senior	Voice&Emails	T3	email team	\N	CS
47	Denise	Smith	walkeranthony@lopez.net		t	\N	Bangladesh	OPS specialist	Chat	T1	call team	\N	OP
48	Emily	Larson	zavalarichard@jones.com		t	\N	Brno	OPS Senior	Emails	T3	chat team	\N	OP
49	Tracy	Salazar	owensmary@bird.com		t	\N	Brno	CS Junior	Operations	T2	email team	\N	OP
50	Ernest	Medina	travisyoung@norman.com		t	\N	Zlin	OPS Junior	Operations	T3	backoffice 1	\N	CS
51	Sharon	Turner	kelsey29@mitchell-chandler.com		t	\N	Tunis	CS specialist	Complaints	T2	call team	\N	OP
52	Michael	King	hunter59@moore-brown.net		t	\N	Brno	OPS specialist	Complaints	T2	call team	\N	OP
53	Gerald	Robinson	kgarcia@gmail.com		t	\N	Bangladesh	CS specialist	Emails	T3	email team	\N	CS
54	Amanda	Rogers	nicolenguyen@hotmail.com		t	\N	Zlin	OPS Senior	Operations	T1	call team	\N	CS
55	Carl	Blevins	rfernandez@yahoo.com		t	\N	Zlin	OPS specialist	Voice&Emails	T3	backoffice 2	\N	CS
56	Courtney	Cooper	richardmiller@peters.net		t	\N	Tunis	OPS Junior	Complaints	T2	backoffice 1	\N	CS
57	Gregory	Wolfe	dwilliams@hotmail.com		t	\N	Brno	CS specialist	Chat	T3	chat team	\N	CS
58	Alejandro	White	craiglynch@mcdonald-tran.biz		t	\N	Bangladesh	CS Junior	Chat	T1	backoffice 2	\N	OP
59	Paul	Clay	bartonjacob@yahoo.com		t	\N	Zlin	OPS Junior	Voice&Emails	T3	backoffice 2	\N	OP
60	Melissa	Taylor	pamela53@harmon.org		t	\N	Bangladesh	CS Junior	Emails	T3	email team	\N	CS
61	Michael	Friedman	travisleonard@gmail.com		t	\N	Brno	CS specialist	Emails	T1	email team	\N	OP
62	Shane	Chase	torresjohn@yahoo.com		t	\N	Tunis	CS specialist	Chat	T2	backoffice 1	\N	CS
63	Jessica	Payne	samueloneill@yahoo.com		t	\N	Zlin	CS specialist	Operations	T3	call team	\N	CS
64	Antonio	Alexander	fgutierrez@hotmail.com		t	\N	Brno	OPS specialist	Chat	T3	call team	\N	OP
65	Sarah	Conner	apatrick@martinez-hatfield.org		t	\N	Amsterdam	OPS Junior	Chat	T2	call team	\N	CS
66	Melinda	Dennis	simmonsantonio@gmail.com		t	\N	Zlin	OPS specialist	Operations	T2	backoffice 1	\N	CS
67	Mary	Bennett	adriandavis@weaver.com		t	\N	Bangladesh	OPS Senior	Chat	T1	email team	\N	OP
68	Jo	Hahn	williamsmarco@gmail.com		t	\N	Zlin	CS Junior	Emails	T1	backoffice 1	\N	OP
69	Theresa	Stanton	lori83@gmail.com		t	\N	Tunis	CS specialist	Emails	T1	backoffice 2	\N	OP
70	Stephen	Stokes	ryan03@gmail.com		t	\N	Brno	OPS Junior	Voice&Emails	T1	backoffice 2	\N	OP
71	Madeline	Riley	brenda62@gmail.com		t	\N	Tunis	CS specialist	Operations	T1	email team	\N	CS
72	Sylvia	Jordan	richardlewis@yahoo.com		t	\N	Bangladesh	OPS Junior	Operations	T1	call team	\N	OP
73	Julie	Johnson	tanderson@martin.biz		t	\N	Bangladesh	OPS Junior	Emails	T2	call team	\N	CS
74	Ryan	Taylor	wstuart@gmail.com		t	\N	Tunis	OPS specialist	Complaints	T1	call team	\N	OP
75	Clifford	Mitchell	andrewbarber@gmail.com		t	\N	Tunis	CS specialist	Voice&Emails	T1	backoffice 1	\N	CS
76	Joseph	Mitchell	mooreshirley@hotmail.com		t	\N	Amsterdam	CS specialist	Voice&Emails	T1	backoffice 1	\N	CS
77	Thomas	Wise	spencerbutler@johnson.org		t	\N	Amsterdam	OPS Senior	Emails	T3	call team	\N	CS
78	Courtney	Bates	wrowland@gmail.com		t	\N	Brno	CS specialist	Complaints	T2	backoffice 2	\N	CS
79	Benjamin	Gilmore	gjordan@yahoo.com		t	\N	Bangladesh	OPS Senior	Chat	T2	call team	\N	CS
80	Michael	Morrow	rachel68@whitaker.com		t	\N	Bangladesh	CS Junior	Emails	T2	email team	\N	CS
81	Stephanie	Baxter	hilllaura@adams.info		t	\N	Brno	OPS Senior	Complaints	T1	email team	\N	CS
82	Jasmine	Hendricks	halljamie@shannon.com		t	\N	Tunis	CS specialist	Complaints	T3	call team	\N	OP
83	Samantha	Mcdonald	teresarobinson@yahoo.com		t	\N	Tunis	OPS Junior	Operations	T3	backoffice 1	\N	CS
84	Ray	Cardenas	medinagabriela@garrett.net		t	\N	Tunis	OPS Junior	Chat	T1	email team	\N	OP
85	Benjamin	Garcia	dustin95@yahoo.com		t	\N	Zlin	OPS specialist	Operations	T2	call team	\N	CS
86	David	Williams	jesusdavis@yahoo.com		t	\N	Zlin	CS Junior	Voice&Emails	T3	chat team	\N	OP
87	Michelle	Perez	farmerthomas@yahoo.com		t	\N	Bangladesh	OPS Senior	Complaints	T1	backoffice 2	\N	CS
88	Amy	Hampton	sanderstony@hotmail.com		t	\N	Amsterdam	OPS Senior	Operations	T2	backoffice 2	\N	CS
89	Anthony	Howard	woodlaura@mayer-turner.com		t	\N	Tunis	CS specialist	Emails	T1	email team	\N	OP
90	James	Jones	jacob17@gmail.com		t	\N	Brno	CS Junior	Emails	T1	call team	\N	OP
91	Vicki	Johnson	xolson@hutchinson.net		t	\N	Brno	OPS specialist	Emails	T3	backoffice 1	\N	CS
92	Wanda	Miller	bwagner@hotmail.com		t	\N	Amsterdam	OPS Junior	Chat	T2	chat team	\N	OP
93	Anthony	Pierce	howellgary@yahoo.com		t	\N	Brno	OPS Senior	Voice&Emails	T1	backoffice 2	\N	OP
94	Carrie	Short	jennifercaldwell@estrada.com		t	\N	Amsterdam	OPS Junior	Operations	T2	backoffice 2	\N	CS
95	Wanda	Jordan	riveracindy@rogers.net		t	\N	Amsterdam	CS specialist	Voice&Emails	T2	email team	\N	OP
96	Joan	Friedman	tracy91@horton.com		t	\N	Amsterdam	OPS Junior	Complaints	T2	call team	\N	OP
97	Dominic	Barber	petersonzachary@yahoo.com		t	\N	Amsterdam	CS Junior	Operations	T1	backoffice 1	\N	OP
98	Daniel	Melendez	powelltravis@robinson.com		t	\N	Tunis	CS specialist	Emails	T3	chat team	\N	CS
99	Anthony	Lopez	jennyrice@gibson-brown.biz		t	\N	Tunis	CS specialist	Complaints	T1	chat team	\N	OP
100	Anne	Delgado	davisjustin@oconnor.biz		t	\N	Brno	CS Junior	Chat	T2	call team	\N	OP
101	Noah	Evans	philip87@hotmail.com		t	\N	Bangladesh	OPS specialist	Emails	T1	chat team	\N	OP
102	Holly	Sandoval	michaelross@hotmail.com		t	\N	Bangladesh	OPS Senior	Voice&Emails	T2	chat team	\N	OP
103	Michael	Shepherd	edwardsjeffrey@hotmail.com		t	\N	Zlin	CS specialist	Emails	T2	backoffice 2	\N	OP
104	Eric	Goodwin	angela13@yahoo.com		t	\N	Zlin	CS Junior	Voice&Emails	T1	chat team	\N	OP
\.


--
-- Data for Name: agent_assigned_queues; Type: TABLE DATA; Schema: public_old; Owner: -
--

COPY public_old.agent_assigned_queues (agent_id, queue_id) FROM stdin;
\.


--
-- Data for Name: agent_off_shift; Type: TABLE DATA; Schema: public_old; Owner: -
--

COPY public_old.agent_off_shift (id, shift_id, start_time_utc, end_time_utc, agent_id, off_reason) FROM stdin;
1	5	2019-04-30 15:00:00	2019-04-30 23:00:00	9	Doctors appt
2	6	2019-05-14 15:00:00	2019-05-14 23:00:00	38	Sick day
3	6	2019-05-12 23:00:00	2019-05-13 11:00:00	83	Maternity leave
4	7	2019-04-26 15:00:00	2019-04-26 23:00:00	48	Vacation
5	3	2019-05-15 07:00:00	2019-05-15 19:00:00	10	Vacation
6	4	2019-05-07 07:00:00	2019-05-07 15:00:00	66	Maternity leave
7	7	2019-04-26 15:00:00	2019-04-26 23:00:00	104	Doctors appt
8	1	2019-04-22 07:00:00	2019-04-22 19:00:00	96	Doctors appt
9	4	2019-05-08 15:00:00	2019-05-08 23:00:00	101	Sick day
10	5	2019-05-20 15:00:00	2019-05-20 23:00:00	39	Doctors appt
11	7	2019-05-17 07:00:00	2019-05-17 15:00:00	68	Vacation
12	4	2019-04-29 07:00:00	2019-04-29 15:00:00	42	Maternity leave
13	5	2019-04-23 23:00:00	2019-04-24 07:00:00	72	Maternity leave
14	6	2019-04-26 15:00:00	2019-04-27 03:00:00	15	Doctors appt
15	4	2019-05-09 15:00:00	2019-05-10 03:00:00	21	Doctors appt
16	3	2019-05-15 15:00:00	2019-05-15 23:00:00	44	Maternity leave
17	4	2019-05-18 23:00:00	2019-05-19 11:00:00	83	Maternity leave
18	7	2019-05-15 15:00:00	2019-05-15 23:00:00	47	Doctors appt
19	1	2019-05-04 15:00:00	2019-05-05 03:00:00	63	Doctors appt
20	5	2019-05-07 07:00:00	2019-05-07 15:00:00	80	Vacation
21	7	2019-05-14 23:00:00	2019-05-15 07:00:00	40	Maternity leave
22	3	2019-05-07 07:00:00	2019-05-07 19:00:00	8	Maternity leave
23	6	2019-05-10 15:00:00	2019-05-10 23:00:00	25	Maternity leave
24	4	2019-05-03 15:00:00	2019-05-04 03:00:00	46	Sick day
25	3	2019-05-04 23:00:00	2019-05-05 11:00:00	70	Vacation
26	3	2019-05-11 07:00:00	2019-05-11 15:00:00	7	Sick day
27	7	2019-04-20 15:00:00	2019-04-21 03:00:00	42	Vacation
28	4	2019-05-14 07:00:00	2019-05-14 19:00:00	55	Vacation
29	4	2019-04-27 15:00:00	2019-04-27 23:00:00	88	Sick day
30	5	2019-05-08 07:00:00	2019-05-08 15:00:00	77	Maternity leave
31	7	2019-05-07 15:00:00	2019-05-07 23:00:00	24	Vacation
32	2	2019-05-15 07:00:00	2019-05-15 19:00:00	47	Doctors appt
33	4	2019-05-06 23:00:00	2019-05-07 11:00:00	45	Sick day
34	4	2019-05-15 07:00:00	2019-05-15 19:00:00	67	Maternity leave
35	3	2019-04-20 23:00:00	2019-04-21 07:00:00	25	Vacation
36	4	2019-04-20 07:00:00	2019-04-20 15:00:00	56	Sick day
37	1	2019-05-03 07:00:00	2019-05-03 19:00:00	83	Maternity leave
38	3	2019-04-22 07:00:00	2019-04-22 15:00:00	15	Vacation
39	5	2019-05-16 07:00:00	2019-05-16 19:00:00	70	Doctors appt
40	3	2019-05-19 07:00:00	2019-05-19 15:00:00	47	Maternity leave
41	7	2019-05-01 15:00:00	2019-05-02 03:00:00	68	Doctors appt
42	2	2019-04-25 23:00:00	2019-04-26 07:00:00	8	Maternity leave
43	4	2019-04-23 23:00:00	2019-04-24 11:00:00	8	Maternity leave
44	5	2019-05-05 07:00:00	2019-05-05 15:00:00	87	Maternity leave
45	6	2019-05-05 07:00:00	2019-05-05 15:00:00	102	Maternity leave
46	2	2019-04-26 15:00:00	2019-04-26 23:00:00	84	Maternity leave
47	3	2019-04-25 15:00:00	2019-04-26 03:00:00	8	Doctors appt
48	2	2019-05-02 07:00:00	2019-05-02 19:00:00	24	Sick day
49	5	2019-04-22 07:00:00	2019-04-22 15:00:00	58	Vacation
50	5	2019-05-18 23:00:00	2019-05-19 07:00:00	63	Maternity leave
\.


--
-- Data for Name: agent_on_shift; Type: TABLE DATA; Schema: public_old; Owner: -
--

COPY public_old.agent_on_shift (id, shift_id, start_time_utc, end_time_utc, agent_id) FROM stdin;
1	5	2019-04-24 07:00:00	2019-04-24 15:00:00	44
2	7	2019-04-21 07:00:00	2019-04-21 19:00:00	85
3	6	2019-05-20 15:00:00	2019-05-21 03:00:00	53
4	5	2019-05-18 23:00:00	2019-05-19 11:00:00	81
5	4	2019-05-10 15:00:00	2019-05-11 03:00:00	48
6	7	2019-05-17 23:00:00	2019-05-18 11:00:00	58
7	1	2019-05-05 23:00:00	2019-05-06 11:00:00	80
8	1	2019-05-08 07:00:00	2019-05-08 15:00:00	78
9	1	2019-04-29 15:00:00	2019-04-29 23:00:00	37
10	3	2019-05-19 23:00:00	2019-05-20 11:00:00	101
11	3	2019-05-05 23:00:00	2019-05-06 11:00:00	18
12	3	2019-05-14 15:00:00	2019-05-14 23:00:00	50
13	4	2019-04-23 07:00:00	2019-04-23 19:00:00	98
14	2	2019-05-17 23:00:00	2019-05-18 11:00:00	16
15	5	2019-05-18 23:00:00	2019-05-19 11:00:00	81
16	1	2019-05-13 15:00:00	2019-05-14 03:00:00	95
17	1	2019-04-24 23:00:00	2019-04-25 11:00:00	59
18	5	2019-05-19 15:00:00	2019-05-19 23:00:00	52
19	7	2019-04-28 15:00:00	2019-04-28 23:00:00	86
20	1	2019-05-14 07:00:00	2019-05-14 15:00:00	58
21	2	2019-04-21 15:00:00	2019-04-21 23:00:00	18
22	3	2019-04-21 07:00:00	2019-04-21 15:00:00	71
23	4	2019-04-20 07:00:00	2019-04-20 15:00:00	45
24	1	2019-05-13 23:00:00	2019-05-14 07:00:00	31
25	4	2019-05-14 23:00:00	2019-05-15 07:00:00	74
26	6	2019-04-20 23:00:00	2019-04-21 07:00:00	88
27	3	2019-04-30 23:00:00	2019-05-01 11:00:00	55
28	7	2019-05-07 15:00:00	2019-05-07 23:00:00	32
29	2	2019-04-20 07:00:00	2019-04-20 15:00:00	97
30	5	2019-05-18 23:00:00	2019-05-19 11:00:00	98
31	1	2019-05-16 07:00:00	2019-05-16 15:00:00	94
32	3	2019-04-27 07:00:00	2019-04-27 15:00:00	62
33	5	2019-04-23 07:00:00	2019-04-23 19:00:00	30
34	7	2019-04-29 23:00:00	2019-04-30 11:00:00	69
35	1	2019-05-08 07:00:00	2019-05-08 15:00:00	29
36	1	2019-05-05 15:00:00	2019-05-06 03:00:00	28
37	4	2019-04-27 07:00:00	2019-04-27 19:00:00	91
38	3	2019-05-08 07:00:00	2019-05-08 19:00:00	14
39	4	2019-04-24 23:00:00	2019-04-25 11:00:00	71
40	4	2019-05-06 07:00:00	2019-05-06 15:00:00	12
41	4	2019-04-28 15:00:00	2019-04-28 23:00:00	59
42	2	2019-05-16 23:00:00	2019-05-17 11:00:00	70
43	6	2019-05-07 23:00:00	2019-05-08 07:00:00	61
44	4	2019-04-21 15:00:00	2019-04-22 03:00:00	89
45	7	2019-05-16 15:00:00	2019-05-17 03:00:00	7
46	6	2019-05-01 15:00:00	2019-05-01 23:00:00	68
47	1	2019-05-08 23:00:00	2019-05-09 07:00:00	79
48	3	2019-05-14 15:00:00	2019-05-15 03:00:00	85
49	4	2019-04-28 15:00:00	2019-04-28 23:00:00	101
50	3	2019-04-24 07:00:00	2019-04-24 15:00:00	22
51	3	2019-04-21 15:00:00	2019-04-22 03:00:00	71
52	5	2019-05-16 07:00:00	2019-05-16 15:00:00	65
53	2	2019-05-13 15:00:00	2019-05-13 23:00:00	101
54	7	2019-05-02 07:00:00	2019-05-02 19:00:00	12
55	4	2019-05-06 23:00:00	2019-05-07 11:00:00	96
56	5	2019-05-17 07:00:00	2019-05-17 19:00:00	48
57	3	2019-04-26 23:00:00	2019-04-27 11:00:00	13
58	3	2019-04-28 15:00:00	2019-04-28 23:00:00	39
59	7	2019-05-04 07:00:00	2019-05-04 15:00:00	54
60	1	2019-05-14 15:00:00	2019-05-15 03:00:00	93
61	4	2019-05-18 23:00:00	2019-05-19 11:00:00	87
62	4	2019-04-29 15:00:00	2019-04-30 03:00:00	70
63	5	2019-04-25 07:00:00	2019-04-25 19:00:00	22
64	3	2019-04-28 23:00:00	2019-04-29 11:00:00	65
65	7	2019-05-04 07:00:00	2019-05-04 15:00:00	68
66	5	2019-05-12 07:00:00	2019-05-12 19:00:00	37
67	6	2019-05-09 23:00:00	2019-05-10 11:00:00	67
68	3	2019-05-10 23:00:00	2019-05-11 11:00:00	86
69	5	2019-04-28 15:00:00	2019-04-28 23:00:00	40
70	1	2019-05-16 15:00:00	2019-05-16 23:00:00	80
71	4	2019-05-14 15:00:00	2019-05-15 03:00:00	43
72	7	2019-05-03 23:00:00	2019-05-04 11:00:00	18
73	4	2019-05-15 07:00:00	2019-05-15 15:00:00	72
74	2	2019-04-28 07:00:00	2019-04-28 19:00:00	85
75	4	2019-05-07 23:00:00	2019-05-08 07:00:00	20
76	2	2019-04-29 23:00:00	2019-04-30 07:00:00	7
77	2	2019-04-26 07:00:00	2019-04-26 19:00:00	100
78	3	2019-05-10 23:00:00	2019-05-11 11:00:00	27
79	7	2019-05-10 23:00:00	2019-05-11 07:00:00	5
80	3	2019-05-07 15:00:00	2019-05-08 03:00:00	92
81	3	2019-05-05 07:00:00	2019-05-05 19:00:00	19
82	5	2019-04-22 23:00:00	2019-04-23 11:00:00	30
83	5	2019-05-03 23:00:00	2019-05-04 11:00:00	92
84	6	2019-05-18 07:00:00	2019-05-18 19:00:00	57
85	2	2019-05-12 07:00:00	2019-05-12 15:00:00	43
86	6	2019-04-20 23:00:00	2019-04-21 07:00:00	54
87	2	2019-05-02 07:00:00	2019-05-02 19:00:00	16
88	3	2019-05-13 15:00:00	2019-05-14 03:00:00	45
89	1	2019-05-06 15:00:00	2019-05-06 23:00:00	83
90	5	2019-05-05 23:00:00	2019-05-06 07:00:00	103
91	1	2019-05-18 23:00:00	2019-05-19 07:00:00	66
92	3	2019-05-01 23:00:00	2019-05-02 07:00:00	58
93	7	2019-04-23 07:00:00	2019-04-23 15:00:00	53
94	6	2019-05-09 23:00:00	2019-05-10 11:00:00	29
95	3	2019-05-05 15:00:00	2019-05-06 03:00:00	36
96	5	2019-05-15 15:00:00	2019-05-15 23:00:00	56
97	5	2019-05-14 15:00:00	2019-05-15 03:00:00	40
98	7	2019-05-13 23:00:00	2019-05-14 07:00:00	52
99	7	2019-04-21 15:00:00	2019-04-22 03:00:00	37
100	7	2019-04-21 23:00:00	2019-04-22 11:00:00	30
101	3	2019-04-29 23:00:00	2019-04-30 11:00:00	70
102	6	2019-04-30 23:00:00	2019-05-01 11:00:00	89
103	4	2019-05-08 23:00:00	2019-05-09 07:00:00	26
104	4	2019-05-04 15:00:00	2019-05-04 23:00:00	86
105	7	2019-05-02 23:00:00	2019-05-03 07:00:00	40
106	4	2019-04-30 07:00:00	2019-04-30 15:00:00	66
107	5	2019-05-06 07:00:00	2019-05-06 15:00:00	92
108	5	2019-05-04 07:00:00	2019-05-04 15:00:00	30
109	1	2019-05-17 07:00:00	2019-05-17 19:00:00	27
110	1	2019-05-07 15:00:00	2019-05-08 03:00:00	72
111	2	2019-04-26 15:00:00	2019-04-26 23:00:00	30
112	2	2019-05-16 23:00:00	2019-05-17 11:00:00	26
113	1	2019-05-16 07:00:00	2019-05-16 19:00:00	41
114	1	2019-05-04 07:00:00	2019-05-04 15:00:00	93
115	6	2019-04-21 23:00:00	2019-04-22 07:00:00	40
116	7	2019-04-27 23:00:00	2019-04-28 07:00:00	46
117	1	2019-05-20 23:00:00	2019-05-21 11:00:00	103
118	6	2019-05-03 15:00:00	2019-05-03 23:00:00	103
119	7	2019-04-30 15:00:00	2019-05-01 03:00:00	26
120	6	2019-05-16 07:00:00	2019-05-16 19:00:00	38
121	6	2019-05-12 07:00:00	2019-05-12 19:00:00	37
122	4	2019-05-17 07:00:00	2019-05-17 19:00:00	89
123	1	2019-05-07 07:00:00	2019-05-07 19:00:00	64
124	6	2019-05-19 23:00:00	2019-05-20 07:00:00	55
125	5	2019-04-28 23:00:00	2019-04-29 07:00:00	63
126	4	2019-05-11 23:00:00	2019-05-12 11:00:00	36
127	4	2019-04-22 23:00:00	2019-04-23 11:00:00	67
128	2	2019-05-14 07:00:00	2019-05-14 19:00:00	75
129	3	2019-04-21 23:00:00	2019-04-22 07:00:00	39
130	3	2019-05-09 23:00:00	2019-05-10 11:00:00	31
131	3	2019-04-23 07:00:00	2019-04-23 15:00:00	30
132	1	2019-05-04 23:00:00	2019-05-05 11:00:00	71
133	3	2019-05-04 07:00:00	2019-05-04 15:00:00	12
134	5	2019-04-30 23:00:00	2019-05-01 11:00:00	34
135	6	2019-05-18 15:00:00	2019-05-19 03:00:00	8
136	2	2019-05-02 15:00:00	2019-05-03 03:00:00	65
137	5	2019-05-14 07:00:00	2019-05-14 15:00:00	65
138	2	2019-04-21 23:00:00	2019-04-22 11:00:00	38
139	7	2019-05-02 15:00:00	2019-05-02 23:00:00	65
140	7	2019-05-06 07:00:00	2019-05-06 15:00:00	75
141	5	2019-04-29 23:00:00	2019-04-30 11:00:00	75
142	4	2019-05-11 23:00:00	2019-05-12 07:00:00	75
143	6	2019-04-28 23:00:00	2019-04-29 11:00:00	30
144	3	2019-04-20 15:00:00	2019-04-20 23:00:00	14
145	1	2019-04-25 23:00:00	2019-04-26 11:00:00	97
146	4	2019-05-07 07:00:00	2019-05-07 19:00:00	66
147	3	2019-05-06 07:00:00	2019-05-06 15:00:00	90
148	6	2019-05-07 15:00:00	2019-05-08 03:00:00	16
149	4	2019-05-07 15:00:00	2019-05-07 23:00:00	48
150	4	2019-04-23 07:00:00	2019-04-23 19:00:00	47
151	6	2019-04-28 07:00:00	2019-04-28 19:00:00	61
152	6	2019-05-14 23:00:00	2019-05-15 07:00:00	90
153	7	2019-05-18 07:00:00	2019-05-18 19:00:00	17
154	3	2019-05-12 15:00:00	2019-05-12 23:00:00	12
155	7	2019-04-25 23:00:00	2019-04-26 07:00:00	61
156	1	2019-05-11 23:00:00	2019-05-12 11:00:00	99
157	5	2019-05-15 07:00:00	2019-05-15 15:00:00	62
158	2	2019-05-03 07:00:00	2019-05-03 19:00:00	9
159	7	2019-04-27 15:00:00	2019-04-27 23:00:00	43
160	5	2019-05-20 07:00:00	2019-05-20 15:00:00	37
161	2	2019-05-14 07:00:00	2019-05-14 15:00:00	68
162	3	2019-05-14 07:00:00	2019-05-14 15:00:00	60
163	2	2019-04-24 07:00:00	2019-04-24 15:00:00	87
164	6	2019-05-09 23:00:00	2019-05-10 07:00:00	67
165	2	2019-04-23 15:00:00	2019-04-23 23:00:00	79
166	3	2019-04-23 07:00:00	2019-04-23 19:00:00	59
167	4	2019-05-03 15:00:00	2019-05-03 23:00:00	43
168	3	2019-05-07 15:00:00	2019-05-07 23:00:00	21
169	2	2019-05-10 23:00:00	2019-05-11 11:00:00	67
170	5	2019-05-16 07:00:00	2019-05-16 19:00:00	59
171	4	2019-05-17 15:00:00	2019-05-17 23:00:00	66
172	1	2019-05-14 23:00:00	2019-05-15 07:00:00	47
173	2	2019-04-29 23:00:00	2019-04-30 11:00:00	71
174	2	2019-05-20 15:00:00	2019-05-20 23:00:00	42
175	6	2019-05-07 15:00:00	2019-05-07 23:00:00	50
176	6	2019-04-21 23:00:00	2019-04-22 07:00:00	86
177	3	2019-05-09 07:00:00	2019-05-09 15:00:00	40
178	3	2019-05-06 23:00:00	2019-05-07 07:00:00	101
179	4	2019-04-21 07:00:00	2019-04-21 15:00:00	74
180	2	2019-04-23 15:00:00	2019-04-23 23:00:00	103
181	2	2019-05-05 07:00:00	2019-05-05 19:00:00	43
182	2	2019-05-08 23:00:00	2019-05-09 11:00:00	81
183	3	2019-05-19 23:00:00	2019-05-20 07:00:00	66
184	7	2019-05-19 23:00:00	2019-05-20 07:00:00	57
185	5	2019-05-14 07:00:00	2019-05-14 19:00:00	56
186	3	2019-04-24 07:00:00	2019-04-24 19:00:00	40
187	7	2019-05-07 15:00:00	2019-05-07 23:00:00	10
188	4	2019-05-07 07:00:00	2019-05-07 15:00:00	36
189	3	2019-05-08 23:00:00	2019-05-09 11:00:00	28
190	2	2019-05-14 07:00:00	2019-05-14 15:00:00	24
191	7	2019-05-17 23:00:00	2019-05-18 11:00:00	76
192	3	2019-04-29 07:00:00	2019-04-29 19:00:00	47
193	5	2019-05-20 07:00:00	2019-05-20 15:00:00	86
194	3	2019-05-02 23:00:00	2019-05-03 07:00:00	84
195	2	2019-05-12 23:00:00	2019-05-13 07:00:00	104
196	3	2019-05-15 07:00:00	2019-05-15 15:00:00	48
197	7	2019-05-17 23:00:00	2019-05-18 07:00:00	67
198	1	2019-05-02 07:00:00	2019-05-02 15:00:00	30
199	3	2019-05-05 23:00:00	2019-05-06 11:00:00	56
200	5	2019-04-23 07:00:00	2019-04-23 19:00:00	30
201	6	2019-05-04 07:00:00	2019-05-04 19:00:00	27
202	2	2019-05-10 23:00:00	2019-05-11 07:00:00	41
203	2	2019-05-20 07:00:00	2019-05-20 15:00:00	37
204	5	2019-04-29 15:00:00	2019-04-30 03:00:00	35
205	7	2019-05-18 23:00:00	2019-05-19 07:00:00	32
206	6	2019-05-13 07:00:00	2019-05-13 19:00:00	5
207	3	2019-04-30 15:00:00	2019-04-30 23:00:00	41
208	6	2019-04-26 15:00:00	2019-04-27 03:00:00	7
209	6	2019-05-18 07:00:00	2019-05-18 15:00:00	14
210	6	2019-04-30 23:00:00	2019-05-01 07:00:00	18
211	4	2019-05-07 15:00:00	2019-05-08 03:00:00	80
212	7	2019-05-18 07:00:00	2019-05-18 15:00:00	62
213	1	2019-05-04 07:00:00	2019-05-04 15:00:00	66
214	5	2019-04-30 15:00:00	2019-04-30 23:00:00	59
215	6	2019-05-10 23:00:00	2019-05-11 11:00:00	45
216	5	2019-04-21 07:00:00	2019-04-21 15:00:00	16
217	6	2019-05-02 15:00:00	2019-05-02 23:00:00	86
218	7	2019-04-21 23:00:00	2019-04-22 07:00:00	76
219	7	2019-05-14 23:00:00	2019-05-15 07:00:00	7
220	3	2019-04-27 15:00:00	2019-04-28 03:00:00	26
221	1	2019-05-07 07:00:00	2019-05-07 19:00:00	31
222	3	2019-04-29 23:00:00	2019-04-30 07:00:00	16
223	2	2019-05-07 23:00:00	2019-05-08 11:00:00	89
224	4	2019-05-15 23:00:00	2019-05-16 07:00:00	82
225	3	2019-05-11 15:00:00	2019-05-12 03:00:00	79
226	5	2019-04-26 15:00:00	2019-04-26 23:00:00	67
227	3	2019-04-25 07:00:00	2019-04-25 19:00:00	70
228	1	2019-05-18 23:00:00	2019-05-19 11:00:00	74
229	1	2019-05-17 23:00:00	2019-05-18 11:00:00	47
230	4	2019-04-23 15:00:00	2019-04-24 03:00:00	93
231	4	2019-04-20 07:00:00	2019-04-20 19:00:00	54
232	6	2019-04-20 07:00:00	2019-04-20 15:00:00	96
233	6	2019-04-21 23:00:00	2019-04-22 11:00:00	63
234	2	2019-05-20 07:00:00	2019-05-20 15:00:00	41
235	4	2019-04-29 15:00:00	2019-04-29 23:00:00	28
236	6	2019-04-28 23:00:00	2019-04-29 11:00:00	52
237	5	2019-04-29 15:00:00	2019-04-30 03:00:00	14
238	4	2019-04-22 15:00:00	2019-04-22 23:00:00	28
239	6	2019-04-23 23:00:00	2019-04-24 11:00:00	57
240	6	2019-04-28 23:00:00	2019-04-29 11:00:00	88
241	7	2019-04-29 23:00:00	2019-04-30 11:00:00	33
242	3	2019-04-27 23:00:00	2019-04-28 11:00:00	36
243	4	2019-05-09 15:00:00	2019-05-09 23:00:00	5
244	3	2019-05-16 15:00:00	2019-05-17 03:00:00	67
245	6	2019-05-04 23:00:00	2019-05-05 11:00:00	57
246	4	2019-05-17 23:00:00	2019-05-18 11:00:00	35
247	4	2019-04-22 07:00:00	2019-04-22 19:00:00	68
248	6	2019-05-18 07:00:00	2019-05-18 15:00:00	69
249	2	2019-04-26 15:00:00	2019-04-26 23:00:00	75
250	7	2019-05-20 23:00:00	2019-05-21 11:00:00	90
251	6	2019-04-26 23:00:00	2019-04-27 07:00:00	32
252	2	2019-04-22 07:00:00	2019-04-22 19:00:00	80
253	1	2019-04-25 07:00:00	2019-04-25 15:00:00	7
254	6	2019-04-29 23:00:00	2019-04-30 07:00:00	83
255	3	2019-05-18 07:00:00	2019-05-18 19:00:00	32
256	4	2019-05-07 15:00:00	2019-05-08 03:00:00	85
257	7	2019-04-25 07:00:00	2019-04-25 19:00:00	31
258	1	2019-04-25 23:00:00	2019-04-26 11:00:00	48
259	2	2019-04-24 07:00:00	2019-04-24 15:00:00	11
260	4	2019-05-14 15:00:00	2019-05-15 03:00:00	27
261	3	2019-05-03 07:00:00	2019-05-03 15:00:00	69
262	1	2019-05-04 07:00:00	2019-05-04 15:00:00	93
263	5	2019-05-10 07:00:00	2019-05-10 19:00:00	66
264	1	2019-05-10 23:00:00	2019-05-11 07:00:00	35
265	3	2019-05-04 07:00:00	2019-05-04 19:00:00	104
266	4	2019-05-16 15:00:00	2019-05-17 03:00:00	77
267	7	2019-05-13 15:00:00	2019-05-13 23:00:00	7
268	1	2019-05-03 23:00:00	2019-05-04 11:00:00	76
269	1	2019-04-27 07:00:00	2019-04-27 19:00:00	85
270	3	2019-05-03 07:00:00	2019-05-03 15:00:00	101
271	1	2019-05-12 07:00:00	2019-05-12 19:00:00	59
272	5	2019-04-23 15:00:00	2019-04-24 03:00:00	88
273	5	2019-05-04 07:00:00	2019-05-04 19:00:00	65
274	5	2019-05-07 23:00:00	2019-05-08 11:00:00	96
275	7	2019-05-05 15:00:00	2019-05-05 23:00:00	103
276	4	2019-05-03 23:00:00	2019-05-04 07:00:00	47
277	6	2019-05-19 07:00:00	2019-05-19 15:00:00	71
278	7	2019-04-25 23:00:00	2019-04-26 07:00:00	23
279	5	2019-05-09 23:00:00	2019-05-10 11:00:00	88
280	1	2019-05-17 15:00:00	2019-05-17 23:00:00	79
281	6	2019-04-25 15:00:00	2019-04-25 23:00:00	85
282	1	2019-05-02 15:00:00	2019-05-02 23:00:00	104
283	4	2019-05-14 15:00:00	2019-05-15 03:00:00	44
284	5	2019-04-29 07:00:00	2019-04-29 15:00:00	54
285	3	2019-05-13 07:00:00	2019-05-13 19:00:00	97
286	1	2019-05-15 23:00:00	2019-05-16 07:00:00	55
287	6	2019-05-20 07:00:00	2019-05-20 19:00:00	24
288	3	2019-04-21 23:00:00	2019-04-22 07:00:00	29
289	1	2019-04-27 07:00:00	2019-04-27 15:00:00	63
290	3	2019-05-03 23:00:00	2019-05-04 11:00:00	99
291	1	2019-05-13 23:00:00	2019-05-14 07:00:00	24
292	1	2019-04-26 07:00:00	2019-04-26 15:00:00	30
293	3	2019-04-22 15:00:00	2019-04-22 23:00:00	72
294	1	2019-05-18 15:00:00	2019-05-18 23:00:00	9
295	1	2019-05-08 15:00:00	2019-05-09 03:00:00	52
296	4	2019-05-17 07:00:00	2019-05-17 19:00:00	20
297	5	2019-05-11 07:00:00	2019-05-11 19:00:00	89
298	1	2019-05-07 07:00:00	2019-05-07 19:00:00	101
299	3	2019-04-22 07:00:00	2019-04-22 15:00:00	31
300	5	2019-04-24 23:00:00	2019-04-25 07:00:00	62
301	1	2019-05-14 23:00:00	2019-05-15 07:00:00	40
302	5	2019-05-13 15:00:00	2019-05-14 03:00:00	98
303	7	2019-04-22 07:00:00	2019-04-22 19:00:00	74
304	3	2019-04-27 23:00:00	2019-04-28 07:00:00	64
305	5	2019-04-23 07:00:00	2019-04-23 19:00:00	86
306	1	2019-05-03 07:00:00	2019-05-03 19:00:00	65
307	3	2019-05-18 15:00:00	2019-05-19 03:00:00	31
308	6	2019-04-21 15:00:00	2019-04-21 23:00:00	73
309	1	2019-05-15 23:00:00	2019-05-16 07:00:00	32
310	3	2019-04-25 15:00:00	2019-04-25 23:00:00	62
311	5	2019-04-21 15:00:00	2019-04-22 03:00:00	72
312	1	2019-05-02 07:00:00	2019-05-02 15:00:00	97
313	3	2019-05-17 15:00:00	2019-05-18 03:00:00	81
314	1	2019-04-25 07:00:00	2019-04-25 19:00:00	30
315	1	2019-05-03 07:00:00	2019-05-03 19:00:00	91
316	5	2019-05-13 23:00:00	2019-05-14 07:00:00	98
317	5	2019-04-23 15:00:00	2019-04-23 23:00:00	66
318	5	2019-05-12 23:00:00	2019-05-13 07:00:00	19
319	4	2019-05-04 15:00:00	2019-05-05 03:00:00	36
320	4	2019-04-24 15:00:00	2019-04-24 23:00:00	16
321	4	2019-04-28 07:00:00	2019-04-28 15:00:00	68
322	3	2019-05-02 23:00:00	2019-05-03 11:00:00	37
323	1	2019-05-12 15:00:00	2019-05-12 23:00:00	87
324	6	2019-05-17 23:00:00	2019-05-18 11:00:00	39
325	4	2019-04-23 15:00:00	2019-04-24 03:00:00	34
326	5	2019-05-10 23:00:00	2019-05-11 07:00:00	12
327	6	2019-05-09 07:00:00	2019-05-09 19:00:00	35
328	6	2019-04-22 15:00:00	2019-04-23 03:00:00	96
329	2	2019-05-08 15:00:00	2019-05-09 03:00:00	54
330	2	2019-05-11 07:00:00	2019-05-11 19:00:00	31
331	3	2019-05-07 23:00:00	2019-05-08 07:00:00	53
332	3	2019-05-12 15:00:00	2019-05-12 23:00:00	41
333	1	2019-05-03 23:00:00	2019-05-04 11:00:00	8
334	3	2019-05-15 15:00:00	2019-05-16 03:00:00	64
335	1	2019-04-21 07:00:00	2019-04-21 19:00:00	9
336	3	2019-04-29 15:00:00	2019-04-29 23:00:00	13
337	7	2019-04-30 23:00:00	2019-05-01 11:00:00	5
338	1	2019-04-26 15:00:00	2019-04-26 23:00:00	64
339	6	2019-05-16 23:00:00	2019-05-17 07:00:00	10
340	6	2019-04-21 15:00:00	2019-04-22 03:00:00	96
341	5	2019-05-16 23:00:00	2019-05-17 07:00:00	75
342	6	2019-05-08 07:00:00	2019-05-08 19:00:00	74
343	3	2019-05-11 23:00:00	2019-05-12 11:00:00	87
344	3	2019-05-02 23:00:00	2019-05-03 11:00:00	32
345	4	2019-04-24 15:00:00	2019-04-25 03:00:00	63
346	1	2019-04-25 07:00:00	2019-04-25 15:00:00	19
347	3	2019-05-18 07:00:00	2019-05-18 19:00:00	33
348	6	2019-04-29 15:00:00	2019-04-29 23:00:00	62
349	7	2019-05-19 23:00:00	2019-05-20 07:00:00	101
350	3	2019-05-20 07:00:00	2019-05-20 19:00:00	87
351	6	2019-04-22 15:00:00	2019-04-23 03:00:00	55
352	5	2019-05-02 23:00:00	2019-05-03 07:00:00	98
353	4	2019-05-12 15:00:00	2019-05-13 03:00:00	5
354	5	2019-05-05 07:00:00	2019-05-05 15:00:00	30
355	2	2019-05-15 23:00:00	2019-05-16 11:00:00	57
356	7	2019-05-14 07:00:00	2019-05-14 15:00:00	16
357	7	2019-05-07 23:00:00	2019-05-08 07:00:00	50
358	1	2019-05-06 15:00:00	2019-05-07 03:00:00	73
359	2	2019-04-26 15:00:00	2019-04-27 03:00:00	48
360	5	2019-05-20 07:00:00	2019-05-20 15:00:00	101
361	2	2019-04-28 23:00:00	2019-04-29 07:00:00	52
362	2	2019-05-19 23:00:00	2019-05-20 07:00:00	77
363	1	2019-05-07 23:00:00	2019-05-08 11:00:00	15
364	5	2019-05-07 23:00:00	2019-05-08 07:00:00	6
365	7	2019-04-21 15:00:00	2019-04-21 23:00:00	46
366	1	2019-04-28 23:00:00	2019-04-29 11:00:00	96
367	2	2019-04-23 23:00:00	2019-04-24 11:00:00	102
368	2	2019-05-20 23:00:00	2019-05-21 11:00:00	75
369	5	2019-04-22 15:00:00	2019-04-22 23:00:00	52
370	1	2019-05-12 23:00:00	2019-05-13 11:00:00	17
371	1	2019-04-28 23:00:00	2019-04-29 11:00:00	74
372	3	2019-05-15 07:00:00	2019-05-15 19:00:00	55
373	2	2019-05-20 23:00:00	2019-05-21 11:00:00	30
374	7	2019-05-05 23:00:00	2019-05-06 11:00:00	28
375	2	2019-05-07 15:00:00	2019-05-08 03:00:00	65
376	4	2019-04-21 15:00:00	2019-04-22 03:00:00	77
377	2	2019-05-14 07:00:00	2019-05-14 15:00:00	69
378	2	2019-05-05 23:00:00	2019-05-06 11:00:00	6
379	7	2019-05-18 07:00:00	2019-05-18 19:00:00	8
380	1	2019-05-12 23:00:00	2019-05-13 11:00:00	98
381	6	2019-05-11 15:00:00	2019-05-11 23:00:00	23
382	3	2019-05-07 15:00:00	2019-05-07 23:00:00	31
383	6	2019-05-17 07:00:00	2019-05-17 15:00:00	59
384	5	2019-05-16 07:00:00	2019-05-16 15:00:00	15
385	2	2019-04-22 15:00:00	2019-04-23 03:00:00	31
386	2	2019-04-24 15:00:00	2019-04-25 03:00:00	78
387	2	2019-05-05 15:00:00	2019-05-06 03:00:00	87
388	7	2019-05-05 15:00:00	2019-05-05 23:00:00	54
389	5	2019-05-14 07:00:00	2019-05-14 19:00:00	74
390	6	2019-04-21 15:00:00	2019-04-21 23:00:00	63
391	2	2019-05-03 23:00:00	2019-05-04 11:00:00	100
392	3	2019-05-04 07:00:00	2019-05-04 19:00:00	11
393	7	2019-05-08 07:00:00	2019-05-08 19:00:00	6
394	3	2019-04-22 23:00:00	2019-04-23 11:00:00	20
395	1	2019-04-23 15:00:00	2019-04-24 03:00:00	63
396	1	2019-04-22 15:00:00	2019-04-23 03:00:00	76
397	2	2019-05-20 07:00:00	2019-05-20 15:00:00	18
398	2	2019-05-08 07:00:00	2019-05-08 19:00:00	82
399	6	2019-04-20 15:00:00	2019-04-20 23:00:00	77
400	4	2019-04-23 15:00:00	2019-04-24 03:00:00	67
401	4	2019-05-04 15:00:00	2019-05-04 23:00:00	7
402	7	2019-05-09 07:00:00	2019-05-09 19:00:00	78
403	5	2019-05-18 23:00:00	2019-05-19 07:00:00	48
404	5	2019-05-13 23:00:00	2019-05-14 07:00:00	88
405	7	2019-05-02 15:00:00	2019-05-03 03:00:00	66
406	2	2019-04-25 23:00:00	2019-04-26 07:00:00	84
407	4	2019-05-13 23:00:00	2019-05-14 11:00:00	16
408	2	2019-04-24 15:00:00	2019-04-25 03:00:00	83
409	6	2019-04-23 15:00:00	2019-04-24 03:00:00	82
410	2	2019-05-18 07:00:00	2019-05-18 19:00:00	62
411	3	2019-04-28 07:00:00	2019-04-28 15:00:00	56
412	2	2019-05-02 07:00:00	2019-05-02 15:00:00	32
413	7	2019-04-24 07:00:00	2019-04-24 15:00:00	87
414	6	2019-04-23 23:00:00	2019-04-24 07:00:00	35
415	4	2019-05-01 07:00:00	2019-05-01 19:00:00	93
416	6	2019-05-18 07:00:00	2019-05-18 19:00:00	104
417	5	2019-04-24 23:00:00	2019-04-25 07:00:00	62
418	3	2019-05-11 07:00:00	2019-05-11 15:00:00	83
419	2	2019-04-21 07:00:00	2019-04-21 15:00:00	67
420	7	2019-05-14 15:00:00	2019-05-14 23:00:00	72
421	5	2019-04-30 07:00:00	2019-04-30 15:00:00	93
422	3	2019-05-05 23:00:00	2019-05-06 07:00:00	59
423	6	2019-05-17 23:00:00	2019-05-18 11:00:00	20
424	5	2019-05-07 07:00:00	2019-05-07 15:00:00	60
425	6	2019-04-23 07:00:00	2019-04-23 19:00:00	43
426	3	2019-04-26 07:00:00	2019-04-26 19:00:00	38
427	3	2019-05-01 23:00:00	2019-05-02 07:00:00	35
428	6	2019-04-30 15:00:00	2019-05-01 03:00:00	35
429	3	2019-05-17 23:00:00	2019-05-18 07:00:00	50
430	1	2019-05-10 23:00:00	2019-05-11 07:00:00	74
431	2	2019-05-12 07:00:00	2019-05-12 19:00:00	44
432	1	2019-04-29 23:00:00	2019-04-30 07:00:00	103
433	3	2019-05-11 15:00:00	2019-05-11 23:00:00	25
434	1	2019-04-22 23:00:00	2019-04-23 07:00:00	17
435	4	2019-04-26 07:00:00	2019-04-26 15:00:00	53
436	6	2019-04-26 23:00:00	2019-04-27 11:00:00	76
437	1	2019-05-19 15:00:00	2019-05-20 03:00:00	35
438	7	2019-05-11 23:00:00	2019-05-12 07:00:00	46
439	3	2019-05-11 07:00:00	2019-05-11 15:00:00	51
440	6	2019-04-28 23:00:00	2019-04-29 07:00:00	33
441	7	2019-05-14 15:00:00	2019-05-15 03:00:00	104
442	7	2019-05-18 07:00:00	2019-05-18 19:00:00	89
443	7	2019-04-23 07:00:00	2019-04-23 19:00:00	50
444	7	2019-05-02 15:00:00	2019-05-03 03:00:00	17
445	2	2019-05-18 23:00:00	2019-05-19 11:00:00	74
446	6	2019-05-02 07:00:00	2019-05-02 15:00:00	54
447	1	2019-05-19 15:00:00	2019-05-20 03:00:00	58
448	6	2019-04-27 23:00:00	2019-04-28 07:00:00	69
449	7	2019-04-25 07:00:00	2019-04-25 19:00:00	29
450	1	2019-04-23 23:00:00	2019-04-24 07:00:00	64
451	7	2019-04-20 23:00:00	2019-04-21 07:00:00	96
452	1	2019-05-08 07:00:00	2019-05-08 15:00:00	29
453	7	2019-05-15 23:00:00	2019-05-16 07:00:00	9
454	5	2019-04-22 15:00:00	2019-04-22 23:00:00	17
455	3	2019-04-27 07:00:00	2019-04-27 15:00:00	19
456	6	2019-04-28 15:00:00	2019-04-29 03:00:00	83
457	6	2019-05-16 07:00:00	2019-05-16 19:00:00	55
458	7	2019-05-16 23:00:00	2019-05-17 07:00:00	92
459	4	2019-05-12 15:00:00	2019-05-13 03:00:00	100
460	3	2019-05-03 23:00:00	2019-05-04 11:00:00	88
461	4	2019-04-29 15:00:00	2019-04-30 03:00:00	60
462	7	2019-04-28 23:00:00	2019-04-29 07:00:00	73
463	5	2019-04-20 23:00:00	2019-04-21 07:00:00	36
464	5	2019-05-06 23:00:00	2019-05-07 07:00:00	83
465	7	2019-04-30 15:00:00	2019-05-01 03:00:00	56
466	5	2019-05-04 23:00:00	2019-05-05 07:00:00	64
467	4	2019-05-03 23:00:00	2019-05-04 07:00:00	57
468	1	2019-05-15 15:00:00	2019-05-16 03:00:00	42
469	2	2019-04-26 07:00:00	2019-04-26 15:00:00	98
470	7	2019-05-04 07:00:00	2019-05-04 15:00:00	70
471	6	2019-05-15 07:00:00	2019-05-15 15:00:00	25
472	7	2019-04-30 15:00:00	2019-04-30 23:00:00	75
473	1	2019-04-29 07:00:00	2019-04-29 19:00:00	15
474	2	2019-04-28 07:00:00	2019-04-28 19:00:00	72
475	2	2019-05-09 07:00:00	2019-05-09 15:00:00	69
476	5	2019-05-10 07:00:00	2019-05-10 15:00:00	64
477	6	2019-05-01 07:00:00	2019-05-01 15:00:00	11
478	5	2019-04-27 07:00:00	2019-04-27 15:00:00	29
479	4	2019-05-09 07:00:00	2019-05-09 15:00:00	6
480	7	2019-04-23 07:00:00	2019-04-23 15:00:00	9
481	7	2019-04-20 07:00:00	2019-04-20 19:00:00	94
482	6	2019-04-21 23:00:00	2019-04-22 07:00:00	104
483	3	2019-04-27 23:00:00	2019-04-28 07:00:00	12
484	1	2019-05-06 23:00:00	2019-05-07 11:00:00	23
485	4	2019-05-02 23:00:00	2019-05-03 07:00:00	32
486	4	2019-05-05 23:00:00	2019-05-06 07:00:00	96
487	4	2019-04-25 23:00:00	2019-04-26 07:00:00	94
488	7	2019-04-30 15:00:00	2019-04-30 23:00:00	70
489	3	2019-05-07 23:00:00	2019-05-08 11:00:00	44
490	7	2019-05-04 07:00:00	2019-05-04 19:00:00	15
491	6	2019-05-11 23:00:00	2019-05-12 11:00:00	60
492	4	2019-05-12 07:00:00	2019-05-12 15:00:00	30
493	7	2019-04-29 07:00:00	2019-04-29 19:00:00	51
494	2	2019-05-11 23:00:00	2019-05-12 07:00:00	20
495	3	2019-05-11 07:00:00	2019-05-11 15:00:00	7
496	3	2019-04-28 23:00:00	2019-04-29 11:00:00	63
497	7	2019-05-05 23:00:00	2019-05-06 07:00:00	24
498	2	2019-04-21 23:00:00	2019-04-22 11:00:00	85
499	3	2019-04-25 15:00:00	2019-04-26 03:00:00	5
500	5	2019-05-11 15:00:00	2019-05-12 03:00:00	58
\.


--
-- Data for Name: agent_shift_queue; Type: TABLE DATA; Schema: public_old; Owner: -
--

COPY public_old.agent_shift_queue (shift_id, updated_on_utc, agent_id, queue_id, start_time_utc, end_time_utc, source, author) FROM stdin;
2	2019-04-23 11:58:37.220497	79	7	2019-04-23 15:00:00	2019-04-23 23:00:00	agatha	\N
\.


--
-- Data for Name: log; Type: TABLE DATA; Schema: public_old; Owner: -
--

COPY public_old.log (action, queue_id, agent_id, author, shift_id, created_on_utc, start_time_utc, end_time_utc) FROM stdin;
INSERT	7	79	\N	2	2019-04-23 11:58:37.220497	2019-04-23 15:00:00	2019-04-23 23:00:00
\.


--
-- Data for Name: queue; Type: TABLE DATA; Schema: public_old; Owner: -
--

COPY public_old.queue (id, name, purecloud_id, balkan_id, group_name) FROM stdin;
1	Call EN	\N	\N	FrontOffice
2	Chat EN	\N	\N	Urgent
3	Call FR	\N	\N	FrontOffice
4	Complaints	\N	\N	BackOffice
5	Refunds	\N	\N	BackOffice
6	Chat EN	\N	\N	General
7	Call JP	\N	\N	FrontOffice
8	Call JP	\N	\N	Urgent
9	Refunds	\N	\N	Urgent
10	Refunds	\N	\N	BackOffice
\.


--
-- Data for Name: shift; Type: TABLE DATA; Schema: public_old; Owner: -
--

COPY public_old.shift (id, name, description, length, minspacing, delete_on_utc, created_on_utc, created_by, modified_on_utc, modified_by, maxspacing) FROM stdin;
1	BO morning 8h		8	0	\N	2019-04-20 09:03:03.655815	sthomas@dickson.com	\N	\N	\N
2	BO afternoon 8h		8	0	\N	2019-04-20 09:03:03.656391	fieldsmegan@mcbride-davis.com	\N	\N	\N
3	BO night 8h		8	0	\N	2019-04-20 09:03:03.656813	sarnold@alvarez-mendez.info	\N	\N	\N
4	FO morning 12h		8	0	\N	2019-04-20 09:03:03.657163	mstephens@gmail.com	\N	\N	\N
5	FO afternoon 12h		8	0	\N	2019-04-20 09:03:03.657305	kevinnichols@yahoo.com	\N	\N	\N
6	FO night 12h		8	0	\N	2019-04-20 09:03:03.657499	smithshannon@gmail.com	\N	\N	\N
7	Complaints 8h		8	0	\N	2019-04-20 09:03:03.657699	johnsonkelli@gmail.com	\N	\N	\N
\.


--
-- Name: hdb_schema_update_event_id_seq; Type: SEQUENCE SET; Schema: hdb_catalog; Owner: -
--

SELECT pg_catalog.setval('hdb_catalog.hdb_schema_update_event_id_seq', 19, true);


--
-- Name: remote_schemas_id_seq; Type: SEQUENCE SET; Schema: hdb_catalog; Owner: -
--

SELECT pg_catalog.setval('hdb_catalog.remote_schemas_id_seq', 1, false);


--
-- Name: agent_assigned_queues_id_seq; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('public.agent_assigned_queues_id_seq', 1, false);


--
-- Name: agent_id_seq; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('public.agent_id_seq', 1, false);


--
-- Name: agent_off_shift_id_seq; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('public.agent_off_shift_id_seq', 1, false);


--
-- Name: agent_on_shift_id_seq; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('public.agent_on_shift_id_seq', 1, false);


--
-- Name: agent_shift_queue_id_seq; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('public.agent_shift_queue_id_seq', 1084, true);


--
-- Name: queue_id_seq; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('public.queue_id_seq', 1, false);


--
-- Name: shift_id_seq; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('public.shift_id_seq', 1, false);


--
-- Name: agent_id_seq; Type: SEQUENCE SET; Schema: public_old; Owner: -
--

SELECT pg_catalog.setval('public_old.agent_id_seq', 104, true);


--
-- Name: agent_off_shift_id_seq; Type: SEQUENCE SET; Schema: public_old; Owner: -
--

SELECT pg_catalog.setval('public_old.agent_off_shift_id_seq', 50, true);


--
-- Name: agent_on_shift_id_seq; Type: SEQUENCE SET; Schema: public_old; Owner: -
--

SELECT pg_catalog.setval('public_old.agent_on_shift_id_seq', 500, true);


--
-- Name: queue_id_seq; Type: SEQUENCE SET; Schema: public_old; Owner: -
--

SELECT pg_catalog.setval('public_old.queue_id_seq', 10, true);


--
-- Name: shift_id_seq; Type: SEQUENCE SET; Schema: public_old; Owner: -
--

SELECT pg_catalog.setval('public_old.shift_id_seq', 7, true);


--
-- Name: event_invocation_logs event_invocation_logs_pkey; Type: CONSTRAINT; Schema: hdb_catalog; Owner: -
--

ALTER TABLE ONLY hdb_catalog.event_invocation_logs
    ADD CONSTRAINT event_invocation_logs_pkey PRIMARY KEY (id);


--
-- Name: event_log event_log_pkey; Type: CONSTRAINT; Schema: hdb_catalog; Owner: -
--

ALTER TABLE ONLY hdb_catalog.event_log
    ADD CONSTRAINT event_log_pkey PRIMARY KEY (id);


--
-- Name: event_triggers event_triggers_pkey; Type: CONSTRAINT; Schema: hdb_catalog; Owner: -
--

ALTER TABLE ONLY hdb_catalog.event_triggers
    ADD CONSTRAINT event_triggers_pkey PRIMARY KEY (name);


--
-- Name: hdb_function hdb_function_pkey; Type: CONSTRAINT; Schema: hdb_catalog; Owner: -
--

ALTER TABLE ONLY hdb_catalog.hdb_function
    ADD CONSTRAINT hdb_function_pkey PRIMARY KEY (function_schema, function_name);


--
-- Name: hdb_permission hdb_permission_pkey; Type: CONSTRAINT; Schema: hdb_catalog; Owner: -
--

ALTER TABLE ONLY hdb_catalog.hdb_permission
    ADD CONSTRAINT hdb_permission_pkey PRIMARY KEY (table_schema, table_name, role_name, perm_type);


--
-- Name: hdb_query_template hdb_query_template_pkey; Type: CONSTRAINT; Schema: hdb_catalog; Owner: -
--

ALTER TABLE ONLY hdb_catalog.hdb_query_template
    ADD CONSTRAINT hdb_query_template_pkey PRIMARY KEY (template_name);


--
-- Name: hdb_relationship hdb_relationship_pkey; Type: CONSTRAINT; Schema: hdb_catalog; Owner: -
--

ALTER TABLE ONLY hdb_catalog.hdb_relationship
    ADD CONSTRAINT hdb_relationship_pkey PRIMARY KEY (table_schema, table_name, rel_name);


--
-- Name: hdb_schema_update_event hdb_schema_update_event_pkey; Type: CONSTRAINT; Schema: hdb_catalog; Owner: -
--

ALTER TABLE ONLY hdb_catalog.hdb_schema_update_event
    ADD CONSTRAINT hdb_schema_update_event_pkey PRIMARY KEY (id);


--
-- Name: hdb_table hdb_table_pkey; Type: CONSTRAINT; Schema: hdb_catalog; Owner: -
--

ALTER TABLE ONLY hdb_catalog.hdb_table
    ADD CONSTRAINT hdb_table_pkey PRIMARY KEY (table_schema, table_name);


--
-- Name: hdb_version hdb_version_pkey; Type: CONSTRAINT; Schema: hdb_catalog; Owner: -
--

ALTER TABLE ONLY hdb_catalog.hdb_version
    ADD CONSTRAINT hdb_version_pkey PRIMARY KEY (hasura_uuid);


--
-- Name: remote_schemas remote_schemas_name_key; Type: CONSTRAINT; Schema: hdb_catalog; Owner: -
--

ALTER TABLE ONLY hdb_catalog.remote_schemas
    ADD CONSTRAINT remote_schemas_name_key UNIQUE (name);


--
-- Name: remote_schemas remote_schemas_pkey; Type: CONSTRAINT; Schema: hdb_catalog; Owner: -
--

ALTER TABLE ONLY hdb_catalog.remote_schemas
    ADD CONSTRAINT remote_schemas_pkey PRIMARY KEY (id);


--
-- Name: agent_assigned_queues agent_assigned_queues_pk; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.agent_assigned_queues
    ADD CONSTRAINT agent_assigned_queues_pk UNIQUE (agent_id, queue_id);


--
-- Name: agent_assigned_queues agent_assigned_queues_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.agent_assigned_queues
    ADD CONSTRAINT agent_assigned_queues_pkey PRIMARY KEY (id);


--
-- Name: agent_off_shift agent_off_shift_pk; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.agent_off_shift
    ADD CONSTRAINT agent_off_shift_pk PRIMARY KEY (id);


--
-- Name: agent_on_shift agent_on_shift_pk; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.agent_on_shift
    ADD CONSTRAINT agent_on_shift_pk PRIMARY KEY (id);


--
-- Name: agent agent_pk; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.agent
    ADD CONSTRAINT agent_pk PRIMARY KEY (id);


--
-- Name: agent_shift_queue agent_shift_queue_pk; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.agent_shift_queue
    ADD CONSTRAINT agent_shift_queue_pk UNIQUE (agent_id, queue_id);


--
-- Name: agent_shift_queue agent_shift_queue_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.agent_shift_queue
    ADD CONSTRAINT agent_shift_queue_pkey PRIMARY KEY (id);


--
-- Name: queue queue_pk; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.queue
    ADD CONSTRAINT queue_pk PRIMARY KEY (id);


--
-- Name: shift shift_pk; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.shift
    ADD CONSTRAINT shift_pk PRIMARY KEY (id);


--
-- Name: agent_assigned_queues agent_assigned_queues_pk; Type: CONSTRAINT; Schema: public_old; Owner: -
--

ALTER TABLE ONLY public_old.agent_assigned_queues
    ADD CONSTRAINT agent_assigned_queues_pk UNIQUE (agent_id, queue_id);


--
-- Name: agent_off_shift agent_off_shift_pk; Type: CONSTRAINT; Schema: public_old; Owner: -
--

ALTER TABLE ONLY public_old.agent_off_shift
    ADD CONSTRAINT agent_off_shift_pk PRIMARY KEY (id);


--
-- Name: agent_on_shift agent_on_shift_pk; Type: CONSTRAINT; Schema: public_old; Owner: -
--

ALTER TABLE ONLY public_old.agent_on_shift
    ADD CONSTRAINT agent_on_shift_pk PRIMARY KEY (id);


--
-- Name: agent agent_pk; Type: CONSTRAINT; Schema: public_old; Owner: -
--

ALTER TABLE ONLY public_old.agent
    ADD CONSTRAINT agent_pk PRIMARY KEY (id);


--
-- Name: agent_shift_queue agent_shift_queue_pk; Type: CONSTRAINT; Schema: public_old; Owner: -
--

ALTER TABLE ONLY public_old.agent_shift_queue
    ADD CONSTRAINT agent_shift_queue_pk UNIQUE (agent_id, queue_id);


--
-- Name: queue queue_pk; Type: CONSTRAINT; Schema: public_old; Owner: -
--

ALTER TABLE ONLY public_old.queue
    ADD CONSTRAINT queue_pk PRIMARY KEY (id);


--
-- Name: shift shift_pk; Type: CONSTRAINT; Schema: public_old; Owner: -
--

ALTER TABLE ONLY public_old.shift
    ADD CONSTRAINT shift_pk PRIMARY KEY (id);


--
-- Name: event_invocation_logs_event_id_idx; Type: INDEX; Schema: hdb_catalog; Owner: -
--

CREATE INDEX event_invocation_logs_event_id_idx ON hdb_catalog.event_invocation_logs USING btree (event_id);


--
-- Name: event_log_trigger_name_idx; Type: INDEX; Schema: hdb_catalog; Owner: -
--

CREATE INDEX event_log_trigger_name_idx ON hdb_catalog.event_log USING btree (trigger_name);


--
-- Name: hdb_version_one_row; Type: INDEX; Schema: hdb_catalog; Owner: -
--

CREATE UNIQUE INDEX hdb_version_one_row ON hdb_catalog.hdb_version USING btree (((version IS NOT NULL)));


--
-- Name: agent_email_uindex; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX agent_email_uindex ON public.agent USING btree (email);


--
-- Name: agent_off_shift_id_uindex; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX agent_off_shift_id_uindex ON public.agent_off_shift USING btree (id);


--
-- Name: agent_on_shift_id_uindex; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX agent_on_shift_id_uindex ON public.agent_on_shift USING btree (id);


--
-- Name: agent_purecloud_id_uindex; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX agent_purecloud_id_uindex ON public.agent USING btree (purecloud_id);


--
-- Name: queue_balkan_id_uindex; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX queue_balkan_id_uindex ON public.queue USING btree (balkan_id);


--
-- Name: queue_purecloud_id_uindex; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX queue_purecloud_id_uindex ON public.queue USING btree (purecloud_id);


--
-- Name: shift_id_uindex; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX shift_id_uindex ON public.shift USING btree (id);


--
-- Name: agent_email_uindex; Type: INDEX; Schema: public_old; Owner: -
--

CREATE UNIQUE INDEX agent_email_uindex ON public_old.agent USING btree (email);


--
-- Name: agent_off_shift_id_uindex; Type: INDEX; Schema: public_old; Owner: -
--

CREATE UNIQUE INDEX agent_off_shift_id_uindex ON public_old.agent_off_shift USING btree (id);


--
-- Name: agent_on_shift_id_uindex; Type: INDEX; Schema: public_old; Owner: -
--

CREATE UNIQUE INDEX agent_on_shift_id_uindex ON public_old.agent_on_shift USING btree (id);


--
-- Name: agent_purecloud_id_uindex; Type: INDEX; Schema: public_old; Owner: -
--

CREATE UNIQUE INDEX agent_purecloud_id_uindex ON public_old.agent USING btree (purecloud_id);


--
-- Name: queue_balkan_id_uindex; Type: INDEX; Schema: public_old; Owner: -
--

CREATE UNIQUE INDEX queue_balkan_id_uindex ON public_old.queue USING btree (balkan_id);


--
-- Name: queue_purecloud_id_uindex; Type: INDEX; Schema: public_old; Owner: -
--

CREATE UNIQUE INDEX queue_purecloud_id_uindex ON public_old.queue USING btree (purecloud_id);


--
-- Name: shift_id_uindex; Type: INDEX; Schema: public_old; Owner: -
--

CREATE UNIQUE INDEX shift_id_uindex ON public_old.shift USING btree (id);


--
-- Name: hdb_schema_update_event hdb_schema_update_event_notifier; Type: TRIGGER; Schema: hdb_catalog; Owner: -
--

CREATE TRIGGER hdb_schema_update_event_notifier AFTER INSERT ON hdb_catalog.hdb_schema_update_event FOR EACH ROW EXECUTE PROCEDURE hdb_catalog.hdb_schema_update_event_notifier();


--
-- Name: hdb_table hdb_table_oid_check; Type: TRIGGER; Schema: hdb_catalog; Owner: -
--

CREATE TRIGGER hdb_table_oid_check BEFORE INSERT OR UPDATE ON hdb_catalog.hdb_table FOR EACH ROW EXECUTE PROCEDURE hdb_catalog.hdb_table_oid_check();


--
-- Name: agent_shift_queue agent_shift_queue_action_trigger; Type: TRIGGER; Schema: public; Owner: -
--

CREATE TRIGGER agent_shift_queue_action_trigger AFTER INSERT OR UPDATE ON public.agent_shift_queue FOR EACH ROW EXECUTE PROCEDURE public.update_log_after_agent_shift_queue_action();


--
-- Name: agent_shift_queue agent_shift_queue_action_trigger; Type: TRIGGER; Schema: public_old; Owner: -
--

CREATE TRIGGER agent_shift_queue_action_trigger AFTER INSERT OR DELETE OR UPDATE ON public_old.agent_shift_queue FOR EACH ROW EXECUTE PROCEDURE public_old.update_log_after_agent_shift_queue_action();


--
-- Name: event_invocation_logs event_invocation_logs_event_id_fkey; Type: FK CONSTRAINT; Schema: hdb_catalog; Owner: -
--

ALTER TABLE ONLY hdb_catalog.event_invocation_logs
    ADD CONSTRAINT event_invocation_logs_event_id_fkey FOREIGN KEY (event_id) REFERENCES hdb_catalog.event_log(id);


--
-- Name: event_triggers event_triggers_schema_name_fkey; Type: FK CONSTRAINT; Schema: hdb_catalog; Owner: -
--

ALTER TABLE ONLY hdb_catalog.event_triggers
    ADD CONSTRAINT event_triggers_schema_name_fkey FOREIGN KEY (schema_name, table_name) REFERENCES hdb_catalog.hdb_table(table_schema, table_name) ON UPDATE CASCADE;


--
-- Name: hdb_permission hdb_permission_table_schema_fkey; Type: FK CONSTRAINT; Schema: hdb_catalog; Owner: -
--

ALTER TABLE ONLY hdb_catalog.hdb_permission
    ADD CONSTRAINT hdb_permission_table_schema_fkey FOREIGN KEY (table_schema, table_name) REFERENCES hdb_catalog.hdb_table(table_schema, table_name) ON UPDATE CASCADE;


--
-- Name: hdb_relationship hdb_relationship_table_schema_fkey; Type: FK CONSTRAINT; Schema: hdb_catalog; Owner: -
--

ALTER TABLE ONLY hdb_catalog.hdb_relationship
    ADD CONSTRAINT hdb_relationship_table_schema_fkey FOREIGN KEY (table_schema, table_name) REFERENCES hdb_catalog.hdb_table(table_schema, table_name) ON UPDATE CASCADE;


--
-- Name: agent_on_shift agent___fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.agent_on_shift
    ADD CONSTRAINT agent___fk FOREIGN KEY (agent_id) REFERENCES public.agent(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: agent_off_shift agent___fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.agent_off_shift
    ADD CONSTRAINT agent___fk FOREIGN KEY (agent_id) REFERENCES public.agent(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: agent_assigned_queues agent_assigned_queues_agent_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.agent_assigned_queues
    ADD CONSTRAINT agent_assigned_queues_agent_id_fkey FOREIGN KEY (agent_id) REFERENCES public.agent(id);


--
-- Name: agent_assigned_queues agent_assigned_queues_queue_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.agent_assigned_queues
    ADD CONSTRAINT agent_assigned_queues_queue_id_fkey FOREIGN KEY (queue_id) REFERENCES public.queue(id);


--
-- Name: agent_shift_queue agent_shift_queue_agent_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.agent_shift_queue
    ADD CONSTRAINT agent_shift_queue_agent_id_fkey FOREIGN KEY (agent_id) REFERENCES public.agent(id);


--
-- Name: agent_shift_queue agent_shift_queue_queue_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.agent_shift_queue
    ADD CONSTRAINT agent_shift_queue_queue_id_fkey FOREIGN KEY (queue_id) REFERENCES public.queue(id);


--
-- Name: log log_agent_id___fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.log
    ADD CONSTRAINT log_agent_id___fk FOREIGN KEY (agent_id) REFERENCES public.agent(id) ON UPDATE SET NULL ON DELETE SET NULL;


--
-- Name: log log_queue_id___fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.log
    ADD CONSTRAINT log_queue_id___fk FOREIGN KEY (queue_id) REFERENCES public.queue(id) ON UPDATE SET NULL ON DELETE SET NULL;


--
-- Name: agent_on_shift shift___fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.agent_on_shift
    ADD CONSTRAINT shift___fk FOREIGN KEY (shift_id) REFERENCES public.shift(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: agent_off_shift shift___fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.agent_off_shift
    ADD CONSTRAINT shift___fk FOREIGN KEY (shift_id) REFERENCES public.shift(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: agent team_manager___fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.agent
    ADD CONSTRAINT team_manager___fk FOREIGN KEY (team_manager) REFERENCES public.agent(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: agent_on_shift agent___fk; Type: FK CONSTRAINT; Schema: public_old; Owner: -
--

ALTER TABLE ONLY public_old.agent_on_shift
    ADD CONSTRAINT agent___fk FOREIGN KEY (agent_id) REFERENCES public_old.agent(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: agent_off_shift agent___fk; Type: FK CONSTRAINT; Schema: public_old; Owner: -
--

ALTER TABLE ONLY public_old.agent_off_shift
    ADD CONSTRAINT agent___fk FOREIGN KEY (agent_id) REFERENCES public_old.agent(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: agent_assigned_queues agent_assigned_queues_agent_id_fkey; Type: FK CONSTRAINT; Schema: public_old; Owner: -
--

ALTER TABLE ONLY public_old.agent_assigned_queues
    ADD CONSTRAINT agent_assigned_queues_agent_id_fkey FOREIGN KEY (agent_id) REFERENCES public_old.agent(id);


--
-- Name: agent_assigned_queues agent_assigned_queues_queue_id_fkey; Type: FK CONSTRAINT; Schema: public_old; Owner: -
--

ALTER TABLE ONLY public_old.agent_assigned_queues
    ADD CONSTRAINT agent_assigned_queues_queue_id_fkey FOREIGN KEY (queue_id) REFERENCES public_old.queue(id);


--
-- Name: agent_shift_queue agent_shift_queue_agent_id_fkey; Type: FK CONSTRAINT; Schema: public_old; Owner: -
--

ALTER TABLE ONLY public_old.agent_shift_queue
    ADD CONSTRAINT agent_shift_queue_agent_id_fkey FOREIGN KEY (agent_id) REFERENCES public_old.agent(id);


--
-- Name: agent_shift_queue agent_shift_queue_queue_id_fkey; Type: FK CONSTRAINT; Schema: public_old; Owner: -
--

ALTER TABLE ONLY public_old.agent_shift_queue
    ADD CONSTRAINT agent_shift_queue_queue_id_fkey FOREIGN KEY (queue_id) REFERENCES public_old.queue(id);


--
-- Name: log log_agent_id___fk; Type: FK CONSTRAINT; Schema: public_old; Owner: -
--

ALTER TABLE ONLY public_old.log
    ADD CONSTRAINT log_agent_id___fk FOREIGN KEY (agent_id) REFERENCES public_old.agent(id) ON UPDATE SET NULL ON DELETE SET NULL;


--
-- Name: log log_queue_id___fk; Type: FK CONSTRAINT; Schema: public_old; Owner: -
--

ALTER TABLE ONLY public_old.log
    ADD CONSTRAINT log_queue_id___fk FOREIGN KEY (queue_id) REFERENCES public_old.queue(id) ON UPDATE SET NULL ON DELETE SET NULL;


--
-- Name: agent_on_shift shift___fk; Type: FK CONSTRAINT; Schema: public_old; Owner: -
--

ALTER TABLE ONLY public_old.agent_on_shift
    ADD CONSTRAINT shift___fk FOREIGN KEY (shift_id) REFERENCES public_old.shift(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: agent_off_shift shift___fk; Type: FK CONSTRAINT; Schema: public_old; Owner: -
--

ALTER TABLE ONLY public_old.agent_off_shift
    ADD CONSTRAINT shift___fk FOREIGN KEY (shift_id) REFERENCES public_old.shift(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: agent team_manager___fk; Type: FK CONSTRAINT; Schema: public_old; Owner: -
--

ALTER TABLE ONLY public_old.agent
    ADD CONSTRAINT team_manager___fk FOREIGN KEY (team_manager) REFERENCES public_old.agent(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- PostgreSQL database dump complete
--

